/* c/zx-ns.c - WARNING: This file was automatically generated. DO NOT EDIT!
 * $Id$ */
#include "c/zx-ns.h"

struct zx_ns_s zx_ns_tab[61] = {
{ 0, 0, 0, 0, 0, 0, 0, sizeof("ds")-1, "ds", sizeof("http://www.w3.org/2000/09/xmldsig#")-1, "http://www.w3.org/2000/09/xmldsig#"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xenc")-1, "xenc", sizeof("http://www.w3.org/2001/04/xmlenc#")-1, "http://www.w3.org/2001/04/xmlenc#"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("exca")-1, "exca", sizeof("http://www.w3.org/2001/10/xml-exc-c14n#")-1, "http://www.w3.org/2001/10/xml-exc-c14n#"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sa")-1, "sa", sizeof("urn:oasis:names:tc:SAML:2.0:assertion")-1, "urn:oasis:names:tc:SAML:2.0:assertion"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sp")-1, "sp", sizeof("urn:oasis:names:tc:SAML:2.0:protocol")-1, "urn:oasis:names:tc:SAML:2.0:protocol"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("ecp")-1, "ecp", sizeof("urn:oasis:names:tc:SAML:2.0:profiles:SSO:ecp")-1, "urn:oasis:names:tc:SAML:2.0:profiles:SSO:ecp"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("paos")-1, "paos", sizeof("urn:liberty:paos:2006-08")-1, "urn:liberty:paos:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("e")-1, "e", sizeof("http://schemas.xmlsoap.org/soap/envelope/")-1, "http://schemas.xmlsoap.org/soap/envelope/"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("md")-1, "md", sizeof("urn:oasis:names:tc:SAML:2.0:metadata")-1, "urn:oasis:names:tc:SAML:2.0:metadata"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("shibmd")-1, "shibmd", sizeof("urn:mace:shibboleth:metadata:1.0")-1, "urn:mace:shibboleth:metadata:1.0"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sp11")-1, "sp11", sizeof("urn:oasis:names:tc:SAML:1.0:protocol")-1, "urn:oasis:names:tc:SAML:1.0:protocol"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sa11")-1, "sa11", sizeof("urn:oasis:names:tc:SAML:1.0:assertion")-1, "urn:oasis:names:tc:SAML:1.0:assertion"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("ff12")-1, "ff12", sizeof("urn:liberty:iff:2003-08")-1, "urn:liberty:iff:2003-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("ac")-1, "ac", sizeof("urn:liberty:ac:2004-12")-1, "urn:liberty:ac:2004-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("m20")-1, "m20", sizeof("urn:liberty:metadata:2004-12")-1, "urn:liberty:metadata:2004-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("a")-1, "a", sizeof("http://www.w3.org/2005/08/addressing")-1, "http://www.w3.org/2005/08/addressing"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("wsse")-1, "wsse", sizeof("http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd")-1, "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("wsu")-1, "wsu", sizeof("http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd")-1, "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sbf")-1, "sbf", sizeof("urn:liberty:sb")-1, "urn:liberty:sb"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("b")-1, "b", sizeof("urn:liberty:sb:2006-08")-1, "urn:liberty:sb:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sec")-1, "sec", sizeof("urn:liberty:security:2006-08")-1, "urn:liberty:security:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("di")-1, "di", sizeof("urn:liberty:disco:2006-08")-1, "urn:liberty:disco:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("is")-1, "is", sizeof("urn:liberty:is:2006-08")-1, "urn:liberty:is:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("lu")-1, "lu", sizeof("urn:liberty:util:2006-08")-1, "urn:liberty:util:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("dap")-1, "dap", sizeof("urn:liberty:id-sis-dap:2006-08:dst-2.1")-1, "urn:liberty:id-sis-dap:2006-08:dst-2.1"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("subs")-1, "subs", sizeof("urn:liberty:ssos:2006-08")-1, "urn:liberty:ssos:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("dst")-1, "dst", sizeof("urn:liberty:dst:2006-08")-1, "urn:liberty:dst:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("im")-1, "im", sizeof("urn:liberty:ims:2006-08")-1, "urn:liberty:ims:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("ps")-1, "ps", sizeof("urn:liberty:ps:2006-08")-1, "urn:liberty:ps:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("as")-1, "as", sizeof("urn:liberty:sa:2006-08")-1, "urn:liberty:sa:2006-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xml")-1, "xml", sizeof("http://www.w3.org/XML/1998/namespace")-1, "http://www.w3.org/XML/1998/namespace"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xsi")-1, "xsi", sizeof("http://www.w3.org/2001/XMLSchema-instance")-1, "http://www.w3.org/2001/XMLSchema-instance"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xs")-1, "xs", sizeof("http://www.w3.org/2001/XMLSchema")-1, "http://www.w3.org/2001/XMLSchema"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("mm7")-1, "mm7", sizeof("http://www.3gpp.org/ftp/Specs/archive/23_series/23.140/schema/REL-6-MM7-1-4")-1, "http://www.3gpp.org/ftp/Specs/archive/23_series/23.140/schema/REL-6-MM7-1-4"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("cb")-1, "cb", sizeof("urn:liberty:id-sis-cb:2004-10")-1, "urn:liberty:id-sis-cb:2004-10"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("cdm")-1, "cdm", sizeof("urn:liberty:cb:conceptual-data-model:2004-10")-1, "urn:liberty:cb:conceptual-data-model:2004-10"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("gl")-1, "gl", sizeof("urn:liberty:id-sis-gl:2005-07")-1, "urn:liberty:id-sis-gl:2005-07"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("dp")-1, "dp", sizeof("urn:liberty:dp:2006-12")-1, "urn:liberty:dp:2006-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("idp")-1, "idp", sizeof("urn:liberty:idp:2006-12")-1, "urn:liberty:idp:2006-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("pmm")-1, "pmm", sizeof("urn:liberty:pmm:2006-12")-1, "urn:liberty:pmm:2006-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("prov")-1, "prov", sizeof("urn:liberty:prov:2006-12")-1, "urn:liberty:prov:2006-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("shps")-1, "shps", sizeof("urn:liberty:shps:2006-12")-1, "urn:liberty:shps:2006-12"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("hrxml")-1, "hrxml", sizeof("http://ns.hr-xml.org/2007-04-15")-1, "http://ns.hr-xml.org/2007-04-15"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("idhrxml")-1, "idhrxml", sizeof("urn:id-sis-idhrxml:2007-06:dst-2.1")-1, "urn:id-sis-idhrxml:2007-06:dst-2.1"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("demomed")-1, "demomed", sizeof("urn:x-demo:me:2006-01")-1, "urn:x-demo:me:2006-01"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("b12")-1, "b12", sizeof("urn:liberty:sb:2003-08")-1, "urn:liberty:sb:2003-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("sec12")-1, "sec12", sizeof("urn:liberty:sec:2003-08")-1, "urn:liberty:sec:2003-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("di12")-1, "di12", sizeof("urn:liberty:disco:2003-08")-1, "urn:liberty:disco:2003-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("is12")-1, "is12", sizeof("urn:liberty:is:2003-08")-1, "urn:liberty:is:2003-08"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xac")-1, "xac", sizeof("urn:oasis:names:tc:xacml:2.0:context:schema:os")-1, "urn:oasis:names:tc:xacml:2.0:context:schema:os"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xa")-1, "xa", sizeof("urn:oasis:names:tc:xacml:2.0:policy:schema:os")-1, "urn:oasis:names:tc:xacml:2.0:policy:schema:os"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xasa")-1, "xasa", sizeof("urn:oasis:xacml:2.0:saml:assertion:schema:os")-1, "urn:oasis:xacml:2.0:saml:assertion:schema:os"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xasp")-1, "xasp", sizeof("urn:oasis:xacml:2.0:saml:protocol:schema:os")-1, "urn:oasis:xacml:2.0:saml:protocol:schema:os"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xaspcd1")-1, "xaspcd1", sizeof("urn:oasis:names:tc:xacml:2.0:profile:saml2.0:v2:schema:protocol:cd-01")-1, "urn:oasis:names:tc:xacml:2.0:profile:saml2.0:v2:schema:protocol:cd-01"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("xasacd1")-1, "xasacd1", sizeof("urn:oasis:names:tc:xacml:2.0:profile:saml2.0:v2:schema:assertion:cd-01")-1, "urn:oasis:names:tc:xacml:2.0:profile:saml2.0:v2:schema:assertion:cd-01"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("wst")-1, "wst", sizeof("http://docs.oasis-open.org/ws-sx/ws-trust/200512/")-1, "http://docs.oasis-open.org/ws-sx/ws-trust/200512/"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("wsp")-1, "wsp", sizeof("http://schemas.xmlsoap.org/ws/2004/09/policy")-1, "http://schemas.xmlsoap.org/ws/2004/09/policy"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("wsc")-1, "wsc", sizeof("http://docs.oasis-open.org/ws-sx/ws-secureconversation/200512")-1, "http://docs.oasis-open.org/ws-sx/ws-secureconversation/200512"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("tas3")-1, "tas3", sizeof("http://tas3.eu/tas3/200911/")-1, "http://tas3.eu/tas3/200911/"  },
{ 0, 0, 0, 0, 0, 0, 0, sizeof("tas3sol")-1, "tas3sol", sizeof("http://tas3.eu/tas3sol/200911/")-1, "http://tas3.eu/tas3sol/200911/"  },

  { 0,0,0,0,0,0,0, 0,0,0,0 }  /* Trailer element serves at runtime to hold list of unrecognized namespaces. */
};

/* EOF */
