/* c/zx-ns.h - WARNING: This file was automatically generated. DO NOT EDIT!
 * $Id$ */

#ifndef _zx__ns_h
#define _zx__ns_h
#include "zx.h"

extern struct zx_ns_s zx_ns_tab[61];

#define zx_xmlns_ix_ds 0
#define zx_xmlns_ds    "http://www.w3.org/2000/09/xmldsig#"
#define zx_xmlns_ix_xenc 1
#define zx_xmlns_xenc    "http://www.w3.org/2001/04/xmlenc#"
#define zx_xmlns_ix_exca 2
#define zx_xmlns_exca    "http://www.w3.org/2001/10/xml-exc-c14n#"
#define zx_xmlns_ix_sa 3
#define zx_xmlns_sa    "urn:oasis:names:tc:SAML:2.0:assertion"
#define zx_xmlns_ix_sp 4
#define zx_xmlns_sp    "urn:oasis:names:tc:SAML:2.0:protocol"
#define zx_xmlns_ix_ecp 5
#define zx_xmlns_ecp    "urn:oasis:names:tc:SAML:2.0:profiles:SSO:ecp"
#define zx_xmlns_ix_paos 6
#define zx_xmlns_paos    "urn:liberty:paos:2006-08"
#define zx_xmlns_ix_e 7
#define zx_xmlns_e    "http://schemas.xmlsoap.org/soap/envelope/"
#define zx_xmlns_ix_md 8
#define zx_xmlns_md    "urn:oasis:names:tc:SAML:2.0:metadata"
#define zx_xmlns_ix_shibmd 9
#define zx_xmlns_shibmd    "urn:mace:shibboleth:metadata:1.0"
#define zx_xmlns_ix_sp11 10
#define zx_xmlns_sp11    "urn:oasis:names:tc:SAML:1.0:protocol"
#define zx_xmlns_ix_sa11 11
#define zx_xmlns_sa11    "urn:oasis:names:tc:SAML:1.0:assertion"
#define zx_xmlns_ix_ff12 12
#define zx_xmlns_ff12    "urn:liberty:iff:2003-08"
#define zx_xmlns_ix_ac 13
#define zx_xmlns_ac    "urn:liberty:ac:2004-12"
#define zx_xmlns_ix_m20 14
#define zx_xmlns_m20    "urn:liberty:metadata:2004-12"
#define zx_xmlns_ix_a 15
#define zx_xmlns_a    "http://www.w3.org/2005/08/addressing"
#define zx_xmlns_ix_wsse 16
#define zx_xmlns_wsse    "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd"
#define zx_xmlns_ix_wsu 17
#define zx_xmlns_wsu    "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd"
#define zx_xmlns_ix_sbf 18
#define zx_xmlns_sbf    "urn:liberty:sb"
#define zx_xmlns_ix_b 19
#define zx_xmlns_b    "urn:liberty:sb:2006-08"
#define zx_xmlns_ix_sec 20
#define zx_xmlns_sec    "urn:liberty:security:2006-08"
#define zx_xmlns_ix_di 21
#define zx_xmlns_di    "urn:liberty:disco:2006-08"
#define zx_xmlns_ix_is 22
#define zx_xmlns_is    "urn:liberty:is:2006-08"
#define zx_xmlns_ix_lu 23
#define zx_xmlns_lu    "urn:liberty:util:2006-08"
#define zx_xmlns_ix_dap 24
#define zx_xmlns_dap    "urn:liberty:id-sis-dap:2006-08:dst-2.1"
#define zx_xmlns_ix_subs 25
#define zx_xmlns_subs    "urn:liberty:ssos:2006-08"
#define zx_xmlns_ix_dst 26
#define zx_xmlns_dst    "urn:liberty:dst:2006-08"
#define zx_xmlns_ix_im 27
#define zx_xmlns_im    "urn:liberty:ims:2006-08"
#define zx_xmlns_ix_ps 28
#define zx_xmlns_ps    "urn:liberty:ps:2006-08"
#define zx_xmlns_ix_as 29
#define zx_xmlns_as    "urn:liberty:sa:2006-08"
#define zx_xmlns_ix_xml 30
#define zx_xmlns_xml    "http://www.w3.org/XML/1998/namespace"
#define zx_xmlns_ix_xsi 31
#define zx_xmlns_xsi    "http://www.w3.org/2001/XMLSchema-instance"
#define zx_xmlns_ix_xs 32
#define zx_xmlns_xs    "http://www.w3.org/2001/XMLSchema"
#define zx_xmlns_ix_mm7 33
#define zx_xmlns_mm7    "http://www.3gpp.org/ftp/Specs/archive/23_series/23.140/schema/REL-6-MM7-1-4"
#define zx_xmlns_ix_cb 34
#define zx_xmlns_cb    "urn:liberty:id-sis-cb:2004-10"
#define zx_xmlns_ix_cdm 35
#define zx_xmlns_cdm    "urn:liberty:cb:conceptual-data-model:2004-10"
#define zx_xmlns_ix_gl 36
#define zx_xmlns_gl    "urn:liberty:id-sis-gl:2005-07"
#define zx_xmlns_ix_dp 37
#define zx_xmlns_dp    "urn:liberty:dp:2006-12"
#define zx_xmlns_ix_idp 38
#define zx_xmlns_idp    "urn:liberty:idp:2006-12"
#define zx_xmlns_ix_pmm 39
#define zx_xmlns_pmm    "urn:liberty:pmm:2006-12"
#define zx_xmlns_ix_prov 40
#define zx_xmlns_prov    "urn:liberty:prov:2006-12"
#define zx_xmlns_ix_shps 41
#define zx_xmlns_shps    "urn:liberty:shps:2006-12"
#define zx_xmlns_ix_hrxml 42
#define zx_xmlns_hrxml    "http://ns.hr-xml.org/2007-04-15"
#define zx_xmlns_ix_idhrxml 43
#define zx_xmlns_idhrxml    "urn:id-sis-idhrxml:2007-06:dst-2.1"
#define zx_xmlns_ix_demomed 44
#define zx_xmlns_demomed    "urn:x-demo:me:2006-01"
#define zx_xmlns_ix_b12 45
#define zx_xmlns_b12    "urn:liberty:sb:2003-08"
#define zx_xmlns_ix_sec12 46
#define zx_xmlns_sec12    "urn:liberty:sec:2003-08"
#define zx_xmlns_ix_di12 47
#define zx_xmlns_di12    "urn:liberty:disco:2003-08"
#define zx_xmlns_ix_is12 48
#define zx_xmlns_is12    "urn:liberty:is:2003-08"
#define zx_xmlns_ix_xac 49
#define zx_xmlns_xac    "urn:oasis:names:tc:xacml:2.0:context:schema:os"
#define zx_xmlns_ix_xa 50
#define zx_xmlns_xa    "urn:oasis:names:tc:xacml:2.0:policy:schema:os"
#define zx_xmlns_ix_xasa 51
#define zx_xmlns_xasa    "urn:oasis:xacml:2.0:saml:assertion:schema:os"
#define zx_xmlns_ix_xasp 52
#define zx_xmlns_xasp    "urn:oasis:xacml:2.0:saml:protocol:schema:os"
#define zx_xmlns_ix_xaspcd1 53
#define zx_xmlns_xaspcd1    "urn:oasis:names:tc:xacml:2.0:profile:saml2.0:v2:schema:protocol:cd-01"
#define zx_xmlns_ix_xasacd1 54
#define zx_xmlns_xasacd1    "urn:oasis:names:tc:xacml:2.0:profile:saml2.0:v2:schema:assertion:cd-01"
#define zx_xmlns_ix_wst 55
#define zx_xmlns_wst    "http://docs.oasis-open.org/ws-sx/ws-trust/200512/"
#define zx_xmlns_ix_wsp 56
#define zx_xmlns_wsp    "http://schemas.xmlsoap.org/ws/2004/09/policy"
#define zx_xmlns_ix_wsc 57
#define zx_xmlns_wsc    "http://docs.oasis-open.org/ws-sx/ws-secureconversation/200512"
#define zx_xmlns_ix_tas3 58
#define zx_xmlns_tas3    "http://tas3.eu/tas3/200911/"
#define zx_xmlns_ix_tas3sol 59
#define zx_xmlns_tas3sol    "http://tas3.eu/tas3sol/200911/"


#endif
