/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.40
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */


using System;
using System.Runtime.InteropServices;

public class zxid {
  public static void zx_ns_s_n_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_n_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_n_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_n_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_m_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_m_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_m_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_m_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_seen_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_seen_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_seen_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_seen_n_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_seen_n_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_n_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_seen_n_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_seen_p_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_seen_p_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_p_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_seen_p_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_seen_pop_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_seen_pop_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_pop_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_seen_pop_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_inc_n_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_s_inc_n_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_inc_n_get(SWIGTYPE_p_zx_ns_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_ns_s_inc_n_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ns_s_prefix_len_set(SWIGTYPE_p_zx_ns_s self, int value) {
    zxidPINVOKE.zx_ns_s_prefix_len_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static int zx_ns_s_prefix_len_get(SWIGTYPE_p_zx_ns_s self) {
    int ret = zxidPINVOKE.zx_ns_s_prefix_len_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return ret;
  }

  public static void zx_ns_s_prefix_set(SWIGTYPE_p_zx_ns_s self, string value) {
    zxidPINVOKE.zx_ns_s_prefix_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static string zx_ns_s_prefix_get(SWIGTYPE_p_zx_ns_s self) {
    string ret = zxidPINVOKE.zx_ns_s_prefix_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return ret;
  }

  public static void zx_ns_s_url_len_set(SWIGTYPE_p_zx_ns_s self, int value) {
    zxidPINVOKE.zx_ns_s_url_len_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static int zx_ns_s_url_len_get(SWIGTYPE_p_zx_ns_s self) {
    int ret = zxidPINVOKE.zx_ns_s_url_len_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return ret;
  }

  public static void zx_ns_s_url_set(SWIGTYPE_p_zx_ns_s self, string value) {
    zxidPINVOKE.zx_ns_s_url_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static string zx_ns_s_url_get(SWIGTYPE_p_zx_ns_s self) {
    string ret = zxidPINVOKE.zx_ns_s_url_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zx_ns_s new_zx_ns_s() {
    IntPtr cPtr = zxidPINVOKE.new_zx_ns_s();
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, true);
    return ret;
  }

  public static void delete_zx_ns_s(SWIGTYPE_p_zx_ns_s self) {
    zxidPINVOKE.delete_zx_ns_s(SWIGTYPE_p_zx_ns_s.getCPtr(self));
  }

  public static void zx_ctx__base_set(SWIGTYPE_p_zx_ctx self, string value) {
    zxidPINVOKE.zx_ctx__base_set(SWIGTYPE_p_zx_ctx.getCPtr(self), value);
  }

  public static string zx_ctx__base_get(SWIGTYPE_p_zx_ctx self) {
    string ret = zxidPINVOKE.zx_ctx__base_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return ret;
  }

  public static void zx_ctx_p_set(SWIGTYPE_p_zx_ctx self, string value) {
    zxidPINVOKE.zx_ctx_p_set(SWIGTYPE_p_zx_ctx.getCPtr(self), value);
  }

  public static string zx_ctx_p_get(SWIGTYPE_p_zx_ctx self) {
    string ret = zxidPINVOKE.zx_ctx_p_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return ret;
  }

  public static void zx_ctx_lim_set(SWIGTYPE_p_zx_ctx self, string value) {
    zxidPINVOKE.zx_ctx_lim_set(SWIGTYPE_p_zx_ctx.getCPtr(self), value);
  }

  public static string zx_ctx_lim_get(SWIGTYPE_p_zx_ctx self) {
    string ret = zxidPINVOKE.zx_ctx_lim_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return ret;
  }

  public static void zx_ctx_ns_tab_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ctx_ns_tab_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_ns_tab_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_ns_tab_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ctx_unknown_ns_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ctx_unknown_ns_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_unknown_ns_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_unknown_ns_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ctx_guard_seen_n_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ctx_guard_seen_n_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_guard_seen_n_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_guard_seen_n_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ctx_guard_seen_p_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ctx_guard_seen_p_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_guard_seen_p_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_guard_seen_p_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ctx_exclude_sig_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_void value) {
    zxidPINVOKE.zx_ctx_exclude_sig_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_void.getCPtr(value));
  }

  public static SWIGTYPE_p_void zx_ctx_exclude_sig_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_exclude_sig_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_void(cPtr, false);
    return ret;
  }

  public static void zx_ctx_inc_ns_len_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ctx_inc_ns_len_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_inc_ns_len_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_inc_ns_len_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ctx_inc_ns_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ctx_inc_ns_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_inc_ns_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_inc_ns_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_ctx_malloc_func_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_f_size_t__p_void value) {
    zxidPINVOKE.zx_ctx_malloc_func_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_f_size_t__p_void.getCPtr(value));
  }

  public static SWIGTYPE_p_f_size_t__p_void zx_ctx_malloc_func_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_malloc_func_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_f_size_t__p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_f_size_t__p_void(cPtr, false);
    return ret;
  }

  public static void zx_ctx_realloc_func_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_f_p_void_size_t__p_void value) {
    zxidPINVOKE.zx_ctx_realloc_func_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_f_p_void_size_t__p_void.getCPtr(value));
  }

  public static SWIGTYPE_p_f_p_void_size_t__p_void zx_ctx_realloc_func_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_realloc_func_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_f_p_void_size_t__p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_f_p_void_size_t__p_void(cPtr, false);
    return ret;
  }

  public static void zx_ctx_free_func_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_f_p_void__void value) {
    zxidPINVOKE.zx_ctx_free_func_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_f_p_void__void.getCPtr(value));
  }

  public static SWIGTYPE_p_f_p_void__void zx_ctx_free_func_get(SWIGTYPE_p_zx_ctx self) {
    IntPtr cPtr = zxidPINVOKE.zx_ctx_free_func_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    SWIGTYPE_p_f_p_void__void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_f_p_void__void(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_ctx new_zx_ctx() {
    IntPtr cPtr = zxidPINVOKE.new_zx_ctx();
    SWIGTYPE_p_zx_ctx ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ctx(cPtr, true);
    return ret;
  }

  public static void delete_zx_ctx(SWIGTYPE_p_zx_ctx self) {
    zxidPINVOKE.delete_zx_ctx(SWIGTYPE_p_zx_ctx.getCPtr(self));
  }

  public static void zx_node_s_n_set(SWIGTYPE_p_zx_node_s self, SWIGTYPE_p_zx_node_s value) {
    zxidPINVOKE.zx_node_s_n_set(SWIGTYPE_p_zx_node_s.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_node_s_n_get(SWIGTYPE_p_zx_node_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_node_s_n_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    SWIGTYPE_p_zx_node_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
    return ret;
  }

  public static void zx_node_s_wo_set(SWIGTYPE_p_zx_node_s self, SWIGTYPE_p_zx_node_s value) {
    zxidPINVOKE.zx_node_s_wo_set(SWIGTYPE_p_zx_node_s.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_node_s_wo_get(SWIGTYPE_p_zx_node_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_node_s_wo_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    SWIGTYPE_p_zx_node_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
    return ret;
  }

  public static void zx_node_s_ns_set(SWIGTYPE_p_zx_node_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_node_s_ns_set(SWIGTYPE_p_zx_node_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_node_s_ns_get(SWIGTYPE_p_zx_node_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_node_s_ns_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_node_s_tok_set(SWIGTYPE_p_zx_node_s self, short value) {
    zxidPINVOKE.zx_node_s_tok_set(SWIGTYPE_p_zx_node_s.getCPtr(self), value);
  }

  public static short zx_node_s_tok_get(SWIGTYPE_p_zx_node_s self) {
    short ret = zxidPINVOKE.zx_node_s_tok_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    return ret;
  }

  public static void zx_node_s_err_set(SWIGTYPE_p_zx_node_s self, short value) {
    zxidPINVOKE.zx_node_s_err_set(SWIGTYPE_p_zx_node_s.getCPtr(self), value);
  }

  public static short zx_node_s_err_get(SWIGTYPE_p_zx_node_s self) {
    short ret = zxidPINVOKE.zx_node_s_err_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zx_node_s new_zx_node_s() {
    IntPtr cPtr = zxidPINVOKE.new_zx_node_s();
    SWIGTYPE_p_zx_node_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_node_s(cPtr, true);
    return ret;
  }

  public static void delete_zx_node_s(SWIGTYPE_p_zx_node_s self) {
    zxidPINVOKE.delete_zx_node_s(SWIGTYPE_p_zx_node_s.getCPtr(self));
  }

  public static void zx_elem_s_g_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_node_s value) {
    zxidPINVOKE.zx_elem_s_g_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_elem_s_g_get(SWIGTYPE_p_zx_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_elem_s_g_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_node_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
    return ret;
  }

  public static void zx_elem_s_kids_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_elem_s value) {
    zxidPINVOKE.zx_elem_s_kids_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_elem_s zx_elem_s_kids_get(SWIGTYPE_p_zx_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_elem_s_kids_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static void zx_elem_s_any_attr_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_any_attr_s value) {
    zxidPINVOKE.zx_elem_s_any_attr_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_any_attr_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_any_attr_s zx_elem_s_any_attr_get(SWIGTYPE_p_zx_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_elem_s_any_attr_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_any_attr_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_any_attr_s(cPtr, false);
    return ret;
  }

  public static void zx_elem_s_any_elem_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_any_elem_s value) {
    zxidPINVOKE.zx_elem_s_any_elem_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_any_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_any_elem_s zx_elem_s_any_elem_get(SWIGTYPE_p_zx_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_elem_s_any_elem_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_any_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_any_elem_s(cPtr, false);
    return ret;
  }

  public static void zx_elem_s_xmlns_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zx_elem_s_xmlns_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zx_elem_s_xmlns_get(SWIGTYPE_p_zx_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_elem_s_xmlns_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static void zx_elem_s_content_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zx_elem_s_content_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zx_elem_s_content_get(SWIGTYPE_p_zx_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_elem_s_content_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_elem_s new_zx_elem_s() {
    IntPtr cPtr = zxidPINVOKE.new_zx_elem_s();
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, true);
    return ret;
  }

  public static void delete_zx_elem_s(SWIGTYPE_p_zx_elem_s self) {
    zxidPINVOKE.delete_zx_elem_s(SWIGTYPE_p_zx_elem_s.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_elem_s zx_new_simple_elem(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str ss) {
    IntPtr cPtr = zxidPINVOKE.zx_new_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(ss));
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_elem_s zx_ref_len_simple_elem(SWIGTYPE_p_zx_ctx c, int len) {
    IntPtr cPtr = zxidPINVOKE.zx_ref_len_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_elem_s zx_ref_simple_elem(SWIGTYPE_p_zx_ctx c, string s) {
    IntPtr cPtr = zxidPINVOKE.zx_ref_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), s);
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_elem_s zx_dup_len_simple_elem(SWIGTYPE_p_zx_ctx c, int len) {
    IntPtr cPtr = zxidPINVOKE.zx_dup_len_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_elem_s zx_dup_simple_elem(SWIGTYPE_p_zx_ctx c, string s) {
    IntPtr cPtr = zxidPINVOKE.zx_dup_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), s);
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static void zx_str_g_set(SWIGTYPE_p_zx_str self, SWIGTYPE_p_zx_node_s value) {
    zxidPINVOKE.zx_str_g_set(SWIGTYPE_p_zx_str.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_str_g_get(SWIGTYPE_p_zx_str self) {
    IntPtr cPtr = zxidPINVOKE.zx_str_g_get(SWIGTYPE_p_zx_str.getCPtr(self));
    SWIGTYPE_p_zx_node_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
    return ret;
  }

  public static void zx_str_len_set(SWIGTYPE_p_zx_str self, int value) {
    zxidPINVOKE.zx_str_len_set(SWIGTYPE_p_zx_str.getCPtr(self), value);
  }

  public static int zx_str_len_get(SWIGTYPE_p_zx_str self) {
    int ret = zxidPINVOKE.zx_str_len_get(SWIGTYPE_p_zx_str.getCPtr(self));
    return ret;
  }

  public static void zx_str_s_set(SWIGTYPE_p_zx_str self, string value) {
    zxidPINVOKE.zx_str_s_set(SWIGTYPE_p_zx_str.getCPtr(self), value);
  }

  public static string zx_str_s_get(SWIGTYPE_p_zx_str self) {
    string ret = zxidPINVOKE.zx_str_s_get(SWIGTYPE_p_zx_str.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zx_str new_zx_str() {
    IntPtr cPtr = zxidPINVOKE.new_zx_str();
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, true);
    return ret;
  }

  public static void delete_zx_str(SWIGTYPE_p_zx_str self) {
    zxidPINVOKE.delete_zx_str(SWIGTYPE_p_zx_str.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_str zx_ref_str(SWIGTYPE_p_zx_ctx c, string s) {
    IntPtr cPtr = zxidPINVOKE.zx_ref_str(SWIGTYPE_p_zx_ctx.getCPtr(c), s);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_ref_len_str(SWIGTYPE_p_zx_ctx c, int len) {
    IntPtr cPtr = zxidPINVOKE.zx_ref_len_str(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_new_len_str(SWIGTYPE_p_zx_ctx c, int len) {
    IntPtr cPtr = zxidPINVOKE.zx_new_len_str(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_dup_str(SWIGTYPE_p_zx_ctx c, string s) {
    IntPtr cPtr = zxidPINVOKE.zx_dup_str(SWIGTYPE_p_zx_ctx.getCPtr(c), s);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_dup_len_str(SWIGTYPE_p_zx_ctx c, int len) {
    IntPtr cPtr = zxidPINVOKE.zx_dup_len_str(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static string zx_alloc_sprintf(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_int retlen, string f) {
    string ret = zxidPINVOKE.zx_alloc_sprintf(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_int.getCPtr(retlen), f);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_strf(SWIGTYPE_p_zx_ctx c, string f) {
    IntPtr cPtr = zxidPINVOKE.zx_strf(SWIGTYPE_p_zx_ctx.getCPtr(c), f);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static void zx_str_free(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str ss) {
    zxidPINVOKE.zx_str_free(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(ss));
  }

  public static string zx_str_to_c(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str ss) {
    string ret = zxidPINVOKE.zx_str_to_c(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(ss));
    return ret;
  }

  public static void zx_str_conv(SWIGTYPE_p_zx_str ss, SWIGTYPE_p_int out_len, SWIGTYPE_p_p_char out_s) {
    zxidPINVOKE.zx_str_conv(SWIGTYPE_p_zx_str.getCPtr(ss), SWIGTYPE_p_int.getCPtr(out_len), SWIGTYPE_p_p_char.getCPtr(out_s));
  }

  public static int zx_str_ends_in(SWIGTYPE_p_zx_str ss, int len, string suffix) {
    int ret = zxidPINVOKE.zx_str_ends_in(SWIGTYPE_p_zx_str.getCPtr(ss), len, suffix);
    return ret;
  }

  public static void zx_any_elem_s_gg_set(SWIGTYPE_p_zx_any_elem_s self, SWIGTYPE_p_zx_elem_s value) {
    zxidPINVOKE.zx_any_elem_s_gg_set(SWIGTYPE_p_zx_any_elem_s.getCPtr(self), SWIGTYPE_p_zx_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_elem_s zx_any_elem_s_gg_get(SWIGTYPE_p_zx_any_elem_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_any_elem_s_gg_get(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static void zx_any_elem_s_name_len_set(SWIGTYPE_p_zx_any_elem_s self, int value) {
    zxidPINVOKE.zx_any_elem_s_name_len_set(SWIGTYPE_p_zx_any_elem_s.getCPtr(self), value);
  }

  public static int zx_any_elem_s_name_len_get(SWIGTYPE_p_zx_any_elem_s self) {
    int ret = zxidPINVOKE.zx_any_elem_s_name_len_get(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
    return ret;
  }

  public static void zx_any_elem_s_name_set(SWIGTYPE_p_zx_any_elem_s self, string value) {
    zxidPINVOKE.zx_any_elem_s_name_set(SWIGTYPE_p_zx_any_elem_s.getCPtr(self), value);
  }

  public static string zx_any_elem_s_name_get(SWIGTYPE_p_zx_any_elem_s self) {
    string ret = zxidPINVOKE.zx_any_elem_s_name_get(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zx_any_elem_s new_zx_any_elem_s() {
    IntPtr cPtr = zxidPINVOKE.new_zx_any_elem_s();
    SWIGTYPE_p_zx_any_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_any_elem_s(cPtr, true);
    return ret;
  }

  public static void delete_zx_any_elem_s(SWIGTYPE_p_zx_any_elem_s self) {
    zxidPINVOKE.delete_zx_any_elem_s(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
  }

  public static void zx_any_attr_s_ss_set(SWIGTYPE_p_zx_any_attr_s self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zx_any_attr_s_ss_set(SWIGTYPE_p_zx_any_attr_s.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zx_any_attr_s_ss_get(SWIGTYPE_p_zx_any_attr_s self) {
    IntPtr cPtr = zxidPINVOKE.zx_any_attr_s_ss_get(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static void zx_any_attr_s_name_len_set(SWIGTYPE_p_zx_any_attr_s self, int value) {
    zxidPINVOKE.zx_any_attr_s_name_len_set(SWIGTYPE_p_zx_any_attr_s.getCPtr(self), value);
  }

  public static int zx_any_attr_s_name_len_get(SWIGTYPE_p_zx_any_attr_s self) {
    int ret = zxidPINVOKE.zx_any_attr_s_name_len_get(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
    return ret;
  }

  public static void zx_any_attr_s_name_set(SWIGTYPE_p_zx_any_attr_s self, string value) {
    zxidPINVOKE.zx_any_attr_s_name_set(SWIGTYPE_p_zx_any_attr_s.getCPtr(self), value);
  }

  public static string zx_any_attr_s_name_get(SWIGTYPE_p_zx_any_attr_s self) {
    string ret = zxidPINVOKE.zx_any_attr_s_name_get(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zx_any_attr_s new_zx_any_attr_s() {
    IntPtr cPtr = zxidPINVOKE.new_zx_any_attr_s();
    SWIGTYPE_p_zx_any_attr_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_any_attr_s(cPtr, true);
    return ret;
  }

  public static void delete_zx_any_attr_s(SWIGTYPE_p_zx_any_attr_s self) {
    zxidPINVOKE.delete_zx_any_attr_s(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
  }

  public static string zx_memmem(string haystack, int haystack_len, string needle, int needle_len) {
    string ret = zxidPINVOKE.zx_memmem(haystack, haystack_len, needle, needle_len);
    return ret;
  }

  public static SWIGTYPE_p_void zx_alloc(SWIGTYPE_p_zx_ctx c, int size) {
    IntPtr cPtr = zxidPINVOKE.zx_alloc(SWIGTYPE_p_zx_ctx.getCPtr(c), size);
    SWIGTYPE_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_void(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_void zx_zalloc(SWIGTYPE_p_zx_ctx c, int size) {
    IntPtr cPtr = zxidPINVOKE.zx_zalloc(SWIGTYPE_p_zx_ctx.getCPtr(c), size);
    SWIGTYPE_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_void(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_void zx_free(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_void p) {
    IntPtr cPtr = zxidPINVOKE.zx_free(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_void.getCPtr(p));
    SWIGTYPE_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_void(cPtr, false);
    return ret;
  }

  public static string zx_dup_cstr(SWIGTYPE_p_zx_ctx c, string str) {
    string ret = zxidPINVOKE.zx_dup_cstr(SWIGTYPE_p_zx_ctx.getCPtr(c), str);
    return ret;
  }

  public static void zx_reset_ctx(SWIGTYPE_p_zx_ctx ctx) {
    zxidPINVOKE.zx_reset_ctx(SWIGTYPE_p_zx_ctx.getCPtr(ctx));
  }

  public static SWIGTYPE_p_zx_ctx zx_init_ctx() {
    IntPtr cPtr = zxidPINVOKE.zx_init_ctx();
    SWIGTYPE_p_zx_ctx ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ctx(cPtr, false);
    return ret;
  }

  public static void zx_tok_name_set(SWIGTYPE_p_zx_tok self, string value) {
    zxidPINVOKE.zx_tok_name_set(SWIGTYPE_p_zx_tok.getCPtr(self), value);
  }

  public static string zx_tok_name_get(SWIGTYPE_p_zx_tok self) {
    string ret = zxidPINVOKE.zx_tok_name_get(SWIGTYPE_p_zx_tok.getCPtr(self));
    return ret;
  }

  public static void zx_tok_prefix_set(SWIGTYPE_p_zx_tok self, string value) {
    zxidPINVOKE.zx_tok_prefix_set(SWIGTYPE_p_zx_tok.getCPtr(self), value);
  }

  public static string zx_tok_prefix_get(SWIGTYPE_p_zx_tok self) {
    string ret = zxidPINVOKE.zx_tok_prefix_get(SWIGTYPE_p_zx_tok.getCPtr(self));
    return ret;
  }

  public static void zx_tok_ns_set(SWIGTYPE_p_zx_tok self, SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_tok_ns_set(SWIGTYPE_p_zx_tok.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_tok_ns_get(SWIGTYPE_p_zx_tok self) {
    IntPtr cPtr = zxidPINVOKE.zx_tok_ns_get(SWIGTYPE_p_zx_tok.getCPtr(self));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_tok new_zx_tok() {
    IntPtr cPtr = zxidPINVOKE.new_zx_tok();
    SWIGTYPE_p_zx_tok ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_tok(cPtr, true);
    return ret;
  }

  public static void delete_zx_tok(SWIGTYPE_p_zx_tok self) {
    zxidPINVOKE.delete_zx_tok(SWIGTYPE_p_zx_tok.getCPtr(self));
  }

  public static int zx_date_time_to_secs(string dt) {
    int ret = zxidPINVOKE.zx_date_time_to_secs(dt);
    return ret;
  }

  public static int write2_or_append_lock_c_path(string c_path, int len1, string data1, int len2, string data2, string which, int seeky, int flag) {
    int ret = zxidPINVOKE.write2_or_append_lock_c_path(c_path, len1, data1, len2, data2, which, seeky, flag);
    return ret;
  }

  public static int zx_report_openssl_error(string logkey) {
    int ret = zxidPINVOKE.zx_report_openssl_error(logkey);
    return ret;
  }

  public static void zx_fix_any_elem_dec(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_any_elem_s x, string nam, int namlen) {
    zxidPINVOKE.zx_fix_any_elem_dec(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_any_elem_s.getCPtr(x), nam, namlen);
  }

  public static SWIGTYPE_p_zx_ns_s zx_locate_ns_by_prefix(SWIGTYPE_p_zx_ctx c, int len, string prefix) {
    IntPtr cPtr = zxidPINVOKE.zx_locate_ns_by_prefix(SWIGTYPE_p_zx_ctx.getCPtr(c), len, prefix);
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static int zx_is_ns_prefix(SWIGTYPE_p_zx_ns_s ns, int len, string prefix) {
    int ret = zxidPINVOKE.zx_is_ns_prefix(SWIGTYPE_p_zx_ns_s.getCPtr(ns), len, prefix);
    return ret;
  }

  public static SWIGTYPE_p_zx_ns_s zx_prefix_seen(SWIGTYPE_p_zx_ctx c, int len, string prefix) {
    IntPtr cPtr = zxidPINVOKE.zx_prefix_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), len, prefix);
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_ns_s zx_prefix_seen_whine(SWIGTYPE_p_zx_ctx c, int len, string prefix, string logkey, int mk_dummy_ns) {
    IntPtr cPtr = zxidPINVOKE.zx_prefix_seen_whine(SWIGTYPE_p_zx_ctx.getCPtr(c), len, prefix, logkey, mk_dummy_ns);
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_ns_s zx_scan_xmlns(SWIGTYPE_p_zx_ctx c) {
    IntPtr cPtr = zxidPINVOKE.zx_scan_xmlns(SWIGTYPE_p_zx_ctx.getCPtr(c));
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static void zx_pop_seen(SWIGTYPE_p_zx_ns_s ns) {
    zxidPINVOKE.zx_pop_seen(SWIGTYPE_p_zx_ns_s.getCPtr(ns));
  }

  public static SWIGTYPE_p_zx_str zx_raw_cipher(SWIGTYPE_p_zx_ctx c, string algo, int encp, SWIGTYPE_p_zx_str key, int len, int iv_len, string iv) {
    IntPtr cPtr = zxidPINVOKE.zx_raw_cipher(SWIGTYPE_p_zx_ctx.getCPtr(c), algo, encp, SWIGTYPE_p_zx_str.getCPtr(key), len, iv_len, iv);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_rsa_pub_enc(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str plain, SWIGTYPE_p_p_void rsa_pkey, int pad) {
    IntPtr cPtr = zxidPINVOKE.zx_rsa_pub_enc(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(plain), SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_rsa_pub_dec(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str ciphered, SWIGTYPE_p_p_void rsa_pkey, int pad) {
    IntPtr cPtr = zxidPINVOKE.zx_rsa_pub_dec(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(ciphered), SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_rsa_priv_dec(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str ciphered, SWIGTYPE_p_p_void rsa_pkey, int pad) {
    IntPtr cPtr = zxidPINVOKE.zx_rsa_priv_dec(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(ciphered), SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_rsa_priv_enc(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str plain, SWIGTYPE_p_p_void rsa_pkey, int pad) {
    IntPtr cPtr = zxidPINVOKE.zx_rsa_priv_enc(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(plain), SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_p_void zx_get_rsa_pub_from_cert(SWIGTYPE_p_X509 cert, string logkey) {
    IntPtr cPtr = zxidPINVOKE.zx_get_rsa_pub_from_cert(SWIGTYPE_p_X509.getCPtr(cert), logkey);
    SWIGTYPE_p_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_p_void(cPtr, false);
    return ret;
  }

  public static void zx_rand(string buf, int n_bytes) {
    zxidPINVOKE.zx_rand(buf, n_bytes);
  }

  public static string zx_md5_crypt(string pw, string salt, string buf) {
    string ret = zxidPINVOKE.zx_md5_crypt(pw, salt, buf);
    return ret;
  }

  public static SWIGTYPE_p_zx_tok zx_tok_by_ns(SWIGTYPE_p_zx_tok zt, SWIGTYPE_p_zx_tok lim, int len, string name, SWIGTYPE_p_zx_ns_s ns) {
    IntPtr cPtr = zxidPINVOKE.zx_tok_by_ns(SWIGTYPE_p_zx_tok.getCPtr(zt), SWIGTYPE_p_zx_tok.getCPtr(lim), len, name, SWIGTYPE_p_zx_ns_s.getCPtr(ns));
    SWIGTYPE_p_zx_tok ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_tok(cPtr, false);
    return ret;
  }

  public static int zx_len_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_ns_s ns, SWIGTYPE_p_p_zx_ns_s pop_seen) {
    int ret = zxidPINVOKE.zx_len_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_ns_s.getCPtr(ns), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seen));
    return ret;
  }

  public static string zx_enc_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx c, string p, SWIGTYPE_p_zx_ns_s ns, SWIGTYPE_p_p_zx_ns_s pop_seen) {
    string ret = zxidPINVOKE.zx_enc_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), p, SWIGTYPE_p_zx_ns_s.getCPtr(ns), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seen));
    return ret;
  }

  public static void zx_add_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_ns_s ns, SWIGTYPE_p_p_zx_ns_s pop_seen) {
    zxidPINVOKE.zx_add_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_ns_s.getCPtr(ns), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seen));
  }

  public static string zx_enc_seen(string p, SWIGTYPE_p_zx_ns_s ns) {
    string ret = zxidPINVOKE.zx_enc_seen(p, SWIGTYPE_p_zx_ns_s.getCPtr(ns));
    return ret;
  }

  public static int zx_len_so_common(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s x) {
    int ret = zxidPINVOKE.zx_len_so_common(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(x));
    return ret;
  }

  public static int zx_len_wo_common(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s x) {
    int ret = zxidPINVOKE.zx_len_wo_common(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(x));
    return ret;
  }

  public static string zx_enc_unknown_attrs(string p, SWIGTYPE_p_zx_any_attr_s aa) {
    string ret = zxidPINVOKE.zx_enc_unknown_attrs(p, SWIGTYPE_p_zx_any_attr_s.getCPtr(aa));
    return ret;
  }

  public static string zx_enc_so_unknown_elems_and_content(SWIGTYPE_p_zx_ctx c, string p, SWIGTYPE_p_zx_elem_s x) {
    string ret = zxidPINVOKE.zx_enc_so_unknown_elems_and_content(SWIGTYPE_p_zx_ctx.getCPtr(c), p, SWIGTYPE_p_zx_elem_s.getCPtr(x));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_easy_enc_common(SWIGTYPE_p_zx_ctx c, string p, string buf, int len) {
    IntPtr cPtr = zxidPINVOKE.zx_easy_enc_common(SWIGTYPE_p_zx_ctx.getCPtr(c), p, buf, len);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zx_attr_so_len(SWIGTYPE_p_zx_str attr, int name_size) {
    int ret = zxidPINVOKE.zx_attr_so_len(SWIGTYPE_p_zx_str.getCPtr(attr), name_size);
    return ret;
  }

  public static string zx_attr_so_enc(string p, SWIGTYPE_p_zx_str attr, string name, int name_len) {
    string ret = zxidPINVOKE.zx_attr_so_enc(p, SWIGTYPE_p_zx_str.getCPtr(attr), name, name_len);
    return ret;
  }

  public static int zx_attr_wo_len(SWIGTYPE_p_zx_str attr, int name_size) {
    int ret = zxidPINVOKE.zx_attr_wo_len(SWIGTYPE_p_zx_str.getCPtr(attr), name_size);
    return ret;
  }

  public static string zx_attr_wo_enc(string p, SWIGTYPE_p_zx_str attr, string name, int name_len) {
    string ret = zxidPINVOKE.zx_attr_wo_enc(p, SWIGTYPE_p_zx_str.getCPtr(attr), name, name_len);
    return ret;
  }

  public static void zx_free_attr(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_str attr, int free_strs) {
    zxidPINVOKE.zx_free_attr(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_str.getCPtr(attr), free_strs);
  }

  public static void zx_free_elem_common(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s x, int free_strs) {
    zxidPINVOKE.zx_free_elem_common(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(x), free_strs);
  }

  public static void zx_free_simple_elems(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s se, int free_strs) {
    zxidPINVOKE.zx_free_simple_elems(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(se), free_strs);
  }

  public static void zx_prepare_dec_ctx(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_ns_s ns_tab, string start, string lim) {
    zxidPINVOKE.zx_prepare_dec_ctx(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_ns_s.getCPtr(ns_tab), start, lim);
  }

  public static int zx_scan_data(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s el) {
    int ret = zxidPINVOKE.zx_scan_data(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(el));
    return ret;
  }

  public static int zx_scan_pi_or_comment(SWIGTYPE_p_zx_ctx c) {
    int ret = zxidPINVOKE.zx_scan_pi_or_comment(SWIGTYPE_p_zx_ctx.getCPtr(c));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zx_dec_unknown_attr(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s el, string name, string data, int tok, int ctx_tok) {
    IntPtr cPtr = zxidPINVOKE.zx_dec_unknown_attr(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(el), name, data, tok, ctx_tok);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static string zx_dec_attr_val(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_p_char name) {
    string ret = zxidPINVOKE.zx_dec_attr_val(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_p_char.getCPtr(name));
    return ret;
  }

  public static void zx_xml_parse_err(SWIGTYPE_p_zx_ctx c, char quote, string func, string msg) {
    zxidPINVOKE.zx_xml_parse_err(SWIGTYPE_p_zx_ctx.getCPtr(c), quote, func, msg);
  }

  public static int zx_len_inc_ns(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_p_zx_ns_s pop_seenp) {
    int ret = zxidPINVOKE.zx_len_inc_ns(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seenp));
    return ret;
  }

  public static void zx_add_inc_ns(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_p_zx_ns_s pop_seenp) {
    zxidPINVOKE.zx_add_inc_ns(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seenp));
  }

  public static string zx_enc_inc_ns(SWIGTYPE_p_zx_ctx c, string p, SWIGTYPE_p_p_zx_ns_s pop_seenp) {
    string ret = zxidPINVOKE.zx_enc_inc_ns(SWIGTYPE_p_zx_ctx.getCPtr(c), p, SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seenp));
    return ret;
  }

  public static void zxid_conf_magic_set(SWIGTYPE_p_zxid_conf self, uint value) {
    zxidPINVOKE.zxid_conf_magic_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static uint zxid_conf_magic_get(SWIGTYPE_p_zxid_conf self) {
    uint ret = zxidPINVOKE.zxid_conf_magic_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_ctx_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zx_ctx value) {
    zxidPINVOKE.zxid_conf_ctx_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zx_ctx.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ctx zxid_conf_ctx_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_ctx_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zx_ctx ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ctx(cPtr, false);
    return ret;
  }

  public static void zxid_conf_cot_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_entity value) {
    zxidPINVOKE.zxid_conf_cot_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity zxid_conf_cot_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_cot_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static void zxid_conf_path_supplied_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_path_supplied_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_path_supplied_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_path_supplied_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_path_len_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_path_len_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_path_len_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_path_len_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_path_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_path_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_path_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_path_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_url_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_url_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_url_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_url_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_non_standard_entityid_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_non_standard_entityid_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_non_standard_entityid_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_non_standard_entityid_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_redirect_hack_imposed_url_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_redirect_hack_imposed_url_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_redirect_hack_imposed_url_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_redirect_hack_imposed_url_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_redirect_hack_zxid_url_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_redirect_hack_zxid_url_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_redirect_hack_zxid_url_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_redirect_hack_zxid_url_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_redirect_hack_zxid_qs_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_redirect_hack_zxid_qs_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_redirect_hack_zxid_qs_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_redirect_hack_zxid_qs_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_cdc_url_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_cdc_url_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_cdc_url_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_cdc_url_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_cdc_choice_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_cdc_choice_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_cdc_choice_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_cdc_choice_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_md_fetch_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_md_fetch_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_md_fetch_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_md_fetch_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_md_populate_cache_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_md_populate_cache_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_md_populate_cache_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_md_populate_cache_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_md_cache_first_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_md_cache_first_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_md_cache_first_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_md_cache_first_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_md_cache_last_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_md_cache_last_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_md_cache_last_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_md_cache_last_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_auto_cert_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_auto_cert_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_auto_cert_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_auto_cert_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_user_local_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_user_local_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_user_local_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_user_local_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_ena_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_idp_ena_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_idp_ena_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_idp_ena_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_pdp_ena_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_pdp_ena_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_pdp_ena_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_pdp_ena_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_authn_req_sign_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_authn_req_sign_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_authn_req_sign_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_authn_req_sign_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_want_authn_req_signed_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_want_authn_req_signed_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_want_authn_req_signed_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_want_authn_req_signed_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_want_sso_a7n_signed_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_want_sso_a7n_signed_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_want_sso_a7n_signed_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_want_sso_a7n_signed_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_sso_soap_sign_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_sso_soap_sign_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_sso_soap_sign_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_sso_soap_sign_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_sso_soap_resp_sign_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_sso_soap_resp_sign_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_sso_soap_resp_sign_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_sso_soap_resp_sign_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_sso_sign_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_sso_sign_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_sso_sign_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_sso_sign_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_nameid_enc_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_nameid_enc_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_nameid_enc_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_nameid_enc_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_post_a7n_enc_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_post_a7n_enc_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_post_a7n_enc_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_post_a7n_enc_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_di_allow_create_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_di_allow_create_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_di_allow_create_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_di_allow_create_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_di_nid_fmt_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_di_nid_fmt_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_di_nid_fmt_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_di_nid_fmt_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_di_a7n_enc_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_di_a7n_enc_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_di_a7n_enc_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_di_a7n_enc_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_show_conf_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_show_conf_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_show_conf_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_show_conf_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_affiliation_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_affiliation_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_affiliation_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_affiliation_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_nice_name_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_nice_name_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_nice_name_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_nice_name_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_ses_arch_dir_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_ses_arch_dir_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_ses_arch_dir_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_ses_arch_dir_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_ses_cookie_name_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_ses_cookie_name_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_ses_cookie_name_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_ses_cookie_name_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_ipport_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_ipport_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_ipport_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_ipport_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_err_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_err_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_err_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_err_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_act_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_act_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_act_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_act_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_issue_a7n_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_issue_a7n_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_issue_a7n_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_issue_a7n_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_issue_msg_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_issue_msg_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_issue_msg_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_issue_msg_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_rely_a7n_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_rely_a7n_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_rely_a7n_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_rely_a7n_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_rely_msg_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_rely_msg_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_rely_msg_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_rely_msg_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_err_in_act_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_err_in_act_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_err_in_act_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_err_in_act_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_act_in_err_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_act_in_err_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_act_in_err_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_act_in_err_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_sigfail_is_err_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_sigfail_is_err_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_sigfail_is_err_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_sigfail_is_err_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_log_level_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_log_level_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_log_level_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_log_level_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_sig_fatal_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_sig_fatal_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_sig_fatal_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_sig_fatal_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_nosig_fatal_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_nosig_fatal_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_nosig_fatal_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_nosig_fatal_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_msg_sig_ok_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_msg_sig_ok_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_msg_sig_ok_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_msg_sig_ok_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_timeout_fatal_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_timeout_fatal_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_timeout_fatal_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_timeout_fatal_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_audience_fatal_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_audience_fatal_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_audience_fatal_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_audience_fatal_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_dup_a7n_fatal_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_dup_a7n_fatal_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_dup_a7n_fatal_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_dup_a7n_fatal_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_dup_msg_fatal_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_dup_msg_fatal_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_dup_msg_fatal_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_dup_msg_fatal_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_redir_to_content_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_redir_to_content_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_redir_to_content_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_redir_to_content_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_remote_user_ena_set(SWIGTYPE_p_zxid_conf self, char value) {
    zxidPINVOKE.zxid_conf_remote_user_ena_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static char zxid_conf_remote_user_ena_get(SWIGTYPE_p_zxid_conf self) {
    char ret = zxidPINVOKE.zxid_conf_remote_user_ena_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_anon_ok_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_anon_ok_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_anon_ok_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_anon_ok_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_required_authnctx_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_p_char value) {
    zxidPINVOKE.zxid_conf_required_authnctx_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_p_char.getCPtr(value));
  }

  public static SWIGTYPE_p_p_char zxid_conf_required_authnctx_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_required_authnctx_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_p_char ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_p_char(cPtr, false);
    return ret;
  }

  public static void zxid_conf_issue_authnctx_pw_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_issue_authnctx_pw_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_issue_authnctx_pw_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_issue_authnctx_pw_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_pref_acs_binding_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_pref_acs_binding_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_pref_acs_binding_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_pref_acs_binding_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_before_slop_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_before_slop_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_before_slop_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_before_slop_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_after_slop_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_after_slop_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_after_slop_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_after_slop_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_timeskew_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_timeskew_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_timeskew_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_timeskew_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_a7nttl_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_a7nttl_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_a7nttl_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_a7nttl_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_pdp_url_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_pdp_url_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_pdp_url_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_pdp_url_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_pdp_call_url_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_pdp_call_url_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_pdp_call_url_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_pdp_call_url_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_xasp_vers_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_xasp_vers_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_xasp_vers_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_xasp_vers_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_need_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_need value) {
    zxidPINVOKE.zxid_conf_need_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_need.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_need zxid_conf_need_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_need_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_need ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
    return ret;
  }

  public static void zxid_conf_want_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_need value) {
    zxidPINVOKE.zxid_conf_want_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_need.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_need zxid_conf_want_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_want_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_need ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
    return ret;
  }

  public static void zxid_conf_attrsrc_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_atsrc value) {
    zxidPINVOKE.zxid_conf_attrsrc_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_atsrc.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_atsrc zxid_conf_attrsrc_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_attrsrc_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_atsrc ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, false);
    return ret;
  }

  public static void zxid_conf_inmap_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_map value) {
    zxidPINVOKE.zxid_conf_inmap_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map zxid_conf_inmap_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_inmap_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
    return ret;
  }

  public static void zxid_conf_outmap_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_map value) {
    zxidPINVOKE.zxid_conf_outmap_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map zxid_conf_outmap_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_outmap_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
    return ret;
  }

  public static void zxid_conf_pepmap_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_map value) {
    zxidPINVOKE.zxid_conf_pepmap_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map zxid_conf_pepmap_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_pepmap_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
    return ret;
  }

  public static void zxid_conf_localpdp_role_permit_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidPINVOKE.zxid_conf_localpdp_role_permit_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_conf_localpdp_role_permit_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_localpdp_role_permit_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static void zxid_conf_localpdp_role_deny_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidPINVOKE.zxid_conf_localpdp_role_deny_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_conf_localpdp_role_deny_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_localpdp_role_deny_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static void zxid_conf_localpdp_idpnid_permit_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidPINVOKE.zxid_conf_localpdp_idpnid_permit_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_conf_localpdp_idpnid_permit_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_localpdp_idpnid_permit_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static void zxid_conf_localpdp_idpnid_deny_set(SWIGTYPE_p_zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidPINVOKE.zxid_conf_localpdp_idpnid_deny_set(SWIGTYPE_p_zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_conf_localpdp_idpnid_deny_get(SWIGTYPE_p_zxid_conf self) {
    IntPtr cPtr = zxidPINVOKE.zxid_conf_localpdp_idpnid_deny_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static void zxid_conf_max_soap_retry_set(SWIGTYPE_p_zxid_conf self, int value) {
    zxidPINVOKE.zxid_conf_max_soap_retry_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static int zxid_conf_max_soap_retry_get(SWIGTYPE_p_zxid_conf self) {
    int ret = zxidPINVOKE.zxid_conf_max_soap_retry_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_defaultqs_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_defaultqs_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_defaultqs_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_defaultqs_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_mod_saml_attr_prefix_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_mod_saml_attr_prefix_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_mod_saml_attr_prefix_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_mod_saml_attr_prefix_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_page_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_page_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_page_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_page_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_start_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_start_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_start_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_start_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_new_idp_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_new_idp_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_new_idp_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_new_idp_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_our_eid_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_our_eid_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_our_eid_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_our_eid_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_tech_user_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_tech_user_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_tech_user_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_tech_user_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_tech_site_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_tech_site_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_tech_site_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_tech_site_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_footer_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_footer_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_footer_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_footer_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_idp_sel_end_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_idp_sel_end_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_idp_sel_end_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_idp_sel_end_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_page_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_page_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_page_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_page_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_start_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_start_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_start_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_start_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_our_eid_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_our_eid_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_our_eid_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_our_eid_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_tech_user_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_tech_user_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_tech_user_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_tech_user_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_tech_site_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_tech_site_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_tech_site_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_tech_site_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_footer_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_footer_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_footer_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_footer_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_an_end_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_an_end_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_an_end_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_an_end_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_mgmt_start_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_mgmt_start_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_mgmt_start_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_mgmt_start_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_mgmt_logout_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_mgmt_logout_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_mgmt_logout_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_mgmt_logout_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_mgmt_defed_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_mgmt_defed_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_mgmt_defed_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_mgmt_defed_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_mgmt_footer_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_mgmt_footer_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_mgmt_footer_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_mgmt_footer_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_mgmt_end_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_mgmt_end_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_mgmt_end_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_mgmt_end_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static void zxid_conf_dbg_set(SWIGTYPE_p_zxid_conf self, string value) {
    zxidPINVOKE.zxid_conf_dbg_set(SWIGTYPE_p_zxid_conf.getCPtr(self), value);
  }

  public static string zxid_conf_dbg_get(SWIGTYPE_p_zxid_conf self) {
    string ret = zxidPINVOKE.zxid_conf_dbg_get(SWIGTYPE_p_zxid_conf.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zxid_conf new_zxid_conf() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_conf();
    SWIGTYPE_p_zxid_conf ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_conf(cPtr, true);
    return ret;
  }

  public static void delete_zxid_conf(SWIGTYPE_p_zxid_conf self) {
    zxidPINVOKE.delete_zxid_conf(SWIGTYPE_p_zxid_conf.getCPtr(self));
  }

  public static void zxid_cgi_magic_set(SWIGTYPE_p_zxid_cgi self, uint value) {
    zxidPINVOKE.zxid_cgi_magic_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static uint zxid_cgi_magic_get(SWIGTYPE_p_zxid_cgi self) {
    uint ret = zxidPINVOKE.zxid_cgi_magic_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_op_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_op_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_op_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_op_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_pr_ix_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_pr_ix_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_pr_ix_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_pr_ix_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_allow_create_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_allow_create_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_allow_create_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_allow_create_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_ispassive_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_ispassive_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_ispassive_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_ispassive_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_force_authn_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_force_authn_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_force_authn_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_force_authn_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_enc_hint_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_enc_hint_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_enc_hint_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_enc_hint_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_pad6_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_pad6_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_pad6_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_pad6_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_pad7_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidPINVOKE.zxid_cgi_pad7_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char zxid_cgi_pad7_get(SWIGTYPE_p_zxid_cgi self) {
    char ret = zxidPINVOKE.zxid_cgi_pad7_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_sid_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_sid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_sid_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_sid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_nid_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_nid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_nid_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_nid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_uid_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_uid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_uid_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_uid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_pw_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_pw_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_pw_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_pw_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_ssoreq_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_ssoreq_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_ssoreq_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_ssoreq_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_cdc_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_cdc_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_cdc_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_cdc_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_eid_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_eid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_eid_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_eid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_nid_fmt_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_nid_fmt_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_nid_fmt_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_nid_fmt_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_affil_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_affil_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_affil_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_affil_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_consent_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_consent_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_consent_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_consent_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_matching_rule_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_matching_rule_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_matching_rule_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_matching_rule_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_authn_ctx_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_authn_ctx_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_authn_ctx_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_authn_ctx_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_pxy_count_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_pxy_count_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_pxy_count_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_pxy_count_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_get_complete_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_get_complete_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_get_complete_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_get_complete_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_idppxylist_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_idppxylist_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_idppxylist_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_idppxylist_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_rs_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_rs_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_rs_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_rs_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_newnym_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_newnym_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_newnym_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_newnym_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_saml_art_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_saml_art_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_saml_art_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_saml_art_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_saml_resp_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_saml_resp_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_saml_resp_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_saml_resp_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_saml_req_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_saml_req_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_saml_req_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_saml_req_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_sigalg_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_sigalg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_sigalg_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_sigalg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_sig_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_sig_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_sig_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_sig_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_sigval_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_sigval_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_sigval_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_sigval_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_sigmsg_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_sigmsg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_sigmsg_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_sigmsg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_err_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_err_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_err_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_err_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_msg_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_msg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_msg_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_msg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_dbg_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_dbg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_dbg_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_dbg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_zxapp_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_zxapp_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_zxapp_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_zxapp_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_zxrfr_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_zxrfr_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_zxrfr_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_zxrfr_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_ok_set(SWIGTYPE_p_zxid_cgi self, string value) {
    zxidPINVOKE.zxid_cgi_ok_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static string zxid_cgi_ok_get(SWIGTYPE_p_zxid_cgi self) {
    string ret = zxidPINVOKE.zxid_cgi_ok_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return ret;
  }

  public static void zxid_cgi_idp_list_set(SWIGTYPE_p_zxid_cgi self, SWIGTYPE_p_zxid_entity value) {
    zxidPINVOKE.zxid_cgi_idp_list_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity zxid_cgi_idp_list_get(SWIGTYPE_p_zxid_cgi self) {
    IntPtr cPtr = zxidPINVOKE.zxid_cgi_idp_list_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_cgi new_zxid_cgi() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_cgi();
    SWIGTYPE_p_zxid_cgi ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cgi(cPtr, true);
    return ret;
  }

  public static void delete_zxid_cgi(SWIGTYPE_p_zxid_cgi self) {
    zxidPINVOKE.delete_zxid_cgi(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void zxid_ses_magic_set(SWIGTYPE_p_zxid_ses self, uint value) {
    zxidPINVOKE.zxid_ses_magic_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static uint zxid_ses_magic_get(SWIGTYPE_p_zxid_ses self) {
    uint ret = zxidPINVOKE.zxid_ses_magic_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_sid_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_sid_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_sid_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_sid_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_uid_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_uid_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_uid_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_uid_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_nid_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_nid_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_nid_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_nid_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_tgt_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_tgt_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_tgt_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_tgt_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_sesix_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_sesix_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_sesix_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_sesix_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_msgid_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_msgid_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_msgid_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_msgid_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_an_ctx_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_an_ctx_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_an_ctx_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_an_ctx_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_nidfmt_set(SWIGTYPE_p_zxid_ses self, char value) {
    zxidPINVOKE.zxid_ses_nidfmt_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static char zxid_ses_nidfmt_get(SWIGTYPE_p_zxid_ses self) {
    char ret = zxidPINVOKE.zxid_ses_nidfmt_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_tgtfmt_set(SWIGTYPE_p_zxid_ses self, char value) {
    zxidPINVOKE.zxid_ses_tgtfmt_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static char zxid_ses_tgtfmt_get(SWIGTYPE_p_zxid_ses self) {
    char ret = zxidPINVOKE.zxid_ses_tgtfmt_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_sigres_set(SWIGTYPE_p_zxid_ses self, char value) {
    zxidPINVOKE.zxid_ses_sigres_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static char zxid_ses_sigres_get(SWIGTYPE_p_zxid_ses self) {
    char ret = zxidPINVOKE.zxid_ses_sigres_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_pad3_set(SWIGTYPE_p_zxid_ses self, char value) {
    zxidPINVOKE.zxid_ses_pad3_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static char zxid_ses_pad3_get(SWIGTYPE_p_zxid_ses self) {
    char ret = zxidPINVOKE.zxid_ses_pad3_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_sso_a7n_path_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_sso_a7n_path_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_sso_a7n_path_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_sso_a7n_path_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_tgt_a7n_path_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_tgt_a7n_path_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_tgt_a7n_path_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_tgt_a7n_path_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_setcookie_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_setcookie_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_setcookie_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_setcookie_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_cookie_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_cookie_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_cookie_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_cookie_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_rs_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_rs_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_rs_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_rs_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_nameid_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_sa_NameID_s value) {
    zxidPINVOKE.zxid_ses_nameid_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_NameID_s zxid_ses_nameid_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_nameid_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_sa_NameID_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_a7n_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_sa_Assertion_s value) {
    zxidPINVOKE.zxid_ses_a7n_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s zxid_ses_a7n_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_a7n_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_sa_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_tgta7n_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_sa_Assertion_s value) {
    zxidPINVOKE.zxid_ses_tgta7n_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s zxid_ses_tgta7n_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_tgta7n_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_sa_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_a7n11_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_sa11_Assertion_s value) {
    zxidPINVOKE.zxid_ses_a7n11_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa11_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa11_Assertion_s zxid_ses_a7n11_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_a7n11_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_sa11_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa11_Assertion_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_tgta7n11_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_sa11_Assertion_s value) {
    zxidPINVOKE.zxid_ses_tgta7n11_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa11_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa11_Assertion_s zxid_ses_tgta7n11_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_tgta7n11_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_sa11_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa11_Assertion_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_a7n12_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_ff12_Assertion_s value) {
    zxidPINVOKE.zxid_ses_a7n12_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_ff12_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ff12_Assertion_s zxid_ses_a7n12_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_a7n12_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_ff12_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ff12_Assertion_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_tgta7n12_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zx_ff12_Assertion_s value) {
    zxidPINVOKE.zxid_ses_tgta7n12_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zx_ff12_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ff12_Assertion_s zxid_ses_tgta7n12_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_tgta7n12_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zx_ff12_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ff12_Assertion_s(cPtr, false);
    return ret;
  }

  public static void zxid_ses_sesbuf_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_sesbuf_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_sesbuf_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_sesbuf_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_sso_a7n_buf_set(SWIGTYPE_p_zxid_ses self, string value) {
    zxidPINVOKE.zxid_ses_sso_a7n_buf_set(SWIGTYPE_p_zxid_ses.getCPtr(self), value);
  }

  public static string zxid_ses_sso_a7n_buf_get(SWIGTYPE_p_zxid_ses self) {
    string ret = zxidPINVOKE.zxid_ses_sso_a7n_buf_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    return ret;
  }

  public static void zxid_ses_at_set(SWIGTYPE_p_zxid_ses self, SWIGTYPE_p_zxid_attr value) {
    zxidPINVOKE.zxid_ses_at_set(SWIGTYPE_p_zxid_ses.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr zxid_ses_at_get(SWIGTYPE_p_zxid_ses self) {
    IntPtr cPtr = zxidPINVOKE.zxid_ses_at_get(SWIGTYPE_p_zxid_ses.getCPtr(self));
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_ses new_zxid_ses() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_ses();
    SWIGTYPE_p_zxid_ses ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_ses(cPtr, true);
    return ret;
  }

  public static void delete_zxid_ses(SWIGTYPE_p_zxid_ses self) {
    zxidPINVOKE.delete_zxid_ses(SWIGTYPE_p_zxid_ses.getCPtr(self));
  }

  public static void zxid_attr_n_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zxid_attr value) {
    zxidPINVOKE.zxid_attr_n_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr zxid_attr_n_get(SWIGTYPE_p_zxid_attr self) {
    IntPtr cPtr = zxidPINVOKE.zxid_attr_n_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static void zxid_attr_nv_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zxid_attr value) {
    zxidPINVOKE.zxid_attr_nv_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr zxid_attr_nv_get(SWIGTYPE_p_zxid_attr self) {
    IntPtr cPtr = zxidPINVOKE.zxid_attr_nv_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static void zxid_attr_name_set(SWIGTYPE_p_zxid_attr self, string value) {
    zxidPINVOKE.zxid_attr_name_set(SWIGTYPE_p_zxid_attr.getCPtr(self), value);
  }

  public static string zxid_attr_name_get(SWIGTYPE_p_zxid_attr self) {
    string ret = zxidPINVOKE.zxid_attr_name_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    return ret;
  }

  public static void zxid_attr_val_set(SWIGTYPE_p_zxid_attr self, string value) {
    zxidPINVOKE.zxid_attr_val_set(SWIGTYPE_p_zxid_attr.getCPtr(self), value);
  }

  public static string zxid_attr_val_get(SWIGTYPE_p_zxid_attr self) {
    string ret = zxidPINVOKE.zxid_attr_val_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    return ret;
  }

  public static void zxid_attr_map_val_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zxid_attr_map_val_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zxid_attr_map_val_get(SWIGTYPE_p_zxid_attr self) {
    IntPtr cPtr = zxidPINVOKE.zxid_attr_map_val_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static void zxid_attr_orig_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zx_sa_Attribute_s value) {
    zxidPINVOKE.zxid_attr_orig_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zx_sa_Attribute_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s zxid_attr_orig_get(SWIGTYPE_p_zxid_attr self) {
    IntPtr cPtr = zxidPINVOKE.zxid_attr_orig_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    SWIGTYPE_p_zx_sa_Attribute_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
    return ret;
  }

  public static void zxid_attr_issuer_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zxid_attr_issuer_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zxid_attr_issuer_get(SWIGTYPE_p_zxid_attr self) {
    IntPtr cPtr = zxidPINVOKE.zxid_attr_issuer_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_attr new_zxid_attr() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_attr();
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, true);
    return ret;
  }

  public static void delete_zxid_attr(SWIGTYPE_p_zxid_attr self) {
    zxidPINVOKE.delete_zxid_attr(SWIGTYPE_p_zxid_attr.getCPtr(self));
  }

  public static void zxid_need_n_set(SWIGTYPE_p_zxid_need self, SWIGTYPE_p_zxid_need value) {
    zxidPINVOKE.zxid_need_n_set(SWIGTYPE_p_zxid_need.getCPtr(self), SWIGTYPE_p_zxid_need.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_need zxid_need_n_get(SWIGTYPE_p_zxid_need self) {
    IntPtr cPtr = zxidPINVOKE.zxid_need_n_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    SWIGTYPE_p_zxid_need ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
    return ret;
  }

  public static void zxid_need_at_set(SWIGTYPE_p_zxid_need self, SWIGTYPE_p_zxid_attr value) {
    zxidPINVOKE.zxid_need_at_set(SWIGTYPE_p_zxid_need.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr zxid_need_at_get(SWIGTYPE_p_zxid_need self) {
    IntPtr cPtr = zxidPINVOKE.zxid_need_at_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static void zxid_need_usage_set(SWIGTYPE_p_zxid_need self, string value) {
    zxidPINVOKE.zxid_need_usage_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static string zxid_need_usage_get(SWIGTYPE_p_zxid_need self) {
    string ret = zxidPINVOKE.zxid_need_usage_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    return ret;
  }

  public static void zxid_need_retent_set(SWIGTYPE_p_zxid_need self, string value) {
    zxidPINVOKE.zxid_need_retent_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static string zxid_need_retent_get(SWIGTYPE_p_zxid_need self) {
    string ret = zxidPINVOKE.zxid_need_retent_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    return ret;
  }

  public static void zxid_need_oblig_set(SWIGTYPE_p_zxid_need self, string value) {
    zxidPINVOKE.zxid_need_oblig_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static string zxid_need_oblig_get(SWIGTYPE_p_zxid_need self) {
    string ret = zxidPINVOKE.zxid_need_oblig_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    return ret;
  }

  public static void zxid_need_ext_set(SWIGTYPE_p_zxid_need self, string value) {
    zxidPINVOKE.zxid_need_ext_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static string zxid_need_ext_get(SWIGTYPE_p_zxid_need self) {
    string ret = zxidPINVOKE.zxid_need_ext_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zxid_need new_zxid_need() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_need();
    SWIGTYPE_p_zxid_need ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_need(cPtr, true);
    return ret;
  }

  public static void delete_zxid_need(SWIGTYPE_p_zxid_need self) {
    zxidPINVOKE.delete_zxid_need(SWIGTYPE_p_zxid_need.getCPtr(self));
  }

  public static void zxid_map_n_set(SWIGTYPE_p_zxid_map self, SWIGTYPE_p_zxid_map value) {
    zxidPINVOKE.zxid_map_n_set(SWIGTYPE_p_zxid_map.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map zxid_map_n_get(SWIGTYPE_p_zxid_map self) {
    IntPtr cPtr = zxidPINVOKE.zxid_map_n_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
    return ret;
  }

  public static void zxid_map_rule_set(SWIGTYPE_p_zxid_map self, int value) {
    zxidPINVOKE.zxid_map_rule_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static int zxid_map_rule_get(SWIGTYPE_p_zxid_map self) {
    int ret = zxidPINVOKE.zxid_map_rule_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    return ret;
  }

  public static void zxid_map_ns_set(SWIGTYPE_p_zxid_map self, string value) {
    zxidPINVOKE.zxid_map_ns_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static string zxid_map_ns_get(SWIGTYPE_p_zxid_map self) {
    string ret = zxidPINVOKE.zxid_map_ns_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    return ret;
  }

  public static void zxid_map_src_set(SWIGTYPE_p_zxid_map self, string value) {
    zxidPINVOKE.zxid_map_src_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static string zxid_map_src_get(SWIGTYPE_p_zxid_map self) {
    string ret = zxidPINVOKE.zxid_map_src_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    return ret;
  }

  public static void zxid_map_dst_set(SWIGTYPE_p_zxid_map self, string value) {
    zxidPINVOKE.zxid_map_dst_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static string zxid_map_dst_get(SWIGTYPE_p_zxid_map self) {
    string ret = zxidPINVOKE.zxid_map_dst_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    return ret;
  }

  public static void zxid_map_ext_set(SWIGTYPE_p_zxid_map self, string value) {
    zxidPINVOKE.zxid_map_ext_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static string zxid_map_ext_get(SWIGTYPE_p_zxid_map self) {
    string ret = zxidPINVOKE.zxid_map_ext_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zxid_map new_zxid_map() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_map();
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, true);
    return ret;
  }

  public static void delete_zxid_map(SWIGTYPE_p_zxid_map self) {
    zxidPINVOKE.delete_zxid_map(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static void zxid_cstr_list_n_set(SWIGTYPE_p_zxid_cstr_list self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidPINVOKE.zxid_cstr_list_n_set(SWIGTYPE_p_zxid_cstr_list.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_cstr_list_n_get(SWIGTYPE_p_zxid_cstr_list self) {
    IntPtr cPtr = zxidPINVOKE.zxid_cstr_list_n_get(SWIGTYPE_p_zxid_cstr_list.getCPtr(self));
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static void zxid_cstr_list_s_set(SWIGTYPE_p_zxid_cstr_list self, string value) {
    zxidPINVOKE.zxid_cstr_list_s_set(SWIGTYPE_p_zxid_cstr_list.getCPtr(self), value);
  }

  public static string zxid_cstr_list_s_get(SWIGTYPE_p_zxid_cstr_list self) {
    string ret = zxidPINVOKE.zxid_cstr_list_s_get(SWIGTYPE_p_zxid_cstr_list.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zxid_cstr_list new_zxid_cstr_list() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_cstr_list();
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, true);
    return ret;
  }

  public static void delete_zxid_cstr_list(SWIGTYPE_p_zxid_cstr_list self) {
    zxidPINVOKE.delete_zxid_cstr_list(SWIGTYPE_p_zxid_cstr_list.getCPtr(self));
  }

  public static void zxid_atsrc_n_set(SWIGTYPE_p_zxid_atsrc self, SWIGTYPE_p_zxid_atsrc value) {
    zxidPINVOKE.zxid_atsrc_n_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), SWIGTYPE_p_zxid_atsrc.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_atsrc zxid_atsrc_n_get(SWIGTYPE_p_zxid_atsrc self) {
    IntPtr cPtr = zxidPINVOKE.zxid_atsrc_n_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    SWIGTYPE_p_zxid_atsrc ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, false);
    return ret;
  }

  public static void zxid_atsrc_at_set(SWIGTYPE_p_zxid_atsrc self, SWIGTYPE_p_zxid_attr value) {
    zxidPINVOKE.zxid_atsrc_at_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr zxid_atsrc_at_get(SWIGTYPE_p_zxid_atsrc self) {
    IntPtr cPtr = zxidPINVOKE.zxid_atsrc_at_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static void zxid_atsrc_ns_set(SWIGTYPE_p_zxid_atsrc self, string value) {
    zxidPINVOKE.zxid_atsrc_ns_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static string zxid_atsrc_ns_get(SWIGTYPE_p_zxid_atsrc self) {
    string ret = zxidPINVOKE.zxid_atsrc_ns_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return ret;
  }

  public static void zxid_atsrc_weight_set(SWIGTYPE_p_zxid_atsrc self, string value) {
    zxidPINVOKE.zxid_atsrc_weight_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static string zxid_atsrc_weight_get(SWIGTYPE_p_zxid_atsrc self) {
    string ret = zxidPINVOKE.zxid_atsrc_weight_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return ret;
  }

  public static void zxid_atsrc_url_set(SWIGTYPE_p_zxid_atsrc self, string value) {
    zxidPINVOKE.zxid_atsrc_url_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static string zxid_atsrc_url_get(SWIGTYPE_p_zxid_atsrc self) {
    string ret = zxidPINVOKE.zxid_atsrc_url_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return ret;
  }

  public static void zxid_atsrc_aapml_set(SWIGTYPE_p_zxid_atsrc self, string value) {
    zxidPINVOKE.zxid_atsrc_aapml_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static string zxid_atsrc_aapml_get(SWIGTYPE_p_zxid_atsrc self) {
    string ret = zxidPINVOKE.zxid_atsrc_aapml_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return ret;
  }

  public static void zxid_atsrc_otherlim_set(SWIGTYPE_p_zxid_atsrc self, string value) {
    zxidPINVOKE.zxid_atsrc_otherlim_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static string zxid_atsrc_otherlim_get(SWIGTYPE_p_zxid_atsrc self) {
    string ret = zxidPINVOKE.zxid_atsrc_otherlim_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return ret;
  }

  public static void zxid_atsrc_ext_set(SWIGTYPE_p_zxid_atsrc self, string value) {
    zxidPINVOKE.zxid_atsrc_ext_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static string zxid_atsrc_ext_get(SWIGTYPE_p_zxid_atsrc self) {
    string ret = zxidPINVOKE.zxid_atsrc_ext_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zxid_atsrc new_zxid_atsrc() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_atsrc();
    SWIGTYPE_p_zxid_atsrc ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, true);
    return ret;
  }

  public static void delete_zxid_atsrc(SWIGTYPE_p_zxid_atsrc self) {
    zxidPINVOKE.delete_zxid_atsrc(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void zxid_entity_n_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_zxid_entity value) {
    zxidPINVOKE.zxid_entity_n_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity zxid_entity_n_get(SWIGTYPE_p_zxid_entity self) {
    IntPtr cPtr = zxidPINVOKE.zxid_entity_n_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static void zxid_entity_n_cdc_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_zxid_entity value) {
    zxidPINVOKE.zxid_entity_n_cdc_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity zxid_entity_n_cdc_get(SWIGTYPE_p_zxid_entity self) {
    IntPtr cPtr = zxidPINVOKE.zxid_entity_n_cdc_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static void zxid_entity_eid_len_set(SWIGTYPE_p_zxid_entity self, int value) {
    zxidPINVOKE.zxid_entity_eid_len_set(SWIGTYPE_p_zxid_entity.getCPtr(self), value);
  }

  public static int zxid_entity_eid_len_get(SWIGTYPE_p_zxid_entity self) {
    int ret = zxidPINVOKE.zxid_entity_eid_len_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return ret;
  }

  public static void zxid_entity_eid_set(SWIGTYPE_p_zxid_entity self, string value) {
    zxidPINVOKE.zxid_entity_eid_set(SWIGTYPE_p_zxid_entity.getCPtr(self), value);
  }

  public static string zxid_entity_eid_get(SWIGTYPE_p_zxid_entity self) {
    string ret = zxidPINVOKE.zxid_entity_eid_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return ret;
  }

  public static void zxid_entity_sha1_name_set(SWIGTYPE_p_zxid_entity self, string value) {
    zxidPINVOKE.zxid_entity_sha1_name_set(SWIGTYPE_p_zxid_entity.getCPtr(self), value);
  }

  public static string zxid_entity_sha1_name_get(SWIGTYPE_p_zxid_entity self) {
    string ret = zxidPINVOKE.zxid_entity_sha1_name_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return ret;
  }

  public static void zxid_entity_tls_cert_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_X509 value) {
    zxidPINVOKE.zxid_entity_tls_cert_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_X509.getCPtr(value));
  }

  public static SWIGTYPE_p_X509 zxid_entity_tls_cert_get(SWIGTYPE_p_zxid_entity self) {
    IntPtr cPtr = zxidPINVOKE.zxid_entity_tls_cert_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    SWIGTYPE_p_X509 ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_X509(cPtr, false);
    return ret;
  }

  public static void zxid_entity_sign_cert_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_X509 value) {
    zxidPINVOKE.zxid_entity_sign_cert_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_X509.getCPtr(value));
  }

  public static SWIGTYPE_p_X509 zxid_entity_sign_cert_get(SWIGTYPE_p_zxid_entity self) {
    IntPtr cPtr = zxidPINVOKE.zxid_entity_sign_cert_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    SWIGTYPE_p_X509 ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_X509(cPtr, false);
    return ret;
  }

  public static void zxid_entity_enc_cert_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_X509 value) {
    zxidPINVOKE.zxid_entity_enc_cert_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_X509.getCPtr(value));
  }

  public static SWIGTYPE_p_X509 zxid_entity_enc_cert_get(SWIGTYPE_p_zxid_entity self) {
    IntPtr cPtr = zxidPINVOKE.zxid_entity_enc_cert_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    SWIGTYPE_p_X509 ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_X509(cPtr, false);
    return ret;
  }

  public static void zxid_entity_ed_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_zx_md_EntityDescriptor_s value) {
    zxidPINVOKE.zxid_entity_ed_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_zx_md_EntityDescriptor_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_md_EntityDescriptor_s zxid_entity_ed_get(SWIGTYPE_p_zxid_entity self) {
    IntPtr cPtr = zxidPINVOKE.zxid_entity_ed_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    SWIGTYPE_p_zx_md_EntityDescriptor_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_EntityDescriptor_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity new_zxid_entity() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_entity();
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, true);
    return ret;
  }

  public static void delete_zxid_entity(SWIGTYPE_p_zxid_entity self) {
    zxidPINVOKE.delete_zxid_entity(SWIGTYPE_p_zxid_entity.getCPtr(self));
  }

  public static string zxid_simple(string conf, string qs, int auto_flags) {
    string ret = zxidPINVOKE.zxid_simple(conf, qs, auto_flags);
    return ret;
  }

  public static string zxid_idp_list(string conf, int auto_flags) {
    string ret = zxidPINVOKE.zxid_idp_list(conf, auto_flags);
    return ret;
  }

  public static string zxid_idp_select(string conf, int auto_flags) {
    string ret = zxidPINVOKE.zxid_idp_select(conf, auto_flags);
    return ret;
  }

  public static string zxid_fed_mgmt(string conf, string sid, int auto_flags) {
    string ret = zxidPINVOKE.zxid_fed_mgmt(conf, sid, auto_flags);
    return ret;
  }

  public static SWIGTYPE_p_zxid_conf zxid_new_conf_to_cf(string conf) {
    IntPtr cPtr = zxidPINVOKE.zxid_new_conf_to_cf(conf);
    SWIGTYPE_p_zxid_conf ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_conf(cPtr, false);
    return ret;
  }

  public static string zxid_simple_cf(SWIGTYPE_p_zxid_conf cf, int qs_len, string qs, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_simple_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), qs_len, qs, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_idp_list_cf(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_idp_list_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_idp_select_cf(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_idp_select_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_fed_mgmt_cf(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_int res_len, int sid_len, string sid, int auto_flags) {
    string ret = zxidPINVOKE.zxid_fed_mgmt_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_int.getCPtr(res_len), sid_len, sid, auto_flags);
    return ret;
  }

  public static int zxid_conf_to_cf_len(SWIGTYPE_p_zxid_conf cf, int conf_len, string conf) {
    int ret = zxidPINVOKE.zxid_conf_to_cf_len(SWIGTYPE_p_zxid_conf.getCPtr(cf), conf_len, conf);
    return ret;
  }

  public static string zxid_simple_len(int conf_len, string conf, int qs_len, string qs, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_simple_len(conf_len, conf, qs_len, qs, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_idp_list_len(int conf_len, string conf, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_idp_list_len(conf_len, conf, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_idp_select_len(int conf_len, string conf, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_idp_select_len(conf_len, conf, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_fed_mgmt_len(int conf_len, string conf, SWIGTYPE_p_int res_len, string sid, int auto_flags) {
    string ret = zxidPINVOKE.zxid_fed_mgmt_len(conf_len, conf, SWIGTYPE_p_int.getCPtr(res_len), sid, auto_flags);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_idp_select_zxstr_cf(SWIGTYPE_p_zxid_conf cf, int auto_flags) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_select_zxstr_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), auto_flags);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static string zxid_simple_ab_pep(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_simple_ab_pep(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_simple_ses_active_cf(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_simple_ses_active_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static string zxid_simple_no_ses_cf(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_int res_len, int auto_flags) {
    string ret = zxidPINVOKE.zxid_simple_no_ses_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
    return ret;
  }

  public static void zxsig_ref_sref_set(SWIGTYPE_p_zxsig_ref self, SWIGTYPE_p_zx_ds_Reference_s value) {
    zxidPINVOKE.zxsig_ref_sref_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), SWIGTYPE_p_zx_ds_Reference_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ds_Reference_s zxsig_ref_sref_get(SWIGTYPE_p_zxsig_ref self) {
    IntPtr cPtr = zxidPINVOKE.zxsig_ref_sref_get(SWIGTYPE_p_zxsig_ref.getCPtr(self));
    SWIGTYPE_p_zx_ds_Reference_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ds_Reference_s(cPtr, false);
    return ret;
  }

  public static void zxsig_ref_blob_set(SWIGTYPE_p_zxsig_ref self, SWIGTYPE_p_zx_elem_s value) {
    zxidPINVOKE.zxsig_ref_blob_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), SWIGTYPE_p_zx_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_elem_s zxsig_ref_blob_get(SWIGTYPE_p_zxsig_ref self) {
    IntPtr cPtr = zxidPINVOKE.zxsig_ref_blob_get(SWIGTYPE_p_zxsig_ref.getCPtr(self));
    SWIGTYPE_p_zx_elem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
    return ret;
  }

  public static void zxsig_ref_id_set(SWIGTYPE_p_zxsig_ref self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zxsig_ref_id_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zxsig_ref_id_get(SWIGTYPE_p_zxsig_ref self) {
    IntPtr cPtr = zxidPINVOKE.zxsig_ref_id_get(SWIGTYPE_p_zxsig_ref.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static void zxsig_ref_canon_set(SWIGTYPE_p_zxsig_ref self, SWIGTYPE_p_zx_str value) {
    zxidPINVOKE.zxsig_ref_canon_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), SWIGTYPE_p_zx_str.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_str zxsig_ref_canon_get(SWIGTYPE_p_zxsig_ref self) {
    IntPtr cPtr = zxidPINVOKE.zxsig_ref_canon_get(SWIGTYPE_p_zxsig_ref.getCPtr(self));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxsig_ref new_zxsig_ref() {
    IntPtr cPtr = zxidPINVOKE.new_zxsig_ref();
    SWIGTYPE_p_zxsig_ref ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxsig_ref(cPtr, true);
    return ret;
  }

  public static void delete_zxsig_ref(SWIGTYPE_p_zxsig_ref self) {
    zxidPINVOKE.delete_zxsig_ref(SWIGTYPE_p_zxsig_ref.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_ds_Signature_s zxsig_sign(SWIGTYPE_p_zx_ctx c, int n, SWIGTYPE_p_zxsig_ref sref, SWIGTYPE_p_X509 cert, SWIGTYPE_p_p_void priv_key) {
    IntPtr cPtr = zxidPINVOKE.zxsig_sign(SWIGTYPE_p_zx_ctx.getCPtr(c), n, SWIGTYPE_p_zxsig_ref.getCPtr(sref), SWIGTYPE_p_X509.getCPtr(cert), SWIGTYPE_p_p_void.getCPtr(priv_key));
    SWIGTYPE_p_zx_ds_Signature_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ds_Signature_s(cPtr, false);
    return ret;
  }

  public static int zxsig_validate(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_X509 cert, SWIGTYPE_p_zx_ds_Signature_s sig, int n, SWIGTYPE_p_zxsig_ref refs) {
    int ret = zxidPINVOKE.zxsig_validate(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_X509.getCPtr(cert), SWIGTYPE_p_zx_ds_Signature_s.getCPtr(sig), n, SWIGTYPE_p_zxsig_ref.getCPtr(refs));
    return ret;
  }

  public static int zxsig_data_rsa_sha1(SWIGTYPE_p_zx_ctx c, int len, string d, SWIGTYPE_p_p_char sig, SWIGTYPE_p_p_void priv_key, string lk) {
    int ret = zxidPINVOKE.zxsig_data_rsa_sha1(SWIGTYPE_p_zx_ctx.getCPtr(c), len, d, SWIGTYPE_p_p_char.getCPtr(sig), SWIGTYPE_p_p_void.getCPtr(priv_key), lk);
    return ret;
  }

  public static int zxsig_verify_data_rsa_sha1(int len, string data, int siglen, string sig, SWIGTYPE_p_X509 cert, string lk) {
    int ret = zxidPINVOKE.zxsig_verify_data_rsa_sha1(len, data, siglen, sig, SWIGTYPE_p_X509.getCPtr(cert), lk);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxenc_symkey_dec(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_xenc_EncryptedData_s ed, SWIGTYPE_p_zx_str symkey) {
    IntPtr cPtr = zxidPINVOKE.zxenc_symkey_dec(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xenc_EncryptedData_s.getCPtr(ed), SWIGTYPE_p_zx_str.getCPtr(symkey));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxenc_privkey_dec(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_xenc_EncryptedData_s ed, SWIGTYPE_p_zx_xenc_EncryptedKey_s ek) {
    IntPtr cPtr = zxidPINVOKE.zxenc_privkey_dec(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xenc_EncryptedData_s.getCPtr(ed), SWIGTYPE_p_zx_xenc_EncryptedKey_s.getCPtr(ek));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_xenc_EncryptedData_s zxenc_symkey_enc(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str data, SWIGTYPE_p_zx_str ed_id, SWIGTYPE_p_zx_str symkey, SWIGTYPE_p_zx_str symkey_id) {
    IntPtr cPtr = zxidPINVOKE.zxenc_symkey_enc(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(data), SWIGTYPE_p_zx_str.getCPtr(ed_id), SWIGTYPE_p_zx_str.getCPtr(symkey), SWIGTYPE_p_zx_str.getCPtr(symkey_id));
    SWIGTYPE_p_zx_xenc_EncryptedData_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_xenc_EncryptedData_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_xenc_EncryptedData_s zxenc_pubkey_enc(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str data, SWIGTYPE_p_p_zx_xenc_EncryptedKey_s ekp, SWIGTYPE_p_X509 cert, string idsuffix) {
    IntPtr cPtr = zxidPINVOKE.zxenc_pubkey_enc(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(data), SWIGTYPE_p_p_zx_xenc_EncryptedKey_s.getCPtr(ekp), SWIGTYPE_p_X509.getCPtr(cert), idsuffix);
    SWIGTYPE_p_zx_xenc_EncryptedData_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_xenc_EncryptedData_s(cPtr, false);
    return ret;
  }

  public static void zxlog_write_line(SWIGTYPE_p_zxid_conf cf, string c_path, int encflags, int n, string logbuf) {
    zxidPINVOKE.zxlog_write_line(SWIGTYPE_p_zxid_conf.getCPtr(cf), c_path, encflags, n, logbuf);
  }

  public static SWIGTYPE_p_zx_str zxlog_path(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str entid, SWIGTYPE_p_zx_str objid, string dir, string kind, int create_dirs) {
    IntPtr cPtr = zxidPINVOKE.zxlog_path(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(entid), SWIGTYPE_p_zx_str.getCPtr(objid), dir, kind, create_dirs);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxlog_dup_check(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str path, string logkey) {
    int ret = zxidPINVOKE.zxlog_dup_check(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(path), logkey);
    return ret;
  }

  public static int zxlog_blob(SWIGTYPE_p_zxid_conf cf, int logflag, SWIGTYPE_p_zx_str path, SWIGTYPE_p_zx_str blob, string lk) {
    int ret = zxidPINVOKE.zxlog_blob(SWIGTYPE_p_zxid_conf.getCPtr(cf), logflag, SWIGTYPE_p_zx_str.getCPtr(path), SWIGTYPE_p_zx_str.getCPtr(blob), lk);
    return ret;
  }

  public static int zxlog(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_timeval ourts, SWIGTYPE_p_timeval srcts, string ipport, SWIGTYPE_p_zx_str entid, SWIGTYPE_p_zx_str msgid, SWIGTYPE_p_zx_str a7nid, SWIGTYPE_p_zx_str nid, string sigval, string res, string op, string arg, string fmt) {
    int ret = zxidPINVOKE.zxlog(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_timeval.getCPtr(ourts), SWIGTYPE_p_timeval.getCPtr(srcts), ipport, SWIGTYPE_p_zx_str.getCPtr(entid), SWIGTYPE_p_zx_str.getCPtr(msgid), SWIGTYPE_p_zx_str.getCPtr(a7nid), SWIGTYPE_p_zx_str.getCPtr(nid), sigval, res, op, arg, fmt);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ent_from_file(SWIGTYPE_p_zxid_conf cf, string sha1_name) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ent_from_file(SWIGTYPE_p_zxid_conf.getCPtr(cf), sha1_name);
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ent_from_cache(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str eid) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ent_from_cache(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(eid));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static int zxid_write_ent_to_cache(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_entity ent) {
    int ret = zxidPINVOKE.zxid_write_ent_to_cache(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_entity.getCPtr(ent));
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_parse_meta(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_p_char md, string lim) {
    IntPtr cPtr = zxidPINVOKE.zxid_parse_meta(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_p_char.getCPtr(md), lim);
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_meta_ss(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str url) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_meta_ss(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(url));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_meta(SWIGTYPE_p_zxid_conf cf, string url) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_meta(SWIGTYPE_p_zxid_conf.getCPtr(cf), url);
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ent_ss(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str eid) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ent_ss(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(eid));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ent(SWIGTYPE_p_zxid_conf cf, string eid) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ent(SWIGTYPE_p_zxid_conf.getCPtr(cf), eid);
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ent_by_succinct_id(SWIGTYPE_p_zxid_conf cf, string raw_succinct_id) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ent_by_succinct_id(SWIGTYPE_p_zxid_conf.getCPtr(cf), raw_succinct_id);
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ent_by_sha1_name(SWIGTYPE_p_zxid_conf cf, string sha1_name) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ent_by_sha1_name(SWIGTYPE_p_zxid_conf.getCPtr(cf), sha1_name);
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_load_cot_cache(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_load_cot_cache(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_ds_KeyInfo_s zxid_key_info(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_X509 x) {
    IntPtr cPtr = zxidPINVOKE.zxid_key_info(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_X509.getCPtr(x));
    SWIGTYPE_p_zx_ds_KeyInfo_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ds_KeyInfo_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_KeyDescriptor_s zxid_key_desc(SWIGTYPE_p_zxid_conf cf, string use, SWIGTYPE_p_X509 cert) {
    IntPtr cPtr = zxidPINVOKE.zxid_key_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf), use, SWIGTYPE_p_X509.getCPtr(cert));
    SWIGTYPE_p_zx_md_KeyDescriptor_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_KeyDescriptor_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_ArtifactResolutionService_s zxid_ar_desc(SWIGTYPE_p_zxid_conf cf, string binding, string loc, string resp_loc) {
    IntPtr cPtr = zxidPINVOKE.zxid_ar_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    SWIGTYPE_p_zx_md_ArtifactResolutionService_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_ArtifactResolutionService_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_SingleSignOnService_s zxid_sso_desc(SWIGTYPE_p_zxid_conf cf, string binding, string loc, string resp_loc) {
    IntPtr cPtr = zxidPINVOKE.zxid_sso_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    SWIGTYPE_p_zx_md_SingleSignOnService_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_SingleSignOnService_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_SingleLogoutService_s zxid_slo_desc(SWIGTYPE_p_zxid_conf cf, string binding, string loc, string resp_loc) {
    IntPtr cPtr = zxidPINVOKE.zxid_slo_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    SWIGTYPE_p_zx_md_SingleLogoutService_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_SingleLogoutService_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_ManageNameIDService_s zxid_mni_desc(SWIGTYPE_p_zxid_conf cf, string binding, string loc, string resp_loc) {
    IntPtr cPtr = zxidPINVOKE.zxid_mni_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    SWIGTYPE_p_zx_md_ManageNameIDService_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_ManageNameIDService_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_AssertionConsumerService_s zxid_ac_desc(SWIGTYPE_p_zxid_conf cf, string binding, string loc, string index) {
    IntPtr cPtr = zxidPINVOKE.zxid_ac_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf), binding, loc, index);
    SWIGTYPE_p_zx_md_AssertionConsumerService_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_AssertionConsumerService_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_IDPSSODescriptor_s zxid_idp_sso_desc(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_sso_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_md_IDPSSODescriptor_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_IDPSSODescriptor_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_md_SPSSODescriptor_s zxid_sp_sso_desc(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_sso_desc(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_md_SPSSODescriptor_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_md_SPSSODescriptor_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_meta(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_meta(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_send_sp_meta(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    int ret = zxidPINVOKE.zxid_send_sp_meta(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_carml(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_carml(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_my_entity_id(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_my_entity_id(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_my_cdc_url(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_my_cdc_url(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Issuer_s zxid_my_issuer(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_my_issuer(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_sa_Issuer_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Issuer_s(cPtr, false);
    return ret;
  }

  public static void zxid_sha1_file(SWIGTYPE_p_zxid_conf cf, string name, string sha1) {
    zxidPINVOKE.zxid_sha1_file(SWIGTYPE_p_zxid_conf.getCPtr(cf), name, sha1);
  }

  public static SWIGTYPE_p_X509 zxid_extract_cert(string buf, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_extract_cert(buf, name);
    SWIGTYPE_p_X509 ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_X509(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_p_void zxid_extract_private_key(string buf, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_extract_private_key(buf, name);
    SWIGTYPE_p_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_p_void(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_X509 zxid_read_cert(SWIGTYPE_p_zxid_conf cf, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_read_cert(SWIGTYPE_p_zxid_conf.getCPtr(cf), name);
    SWIGTYPE_p_X509 ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_X509(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_p_void zxid_read_private_key(SWIGTYPE_p_zxid_conf cf, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_read_private_key(SWIGTYPE_p_zxid_conf.getCPtr(cf), name);
    SWIGTYPE_p_p_void ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_p_void(cPtr, false);
    return ret;
  }

  public static int zxid_set_opt(SWIGTYPE_p_zxid_conf cf, int which, int val) {
    int ret = zxidPINVOKE.zxid_set_opt(SWIGTYPE_p_zxid_conf.getCPtr(cf), which, val);
    return ret;
  }

  public static string zxid_set_opt_cstr(SWIGTYPE_p_zxid_conf cf, int which, string val) {
    string ret = zxidPINVOKE.zxid_set_opt_cstr(SWIGTYPE_p_zxid_conf.getCPtr(cf), which, val);
    return ret;
  }

  public static void zxid_url_set(SWIGTYPE_p_zxid_conf cf, string url) {
    zxidPINVOKE.zxid_url_set(SWIGTYPE_p_zxid_conf.getCPtr(cf), url);
  }

  public static int zxid_init_conf(SWIGTYPE_p_zxid_conf cf, string conf_dir) {
    int ret = zxidPINVOKE.zxid_init_conf(SWIGTYPE_p_zxid_conf.getCPtr(cf), conf_dir);
    return ret;
  }

  public static SWIGTYPE_p_zxid_conf zxid_init_conf_ctx(SWIGTYPE_p_zxid_conf cf, string zxid_path) {
    IntPtr cPtr = zxidPINVOKE.zxid_init_conf_ctx(SWIGTYPE_p_zxid_conf.getCPtr(cf), zxid_path);
    SWIGTYPE_p_zxid_conf ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_conf(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_conf zxid_new_conf(string zxid_path) {
    IntPtr cPtr = zxidPINVOKE.zxid_new_conf(zxid_path);
    SWIGTYPE_p_zxid_conf ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_conf(cPtr, false);
    return ret;
  }

  public static int zxid_parse_conf_raw(SWIGTYPE_p_zxid_conf cf, int qs_len, string qs) {
    int ret = zxidPINVOKE.zxid_parse_conf_raw(SWIGTYPE_p_zxid_conf.getCPtr(cf), qs_len, qs);
    return ret;
  }

  public static int zxid_parse_conf(SWIGTYPE_p_zxid_conf cf, string qs) {
    int ret = zxidPINVOKE.zxid_parse_conf(SWIGTYPE_p_zxid_conf.getCPtr(cf), qs);
    return ret;
  }

  public static int zxid_mk_self_sig_cert(SWIGTYPE_p_zxid_conf cf, int buflen, string buf, string lk, string name) {
    int ret = zxidPINVOKE.zxid_mk_self_sig_cert(SWIGTYPE_p_zxid_conf.getCPtr(cf), buflen, buf, lk, name);
    return ret;
  }

  public static SWIGTYPE_p_zxid_map zxid_load_map(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_map map, string v) {
    IntPtr cPtr = zxidPINVOKE.zxid_load_map(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_map.getCPtr(map), v);
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_need zxid_load_need(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_need need, string v) {
    IntPtr cPtr = zxidPINVOKE.zxid_load_need(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_need.getCPtr(need), v);
    SWIGTYPE_p_zxid_need ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_atsrc zxid_load_atsrc(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_atsrc atsrc, string v) {
    IntPtr cPtr = zxidPINVOKE.zxid_load_atsrc(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_atsrc.getCPtr(atsrc), v);
    SWIGTYPE_p_zxid_atsrc ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_attr zxid_new_at(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_attr at, int name_len, string name, int val_len, string val, string lk) {
    IntPtr cPtr = zxidPINVOKE.zxid_new_at(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(at), name_len, name, val_len, val, lk);
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_load_cstr_list(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cstr_list lst, string v) {
    IntPtr cPtr = zxidPINVOKE.zxid_load_cstr_list(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cstr_list.getCPtr(lst), v);
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_need zxid_is_needed(SWIGTYPE_p_zxid_need need, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_is_needed(SWIGTYPE_p_zxid_need.getCPtr(need), name);
    SWIGTYPE_p_zxid_need ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_map zxid_find_map(SWIGTYPE_p_zxid_map map, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_find_map(SWIGTYPE_p_zxid_map.getCPtr(map), name);
    SWIGTYPE_p_zxid_map ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_cstr_list zxid_find_cstr_list(SWIGTYPE_p_zxid_cstr_list lst, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_find_cstr_list(SWIGTYPE_p_zxid_cstr_list.getCPtr(lst), name);
    SWIGTYPE_p_zxid_cstr_list ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_attr zxid_find_at(SWIGTYPE_p_zxid_attr pool, string name) {
    IntPtr cPtr = zxidPINVOKE.zxid_find_at(SWIGTYPE_p_zxid_attr.getCPtr(pool), name);
    SWIGTYPE_p_zxid_attr ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_show_conf(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_show_conf(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_parse_cgi(SWIGTYPE_p_zxid_cgi cgi, string qs) {
    int ret = zxidPINVOKE.zxid_parse_cgi(SWIGTYPE_p_zxid_cgi.getCPtr(cgi), qs);
    return ret;
  }

  public static SWIGTYPE_p_zxid_cgi zxid_new_cgi(SWIGTYPE_p_zxid_conf cf, string qs) {
    IntPtr cPtr = zxidPINVOKE.zxid_new_cgi(SWIGTYPE_p_zxid_conf.getCPtr(cf), qs);
    SWIGTYPE_p_zxid_cgi ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_cgi(cPtr, false);
    return ret;
  }

  public static void zxid_get_sid_from_cookie(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, string cookie) {
    zxidPINVOKE.zxid_get_sid_from_cookie(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), cookie);
  }

  public static SWIGTYPE_p_zxid_ses zxid_alloc_ses(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_alloc_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zxid_ses ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_ses(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zxid_ses zxid_fetch_ses(SWIGTYPE_p_zxid_conf cf, string sid) {
    IntPtr cPtr = zxidPINVOKE.zxid_fetch_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), sid);
    SWIGTYPE_p_zxid_ses ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_ses(cPtr, false);
    return ret;
  }

  public static int zxid_get_ses(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string sid) {
    int ret = zxidPINVOKE.zxid_get_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), sid);
    return ret;
  }

  public static int zxid_put_ses(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_put_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static int zxid_del_ses(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_del_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static int zxid_get_ses_sso_a7n(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_get_ses_sso_a7n(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static SWIGTYPE_p_zxid_entity zxid_get_ses_idp(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_ses_idp(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    SWIGTYPE_p_zxid_entity ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
    return ret;
  }

  public static int zxid_find_ses(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_str ses_ix, SWIGTYPE_p_zx_str nid) {
    int ret = zxidPINVOKE.zxid_find_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_str.getCPtr(ses_ix), SWIGTYPE_p_zx_str.getCPtr(nid));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_pool_to_ldif(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_attr pool) {
    IntPtr cPtr = zxidPINVOKE.zxid_pool_to_ldif(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(pool));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_pool_to_json(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_attr pool) {
    IntPtr cPtr = zxidPINVOKE.zxid_pool_to_json(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(pool));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_pool_to_qs(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_attr pool) {
    IntPtr cPtr = zxidPINVOKE.zxid_pool_to_qs(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(pool));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static void zxid_ses_to_pool(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    zxidPINVOKE.zxid_ses_to_pool(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
  }

  public static void zxid_add_attr_to_pool(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string at_name, SWIGTYPE_p_zx_str val) {
    zxidPINVOKE.zxid_add_attr_to_pool(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), at_name, SWIGTYPE_p_zx_str.getCPtr(val));
  }

  public static int zxid_add_qs_to_pool(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string qs, int apply_map) {
    int ret = zxidPINVOKE.zxid_add_qs_to_pool(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), qs, apply_map);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_NameID_s zxid_parse_mni(SWIGTYPE_p_zxid_conf cf, string buf, SWIGTYPE_p_p_char pmniptr) {
    IntPtr cPtr = zxidPINVOKE.zxid_parse_mni(SWIGTYPE_p_zxid_conf.getCPtr(cf), buf, SWIGTYPE_p_p_char.getCPtr(pmniptr));
    SWIGTYPE_p_zx_sa_NameID_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
    return ret;
  }

  public static int zxid_put_user(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str nidfmt, SWIGTYPE_p_zx_str idpent, SWIGTYPE_p_zx_str spqual, SWIGTYPE_p_zx_str idpnid, string mniptr) {
    int ret = zxidPINVOKE.zxid_put_user(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(nidfmt), SWIGTYPE_p_zx_str.getCPtr(idpent), SWIGTYPE_p_zx_str.getCPtr(spqual), SWIGTYPE_p_zx_str.getCPtr(idpnid), mniptr);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_NameID_s zxid_get_user_nameid(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s oldnid) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_user_nameid(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(oldnid));
    SWIGTYPE_p_zx_sa_NameID_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
    return ret;
  }

  public static void zxid_user_change_nameid(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s oldnid, SWIGTYPE_p_zx_str newnym) {
    zxidPINVOKE.zxid_user_change_nameid(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(oldnid), SWIGTYPE_p_zx_str.getCPtr(newnym));
  }

  public static int zxid_pw_authn(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_pw_authn(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static int zxid_version() {
    int ret = zxidPINVOKE.zxid_version();
    return ret;
  }

  public static string zxid_version_str() {
    string ret = zxidPINVOKE.zxid_version_str();
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_date_time(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_time_t secs) {
    IntPtr cPtr = zxidPINVOKE.zxid_date_time(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_time_t.getCPtr(secs));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    if (zxidPINVOKE.SWIGPendingException.Pending) throw zxidPINVOKE.SWIGPendingException.Retrieve();
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_mk_id(SWIGTYPE_p_zxid_conf cf, string prefix, int bits) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_id(SWIGTYPE_p_zxid_conf.getCPtr(cf), prefix, bits);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_soap_call_raw(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str url, SWIGTYPE_p_zx_str data) {
    IntPtr cPtr = zxidPINVOKE.zxid_soap_call_raw(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(url), SWIGTYPE_p_zx_str.getCPtr(data));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_lecp_check(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    IntPtr cPtr = zxidPINVOKE.zxid_lecp_check(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_cdc_read(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    int ret = zxidPINVOKE.zxid_cdc_read(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    return ret;
  }

  public static int zxid_cdc_check(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    int ret = zxidPINVOKE.zxid_cdc_check(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_soap_call_envelope(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str url, SWIGTYPE_p_zx_e_Envelope_s env) {
    IntPtr cPtr = zxidPINVOKE.zxid_soap_call_envelope(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(url), SWIGTYPE_p_zx_e_Envelope_s.getCPtr(env));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_soap_call_hdr_body(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str url, SWIGTYPE_p_zx_e_Header_s hdr, SWIGTYPE_p_zx_e_Body_s body) {
    IntPtr cPtr = zxidPINVOKE.zxid_soap_call_hdr_body(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(url), SWIGTYPE_p_zx_e_Header_s.getCPtr(hdr), SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_soap_call_body(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str url, SWIGTYPE_p_zx_e_Body_s body) {
    IntPtr cPtr = zxidPINVOKE.zxid_soap_call_body(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(url), SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static int zxid_soap_cgi_resp_body(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_e_Body_s body) {
    int ret = zxidPINVOKE.zxid_soap_cgi_resp_body(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_saml2_post_enc(SWIGTYPE_p_zxid_conf cf, string field, SWIGTYPE_p_zx_str payload, string relay_state, int sign, SWIGTYPE_p_zx_str action_url) {
    IntPtr cPtr = zxidPINVOKE.zxid_saml2_post_enc(SWIGTYPE_p_zxid_conf.getCPtr(cf), field, SWIGTYPE_p_zx_str.getCPtr(payload), relay_state, sign, SWIGTYPE_p_zx_str.getCPtr(action_url));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_saml2_redir_enc(SWIGTYPE_p_zxid_conf cf, string cgivar, SWIGTYPE_p_zx_str pay_load, string relay_state) {
    IntPtr cPtr = zxidPINVOKE.zxid_saml2_redir_enc(SWIGTYPE_p_zxid_conf.getCPtr(cf), cgivar, SWIGTYPE_p_zx_str.getCPtr(pay_load), relay_state);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_saml2_redir_url(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str loc, SWIGTYPE_p_zx_str pay_load, string relay_state) {
    IntPtr cPtr = zxidPINVOKE.zxid_saml2_redir_url(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(loc), SWIGTYPE_p_zx_str.getCPtr(pay_load), relay_state);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_saml2_redir(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str loc, SWIGTYPE_p_zx_str pay_load, string relay_state) {
    IntPtr cPtr = zxidPINVOKE.zxid_saml2_redir(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(loc), SWIGTYPE_p_zx_str.getCPtr(pay_load), relay_state);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_saml2_resp_redir(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str loc, SWIGTYPE_p_zx_str pay_load, string relay_state) {
    IntPtr cPtr = zxidPINVOKE.zxid_saml2_resp_redir(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(loc), SWIGTYPE_p_zx_str.getCPtr(pay_load), relay_state);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_saml_ok(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zx_sp_Status_s st, string what) {
    int ret = zxidPINVOKE.zxid_saml_ok(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zx_sp_Status_s.getCPtr(st), what);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_NameID_s zxid_decrypt_nameid(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, SWIGTYPE_p_zx_sa_EncryptedID_s encid) {
    IntPtr cPtr = zxidPINVOKE.zxid_decrypt_nameid(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), SWIGTYPE_p_zx_sa_EncryptedID_s.getCPtr(encid));
    SWIGTYPE_p_zx_sa_NameID_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_decrypt_newnym(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str newnym, SWIGTYPE_p_zx_sp_NewEncryptedID_s encid) {
    IntPtr cPtr = zxidPINVOKE.zxid_decrypt_newnym(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(newnym), SWIGTYPE_p_zx_sp_NewEncryptedID_s.getCPtr(encid));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_chk_sig(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_elem_s elem, SWIGTYPE_p_zx_ds_Signature_s sig, SWIGTYPE_p_zx_sa_Issuer_s issue_ent, string lk) {
    int ret = zxidPINVOKE.zxid_chk_sig(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_elem_s.getCPtr(elem), SWIGTYPE_p_zx_ds_Signature_s.getCPtr(sig), SWIGTYPE_p_zx_sa_Issuer_s.getCPtr(issue_ent), lk);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_map_val(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_map map, SWIGTYPE_p_zx_str val) {
    IntPtr cPtr = zxidPINVOKE.zxid_map_val(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_map.getCPtr(map), SWIGTYPE_p_zx_str.getCPtr(val));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_idp_loc_raw(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity idp_meta, int svc_type, string binding, int req) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_loc_raw(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), svc_type, binding, req);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_idp_loc(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zxid_entity idp_meta, int svc_type, string binding) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_loc(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), svc_type, binding);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_idp_soap(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zxid_entity idp_meta, int svc_type, SWIGTYPE_p_zx_e_Body_s body) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_soap(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), svc_type, SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_loc_by_index_raw(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, SWIGTYPE_p_zx_str ix, SWIGTYPE_p_int binding) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_loc_by_index_raw(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, SWIGTYPE_p_zx_str.getCPtr(ix), SWIGTYPE_p_int.getCPtr(binding));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_loc_raw(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, string binding, int req) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_loc_raw(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, binding, req);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_loc(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, string binding) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_loc(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, binding);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_sp_soap(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, SWIGTYPE_p_zx_e_Body_s body) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_soap(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_root_s zxid_decode_redir_or_post(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    IntPtr cPtr = zxidPINVOKE.zxid_decode_redir_or_post(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    SWIGTYPE_p_zx_root_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_dispatch(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_dispatch(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_sp_soap_dispatch(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_root_s r) {
    int ret = zxidPINVOKE.zxid_sp_soap_dispatch(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_root_s.getCPtr(r));
    return ret;
  }

  public static int zxid_sp_soap_parse(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, int len, string buf) {
    int ret = zxidPINVOKE.zxid_sp_soap_parse(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), len, buf);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s zxid_dec_a7n(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zx_sa_EncryptedAssertion_s enca7n) {
    IntPtr cPtr = zxidPINVOKE.zxid_dec_a7n(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zx_sa_EncryptedAssertion_s.getCPtr(enca7n));
    SWIGTYPE_p_zx_sa_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_idp_dispatch(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_dispatch(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_idp_soap_dispatch(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_root_s r) {
    int ret = zxidPINVOKE.zxid_idp_soap_dispatch(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_root_s.getCPtr(r));
    return ret;
  }

  public static int zxid_idp_soap_parse(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, int len, string buf) {
    int ret = zxidPINVOKE.zxid_idp_soap_parse(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), len, buf);
    return ret;
  }

  public static int zxid_anoint_a7n(SWIGTYPE_p_zxid_conf cf, int sign, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zx_str issued_to, string lk) {
    int ret = zxidPINVOKE.zxid_anoint_a7n(SWIGTYPE_p_zxid_conf.getCPtr(cf), sign, SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zx_str.getCPtr(issued_to), lk);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s zxid_add_ldif_attrs(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_Attribute_s prev, int len, string p, string lk) {
    IntPtr cPtr = zxidPINVOKE.zxid_add_ldif_attrs(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Attribute_s.getCPtr(prev), len, p, lk);
    SWIGTYPE_p_zx_sa_Attribute_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s zxid_gen_bootstraps(SWIGTYPE_p_zxid_conf cf, string uid, string path, SWIGTYPE_p_zx_sa_Attribute_s bootstraps) {
    IntPtr cPtr = zxidPINVOKE.zxid_gen_bootstraps(SWIGTYPE_p_zxid_conf.getCPtr(cf), uid, path, SWIGTYPE_p_zx_sa_Attribute_s.getCPtr(bootstraps));
    SWIGTYPE_p_zx_sa_Attribute_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s zxid_mk_user_a7n_to_sp(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string uid, SWIGTYPE_p_zx_sa_NameID_s nameid, SWIGTYPE_p_zxid_entity sp_meta, string sp_name_buf, int add_bs) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_user_a7n_to_sp(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), uid, SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nameid), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), sp_name_buf, add_bs);
    SWIGTYPE_p_zx_sa_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_NameID_s zxid_check_fed(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str affil, string uid, char allow_create, SWIGTYPE_p_timeval srcts, SWIGTYPE_p_zx_str issuer, SWIGTYPE_p_zx_str req_id, string sp_name_buf) {
    IntPtr cPtr = zxidPINVOKE.zxid_check_fed(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(affil), uid, allow_create, SWIGTYPE_p_timeval.getCPtr(srcts), SWIGTYPE_p_zx_str.getCPtr(issuer), SWIGTYPE_p_zx_str.getCPtr(req_id), sp_name_buf);
    SWIGTYPE_p_zx_sa_NameID_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
    return ret;
  }

  public static string zxid_add_fed_tok_to_epr(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_a_EndpointReference_s epr, string uid) {
    string ret = zxidPINVOKE.zxid_add_fed_tok_to_epr(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr), uid);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_idp_sso(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sp_AuthnRequest_s ar) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_sso(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_AuthnRequest_s.getCPtr(ar));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_as_SASLResponse_s zxid_idp_as_do(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_as_SASLRequest_s req) {
    IntPtr cPtr = zxidPINVOKE.zxid_idp_as_do(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_as_SASLRequest_s.getCPtr(req));
    SWIGTYPE_p_zx_as_SASLResponse_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_as_SASLResponse_s(cPtr, false);
    return ret;
  }

  public static int zxid_pick_sso_profile(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity idp_met) {
    int ret = zxidPINVOKE.zxid_pick_sso_profile(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(idp_met));
    return ret;
  }

  public static int zxid_start_sso(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    int ret = zxidPINVOKE.zxid_start_sso(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_start_sso_url(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    IntPtr cPtr = zxidPINVOKE.zxid_start_sso_url(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_start_sso_location(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    IntPtr cPtr = zxidPINVOKE.zxid_start_sso_location(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_sp_deref_art(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_sp_deref_art(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static int zxid_sp_sso_finalize(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sa_Assertion_s a7n) {
    int ret = zxidPINVOKE.zxid_sp_sso_finalize(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n));
    return ret;
  }

  public static int zxid_sp_anon_finalize(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_sp_anon_finalize(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static string zxid_saml2_map_nid_fmt(string f) {
    string ret = zxidPINVOKE.zxid_saml2_map_nid_fmt(f);
    return ret;
  }

  public static string zxid_saml2_map_protocol_binding(string b) {
    string ret = zxidPINVOKE.zxid_saml2_map_protocol_binding(b);
    return ret;
  }

  public static int zxid_protocol_binding_map_saml2(SWIGTYPE_p_zx_str b) {
    int ret = zxidPINVOKE.zxid_protocol_binding_map_saml2(SWIGTYPE_p_zx_str.getCPtr(b));
    return ret;
  }

  public static string zxid_saml2_map_authn_ctx(string c) {
    string ret = zxidPINVOKE.zxid_saml2_map_authn_ctx(c);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Issuer_s zxid_issuer(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str nameid, string affiliation) {
    IntPtr cPtr = zxidPINVOKE.zxid_issuer(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(nameid), affiliation);
    SWIGTYPE_p_zx_sa_Issuer_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Issuer_s(cPtr, false);
    return ret;
  }

  public static void zxid_sigres_map(int sigres, SWIGTYPE_p_p_char sigval, SWIGTYPE_p_p_char sigmsg) {
    zxidPINVOKE.zxid_sigres_map(sigres, SWIGTYPE_p_p_char.getCPtr(sigval), SWIGTYPE_p_p_char.getCPtr(sigmsg));
  }

  public static int zxid_validate_cond(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zx_str myentid, SWIGTYPE_p_timeval ourts, SWIGTYPE_p_p_char err) {
    int ret = zxidPINVOKE.zxid_validate_cond(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zx_str.getCPtr(myentid), SWIGTYPE_p_timeval.getCPtr(ourts), SWIGTYPE_p_p_char.getCPtr(err));
    return ret;
  }

  public static int zxid_sp_slo_soap(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_sp_slo_soap(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_slo_redir(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_slo_redir(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_sp_slo_do(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sp_LogoutRequest_s req) {
    int ret = zxidPINVOKE.zxid_sp_slo_do(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_LogoutRequest_s.getCPtr(req));
    return ret;
  }

  public static int zxid_idp_slo_do(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sp_LogoutRequest_s req) {
    int ret = zxidPINVOKE.zxid_idp_slo_do(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_LogoutRequest_s.getCPtr(req));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_slo_resp_redir(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zx_sp_LogoutRequest_s req) {
    IntPtr cPtr = zxidPINVOKE.zxid_slo_resp_redir(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zx_sp_LogoutRequest_s.getCPtr(req));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_sp_mni_soap(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_str new_nym) {
    int ret = zxidPINVOKE.zxid_sp_mni_soap(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_str.getCPtr(new_nym));
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_sp_mni_redir(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_str new_nym) {
    IntPtr cPtr = zxidPINVOKE.zxid_sp_mni_redir(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_str.getCPtr(new_nym));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_ManageNameIDResponse_s zxid_mni_do(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sp_ManageNameIDRequest_s mni) {
    IntPtr cPtr = zxidPINVOKE.zxid_mni_do(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_ManageNameIDRequest_s.getCPtr(mni));
    SWIGTYPE_p_zx_sp_ManageNameIDResponse_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_ManageNameIDResponse_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_mni_do_ss(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_sp_ManageNameIDRequest_s mni, SWIGTYPE_p_zx_str loc) {
    IntPtr cPtr = zxidPINVOKE.zxid_mni_do_ss(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_ManageNameIDRequest_s.getCPtr(mni), SWIGTYPE_p_zx_str.getCPtr(loc));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_pep_az_soap(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_ses ses, string pdp_url) {
    int ret = zxidPINVOKE.zxid_pep_az_soap(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_ses.getCPtr(ses), pdp_url);
    return ret;
  }

  public static int zxid_az_cf_ses(SWIGTYPE_p_zxid_conf cf, string qs, SWIGTYPE_p_zxid_ses ses) {
    int ret = zxidPINVOKE.zxid_az_cf_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), qs, SWIGTYPE_p_zxid_ses.getCPtr(ses));
    return ret;
  }

  public static int zxid_az_cf(SWIGTYPE_p_zxid_conf cf, string qs, string sid) {
    int ret = zxidPINVOKE.zxid_az_cf(SWIGTYPE_p_zxid_conf.getCPtr(cf), qs, sid);
    return ret;
  }

  public static int zxid_az(string conf, string qs, string sid) {
    int ret = zxidPINVOKE.zxid_az(conf, qs, sid);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s zxid_find_attribute(SWIGTYPE_p_zx_sa_Assertion_s a7n, int nfmt_len, string nfmt, int name_len, string name, int friendly_len, string friendly, int n) {
    IntPtr cPtr = zxidPINVOKE.zxid_find_attribute(SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), nfmt_len, nfmt, name_len, name, friendly_len, friendly, n);
    SWIGTYPE_p_zx_sa_Attribute_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_AuthnRequest_s zxid_mk_authn_req(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_authn_req(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    SWIGTYPE_p_zx_sp_AuthnRequest_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_AuthnRequest_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_ArtifactResolve_s zxid_mk_art_deref(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_entity idp_meta, string artifact) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_art_deref(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), artifact);
    SWIGTYPE_p_zx_sp_ArtifactResolve_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_ArtifactResolve_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_Status_s zxid_mk_Status(SWIGTYPE_p_zxid_conf cf, string sc1, string sc2, string msg) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_Status(SWIGTYPE_p_zxid_conf.getCPtr(cf), sc1, sc2, msg);
    SWIGTYPE_p_zx_sp_Status_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_Status_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_Status_s zxid_OK(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_OK(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_sp_Status_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_Status_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_EncryptedID_s zxid_mk_enc_id(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, SWIGTYPE_p_zxid_entity meta) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_enc_id(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), SWIGTYPE_p_zxid_entity.getCPtr(meta));
    SWIGTYPE_p_zx_sa_EncryptedID_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_EncryptedID_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_EncryptedAssertion_s zxid_mk_enc_a7n(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zxid_entity meta) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_enc_a7n(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zxid_entity.getCPtr(meta));
    SWIGTYPE_p_zx_sa_EncryptedAssertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_EncryptedAssertion_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_LogoutRequest_s zxid_mk_logout(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, SWIGTYPE_p_zx_str ses_ix, SWIGTYPE_p_zxid_entity idp) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_logout(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), SWIGTYPE_p_zx_str.getCPtr(ses_ix), SWIGTYPE_p_zxid_entity.getCPtr(idp));
    SWIGTYPE_p_zx_sp_LogoutRequest_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_LogoutRequest_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_LogoutResponse_s zxid_mk_logout_resp(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sp_Status_s st, SWIGTYPE_p_zx_str req_id) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_logout_resp(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sp_Status_s.getCPtr(st), SWIGTYPE_p_zx_str.getCPtr(req_id));
    SWIGTYPE_p_zx_sp_LogoutResponse_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_LogoutResponse_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_ManageNameIDRequest_s zxid_mk_mni(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, SWIGTYPE_p_zx_str new_nym, SWIGTYPE_p_zxid_entity idp) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_mni(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), SWIGTYPE_p_zx_str.getCPtr(new_nym), SWIGTYPE_p_zxid_entity.getCPtr(idp));
    SWIGTYPE_p_zx_sp_ManageNameIDRequest_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_ManageNameIDRequest_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_ManageNameIDResponse_s zxid_mk_mni_resp(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sp_Status_s st, SWIGTYPE_p_zx_str req_id) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_mni_resp(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sp_Status_s.getCPtr(st), SWIGTYPE_p_zx_str.getCPtr(req_id));
    SWIGTYPE_p_zx_sp_ManageNameIDResponse_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_ManageNameIDResponse_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s zxid_mk_a7n(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str audience, SWIGTYPE_p_zx_sa_Subject_s subj, SWIGTYPE_p_zx_sa_AuthnStatement_s an_stmt, SWIGTYPE_p_zx_sa_AttributeStatement_s at_stmt, SWIGTYPE_p_zx_xasa_XACMLAuthzDecisionStatement_s az_stmt) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_a7n(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(audience), SWIGTYPE_p_zx_sa_Subject_s.getCPtr(subj), SWIGTYPE_p_zx_sa_AuthnStatement_s.getCPtr(an_stmt), SWIGTYPE_p_zx_sa_AttributeStatement_s.getCPtr(at_stmt), SWIGTYPE_p_zx_xasa_XACMLAuthzDecisionStatement_s.getCPtr(az_stmt));
    SWIGTYPE_p_zx_sa_Assertion_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Subject_s zxid_mk_subj(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_entity sp_meta, SWIGTYPE_p_zx_sa_NameID_s nid) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_subj(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid));
    SWIGTYPE_p_zx_sa_Subject_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Subject_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_AuthnStatement_s zxid_mk_an_stmt(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_an_stmt(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
    SWIGTYPE_p_zx_sa_AuthnStatement_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_AuthnStatement_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sp_Response_s zxid_mk_saml_resp(SWIGTYPE_p_zxid_conf cf) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_saml_resp(SWIGTYPE_p_zxid_conf.getCPtr(cf));
    SWIGTYPE_p_zx_sp_Response_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sp_Response_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_xac_Response_s zxid_mk_xacml_resp(SWIGTYPE_p_zxid_conf cf, string decision) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_xacml_resp(SWIGTYPE_p_zxid_conf.getCPtr(cf), decision);
    SWIGTYPE_p_zx_xac_Response_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_xac_Response_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_xac_Attribute_s zxid_mk_xacml_simple_at(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_xac_Attribute_s aa, SWIGTYPE_p_zx_str atid, SWIGTYPE_p_zx_str attype, SWIGTYPE_p_zx_str atissuer, SWIGTYPE_p_zx_str atvalue) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_xacml_simple_at(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(aa), SWIGTYPE_p_zx_str.getCPtr(atid), SWIGTYPE_p_zx_str.getCPtr(attype), SWIGTYPE_p_zx_str.getCPtr(atissuer), SWIGTYPE_p_zx_str.getCPtr(atvalue));
    SWIGTYPE_p_zx_xac_Attribute_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_xac_Attribute_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_xasp_XACMLAuthzDecisionQuery_s zxid_mk_az(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_xac_Attribute_s subj, SWIGTYPE_p_zx_xac_Attribute_s rsrc, SWIGTYPE_p_zx_xac_Attribute_s act, SWIGTYPE_p_zx_xac_Attribute_s env) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_az(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(subj), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(rsrc), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(act), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(env));
    SWIGTYPE_p_zx_xasp_XACMLAuthzDecisionQuery_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_xasp_XACMLAuthzDecisionQuery_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_xaspcd1_XACMLAuthzDecisionQuery_s zxid_mk_az_cd1(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_xac_Attribute_s subj, SWIGTYPE_p_zx_xac_Attribute_s rsrc, SWIGTYPE_p_zx_xac_Attribute_s act, SWIGTYPE_p_zx_xac_Attribute_s env) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_az_cd1(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(subj), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(rsrc), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(act), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(env));
    SWIGTYPE_p_zx_xaspcd1_XACMLAuthzDecisionQuery_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_xaspcd1_XACMLAuthzDecisionQuery_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s zxid_mk_attribute(SWIGTYPE_p_zxid_conf cf, string name, string val) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_attribute(SWIGTYPE_p_zxid_conf.getCPtr(cf), name, val);
    SWIGTYPE_p_zx_sa_Attribute_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_lu_Status_s zxid_mk_lu_Status(SWIGTYPE_p_zxid_conf cf, string sc1, string sc2, string msg, string arg4) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_lu_Status(SWIGTYPE_p_zxid_conf.getCPtr(cf), sc1, sc2, msg, arg4);
    SWIGTYPE_p_zx_lu_Status_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_lu_Status_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_di_Query_s zxid_mk_di_query(SWIGTYPE_p_zxid_conf cf, string svc_type, string url, string di_opt, string action) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_di_query(SWIGTYPE_p_zxid_conf.getCPtr(cf), svc_type, url, di_opt, action);
    SWIGTYPE_p_zx_di_Query_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_di_Query_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_a_Address_s zxid_mk_addr(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_str url) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_addr(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_str.getCPtr(url));
    SWIGTYPE_p_zx_a_Address_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_a_Address_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_Select_s zxid_mk_dap_select(SWIGTYPE_p_zxid_conf cf, string dn, string filter, string attributes, int deref_aliases, int scope, int sizelimit, int timelimit, int typesonly) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_select(SWIGTYPE_p_zxid_conf.getCPtr(cf), dn, filter, attributes, deref_aliases, scope, sizelimit, timelimit, typesonly);
    SWIGTYPE_p_zx_dap_Select_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_Select_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_QueryItem_s zxid_mk_dap_query_item(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_dap_Select_s sel, string objtype, string predef, string sort, string changed_since, int incl_common_attrs, int offset, int count, string setreq, string setid, string contingent_itemidref) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_query_item(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_Select_s.getCPtr(sel), objtype, predef, sort, changed_since, incl_common_attrs, offset, count, setreq, setid, contingent_itemidref);
    SWIGTYPE_p_zx_dap_QueryItem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_QueryItem_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_TestOp_s zxid_mk_dap_testop(SWIGTYPE_p_zxid_conf cf, string dn, string filter, string attributes, int deref_aliases, int scope, int sizelimit, int timelimit, int typesonly) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_testop(SWIGTYPE_p_zxid_conf.getCPtr(cf), dn, filter, attributes, deref_aliases, scope, sizelimit, timelimit, typesonly);
    SWIGTYPE_p_zx_dap_TestOp_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_TestOp_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_TestItem_s zxid_mk_dap_test_item(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_dap_TestOp_s top, string objtype, string predef) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_test_item(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_TestOp_s.getCPtr(top), objtype, predef);
    SWIGTYPE_p_zx_dap_TestItem_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_TestItem_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_ResultQuery_s zxid_mk_dap_resquery(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_dap_Select_s sel, string objtype, string predef, string sort, string changed_since, int incl_common_attr, string contingent_itemidref) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_resquery(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_Select_s.getCPtr(sel), objtype, predef, sort, changed_since, incl_common_attr, contingent_itemidref);
    SWIGTYPE_p_zx_dap_ResultQuery_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_ResultQuery_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_Subscription_s zxid_mk_dap_subscription(SWIGTYPE_p_zxid_conf cf, string subsID, string itemidref, SWIGTYPE_p_zx_dap_ResultQuery_s rq, string aggreg, string trig, string starts, string expires, int incl_data, string admin_notif, string notify_ref) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_subscription(SWIGTYPE_p_zxid_conf.getCPtr(cf), subsID, itemidref, SWIGTYPE_p_zx_dap_ResultQuery_s.getCPtr(rq), aggreg, trig, starts, expires, incl_data, admin_notif, notify_ref);
    SWIGTYPE_p_zx_dap_Subscription_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_Subscription_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_dap_Query_s zxid_mk_dap_query(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_dap_TestItem_s tis, SWIGTYPE_p_zx_dap_QueryItem_s qis, SWIGTYPE_p_zx_dap_Subscription_s subs) {
    IntPtr cPtr = zxidPINVOKE.zxid_mk_dap_query(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_TestItem_s.getCPtr(tis), SWIGTYPE_p_zx_dap_QueryItem_s.getCPtr(qis), SWIGTYPE_p_zx_dap_Subscription_s.getCPtr(subs));
    SWIGTYPE_p_zx_dap_Query_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_dap_Query_s(cPtr, false);
    return ret;
  }

  public static string zxid_wsp_validate(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string az_cred, string enve) {
    string ret = zxidPINVOKE.zxid_wsp_validate(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), az_cred, enve);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_wsp_decorate(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string az_cred, string enve) {
    IntPtr cPtr = zxidPINVOKE.zxid_wsp_decorate(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), az_cred, enve);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_wsp_decoratef(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string az_cred, string env_f) {
    IntPtr cPtr = zxidPINVOKE.zxid_wsp_decoratef(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), az_cred, env_f);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_e_Envelope_s zxid_wsf_decor(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_e_Envelope_s env) {
    IntPtr cPtr = zxidPINVOKE.zxid_wsf_decor(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_e_Envelope_s.getCPtr(env));
    SWIGTYPE_p_zx_e_Envelope_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_e_Envelope_s(cPtr, false);
    return ret;
  }

  public static int zxid_map_sec_mech(SWIGTYPE_p_zx_a_EndpointReference_s epr) {
    int ret = zxidPINVOKE.zxid_map_sec_mech(SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr));
    return ret;
  }

  public static SWIGTYPE_p_zx_e_Envelope_s zxid_wsc_call(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_a_EndpointReference_s epr, SWIGTYPE_p_zx_e_Envelope_s env) {
    IntPtr cPtr = zxidPINVOKE.zxid_wsc_call(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr), SWIGTYPE_p_zx_e_Envelope_s.getCPtr(env));
    SWIGTYPE_p_zx_e_Envelope_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_e_Envelope_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_call(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string svctype, string url, string di_opt, string az_cred, string enve) {
    IntPtr cPtr = zxidPINVOKE.zxid_call(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), svctype, url, di_opt, az_cred, enve);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_callf(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string svctype, string url, string di_opt, string az_cred, string env_f) {
    IntPtr cPtr = zxidPINVOKE.zxid_callf(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), svctype, url, di_opt, az_cred, env_f);
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static int zxid_nice_sha1(SWIGTYPE_p_zxid_conf cf, string buf, int buf_len, SWIGTYPE_p_zx_str name, SWIGTYPE_p_zx_str contint, int ign_prefix) {
    int ret = zxidPINVOKE.zxid_nice_sha1(SWIGTYPE_p_zxid_conf.getCPtr(cf), buf, buf_len, SWIGTYPE_p_zx_str.getCPtr(name), SWIGTYPE_p_zx_str.getCPtr(contint), ign_prefix);
    return ret;
  }

  public static void zxid_fold_svc(string path, int len) {
    zxidPINVOKE.zxid_fold_svc(path, len);
  }

  public static int zxid_epr_path(SWIGTYPE_p_zxid_conf cf, string dir, string sid, string buf, int buf_len, SWIGTYPE_p_zx_str svc, SWIGTYPE_p_zx_str cont) {
    int ret = zxidPINVOKE.zxid_epr_path(SWIGTYPE_p_zxid_conf.getCPtr(cf), dir, sid, buf, buf_len, SWIGTYPE_p_zx_str.getCPtr(svc), SWIGTYPE_p_zx_str.getCPtr(cont));
    return ret;
  }

  public static SWIGTYPE_p_zx_a_EndpointReference_s zxid_get_epr(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string svc, string url, string di_opt, string action, int n) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_epr(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), svc, url, di_opt, action, n);
    SWIGTYPE_p_zx_a_EndpointReference_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_a_EndpointReference_s(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_a_EndpointReference_s zxid_find_epr(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, string svc, string url, string di_opt, string action, int n) {
    IntPtr cPtr = zxidPINVOKE.zxid_find_epr(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), svc, url, di_opt, action, n);
    SWIGTYPE_p_zx_a_EndpointReference_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_a_EndpointReference_s(cPtr, false);
    return ret;
  }

  public static int zxid_cache_epr(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses, SWIGTYPE_p_zx_a_EndpointReference_s epr) {
    int ret = zxidPINVOKE.zxid_cache_epr(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr));
    return ret;
  }

  public static void zxid_snarf_eprs_from_ses(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zxid_ses ses) {
    zxidPINVOKE.zxid_snarf_eprs_from_ses(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_ses.getCPtr(ses));
  }

  public static SWIGTYPE_p_zx_str zxid_get_epr_address(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_a_EndpointReference_s epr) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_epr_address(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_str zxid_get_epr_entid(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_a_EndpointReference_s epr) {
    IntPtr cPtr = zxidPINVOKE.zxid_get_epr_entid(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr));
    SWIGTYPE_p_zx_str ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_str(cPtr, false);
    return ret;
  }

  public static SWIGTYPE_p_zx_di_QueryResponse_s zxid_di_query(SWIGTYPE_p_zxid_conf cf, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zx_di_Query_s req) {
    IntPtr cPtr = zxidPINVOKE.zxid_di_query(SWIGTYPE_p_zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zx_di_Query_s.getCPtr(req));
    SWIGTYPE_p_zx_di_QueryResponse_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_di_QueryResponse_s(cPtr, false);
    return ret;
  }

  public static void std_basis_64_set(string value) {
    zxidPINVOKE.std_basis_64_set(value);
  }

  public static string std_basis_64_get() {
    string ret = zxidPINVOKE.std_basis_64_get();
    return ret;
  }

  public static void safe_basis_64_set(string value) {
    zxidPINVOKE.safe_basis_64_set(value);
  }

  public static string safe_basis_64_get() {
    string ret = zxidPINVOKE.safe_basis_64_get();
    return ret;
  }

  public static void zx_std_index_64_set(SWIGTYPE_p_unsigned_char value) {
    zxidPINVOKE.zx_std_index_64_set(SWIGTYPE_p_unsigned_char.getCPtr(value));
  }

  public static SWIGTYPE_p_unsigned_char zx_std_index_64_get() {
    IntPtr cPtr = zxidPINVOKE.zx_std_index_64_get();
    SWIGTYPE_p_unsigned_char ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_unsigned_char(cPtr, false);
    return ret;
  }

  public static string base64_fancy_raw(string p, int len, string r, string basis_64, int line_len, int eol_len, string eol, char eq_pad) {
    string ret = zxidPINVOKE.base64_fancy_raw(p, len, r, basis_64, line_len, eol_len, eol, eq_pad);
    return ret;
  }

  public static string unbase64_raw(string p, string lim, string r, SWIGTYPE_p_unsigned_char index_64) {
    string ret = zxidPINVOKE.unbase64_raw(p, lim, r, SWIGTYPE_p_unsigned_char.getCPtr(index_64));
    return ret;
  }

  public static string sha1_safe_base64(string out_buf, int len, string data) {
    string ret = zxidPINVOKE.sha1_safe_base64(out_buf, len, data);
    return ret;
  }

  public static string zx_zlib_raw_deflate(SWIGTYPE_p_zx_ctx c, int in_len, string arg2, SWIGTYPE_p_int out_len) {
    string ret = zxidPINVOKE.zx_zlib_raw_deflate(SWIGTYPE_p_zx_ctx.getCPtr(c), in_len, arg2, SWIGTYPE_p_int.getCPtr(out_len));
    return ret;
  }

  public static string zx_zlib_raw_inflate(SWIGTYPE_p_zx_ctx c, int in_len, string arg2, SWIGTYPE_p_int out_len) {
    string ret = zxidPINVOKE.zx_zlib_raw_inflate(SWIGTYPE_p_zx_ctx.getCPtr(c), in_len, arg2, SWIGTYPE_p_int.getCPtr(out_len));
    return ret;
  }

  public static int zx_url_encode_len(int in_len, string arg1) {
    int ret = zxidPINVOKE.zx_url_encode_len(in_len, arg1);
    return ret;
  }

  public static string zx_url_encode_raw(int in_len, string arg1, string arg2) {
    string ret = zxidPINVOKE.zx_url_encode_raw(in_len, arg1, arg2);
    return ret;
  }

  public static string zx_url_encode(SWIGTYPE_p_zx_ctx c, int in_len, string arg2, SWIGTYPE_p_int out_len) {
    string ret = zxidPINVOKE.zx_url_encode(SWIGTYPE_p_zx_ctx.getCPtr(c), in_len, arg2, SWIGTYPE_p_int.getCPtr(out_len));
    return ret;
  }

  public static void hex_trans_set(SWIGTYPE_p_unsigned_char value) {
    zxidPINVOKE.hex_trans_set(SWIGTYPE_p_unsigned_char.getCPtr(value));
  }

  public static SWIGTYPE_p_unsigned_char hex_trans_get() {
    IntPtr cPtr = zxidPINVOKE.hex_trans_get();
    SWIGTYPE_p_unsigned_char ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_unsigned_char(cPtr, false);
    return ret;
  }

  public static void ykmodhex_trans_set(SWIGTYPE_p_unsigned_char value) {
    zxidPINVOKE.ykmodhex_trans_set(SWIGTYPE_p_unsigned_char.getCPtr(value));
  }

  public static SWIGTYPE_p_unsigned_char ykmodhex_trans_get() {
    IntPtr cPtr = zxidPINVOKE.ykmodhex_trans_get();
    SWIGTYPE_p_unsigned_char ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_unsigned_char(cPtr, false);
    return ret;
  }

  public static string zx_hexdec(string dst, string src, int len, SWIGTYPE_p_unsigned_char trans) {
    string ret = zxidPINVOKE.zx_hexdec(dst, src, len, SWIGTYPE_p_unsigned_char.getCPtr(trans));
    return ret;
  }

  public static int read_all(int maxlen, string buf, string logkey, string name_fmt) {
    int ret = zxidPINVOKE.read_all(maxlen, buf, logkey, name_fmt);
    return ret;
  }

  public static int name_from_path(string buf, int buf_len, string name_fmt) {
    int ret = zxidPINVOKE.name_from_path(buf, buf_len, name_fmt);
    return ret;
  }

  public static SWIGTYPE_p_fdtype open_fd_from_path(int flags, int mode, string logkey, string name_fmt) {
    SWIGTYPE_p_fdtype ret = new SWIGTYPE_p_fdtype(zxidPINVOKE.open_fd_from_path(flags, mode, logkey, name_fmt), true);
    return ret;
  }

  public static int read_all_fd(SWIGTYPE_p_fdtype fd, string p, int want, SWIGTYPE_p_int got_all) {
    int ret = zxidPINVOKE.read_all_fd(SWIGTYPE_p_fdtype.getCPtr(fd), p, want, SWIGTYPE_p_int.getCPtr(got_all));
    if (zxidPINVOKE.SWIGPendingException.Pending) throw zxidPINVOKE.SWIGPendingException.Retrieve();
    return ret;
  }

  public static int write_all_fd(SWIGTYPE_p_fdtype fd, string p, int pending) {
    int ret = zxidPINVOKE.write_all_fd(SWIGTYPE_p_fdtype.getCPtr(fd), p, pending);
    if (zxidPINVOKE.SWIGPendingException.Pending) throw zxidPINVOKE.SWIGPendingException.Retrieve();
    return ret;
  }

  public static int write_all_path_fmt(string logkey, int len, string buf, string path_fmt, string prepath, string postpath, string data_fmt) {
    int ret = zxidPINVOKE.write_all_path_fmt(logkey, len, buf, path_fmt, prepath, postpath, data_fmt);
    return ret;
  }

  public static int close_file(SWIGTYPE_p_fdtype fd, string logkey) {
    int ret = zxidPINVOKE.close_file(SWIGTYPE_p_fdtype.getCPtr(fd), logkey);
    if (zxidPINVOKE.SWIGPendingException.Pending) throw zxidPINVOKE.SWIGPendingException.Retrieve();
    return ret;
  }

  public static void zxid_curl_ctx_p_set(SWIGTYPE_p_zxid_curl_ctx self, string value) {
    zxidPINVOKE.zxid_curl_ctx_p_set(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self), value);
  }

  public static string zxid_curl_ctx_p_get(SWIGTYPE_p_zxid_curl_ctx self) {
    string ret = zxidPINVOKE.zxid_curl_ctx_p_get(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self));
    return ret;
  }

  public static void zxid_curl_ctx_lim_set(SWIGTYPE_p_zxid_curl_ctx self, string value) {
    zxidPINVOKE.zxid_curl_ctx_lim_set(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self), value);
  }

  public static string zxid_curl_ctx_lim_get(SWIGTYPE_p_zxid_curl_ctx self) {
    string ret = zxidPINVOKE.zxid_curl_ctx_lim_get(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self));
    return ret;
  }

  public static SWIGTYPE_p_zxid_curl_ctx new_zxid_curl_ctx() {
    IntPtr cPtr = zxidPINVOKE.new_zxid_curl_ctx();
    SWIGTYPE_p_zxid_curl_ctx ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zxid_curl_ctx(cPtr, true);
    return ret;
  }

  public static void delete_zxid_curl_ctx(SWIGTYPE_p_zxid_curl_ctx self) {
    zxidPINVOKE.delete_zxid_curl_ctx(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self));
  }

  public static uint zxid_curl_write_data(SWIGTYPE_p_void buffer, uint size, uint nmemb, SWIGTYPE_p_void userp) {
    uint ret = zxidPINVOKE.zxid_curl_write_data(SWIGTYPE_p_void.getCPtr(buffer), size, nmemb, SWIGTYPE_p_void.getCPtr(userp));
    return ret;
  }

  public static uint zxid_curl_read_data(SWIGTYPE_p_void buffer, uint size, uint nmemb, SWIGTYPE_p_void userp) {
    uint ret = zxidPINVOKE.zxid_curl_read_data(SWIGTYPE_p_void.getCPtr(buffer), size, nmemb, SWIGTYPE_p_void.getCPtr(userp));
    return ret;
  }

  public static void zx_ns_tab_set(SWIGTYPE_p_zx_ns_s value) {
    zxidPINVOKE.zx_ns_tab_set(SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_tab_get() {
    IntPtr cPtr = zxidPINVOKE.zx_ns_tab_get();
    SWIGTYPE_p_zx_ns_s ret = (cPtr == IntPtr.Zero) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
    return ret;
  }

  public static readonly int ZXERR_EOF = zxidPINVOKE.ZXERR_EOF_get();
  public static readonly int ZXERR_MISMATCH_CLOSE = zxidPINVOKE.ZXERR_MISMATCH_CLOSE_get();
  public static readonly int ZXERR_BAD_ATTR_NS = zxidPINVOKE.ZXERR_BAD_ATTR_NS_get();
  public static readonly int ZXERR_BAD_ELEM_NS = zxidPINVOKE.ZXERR_BAD_ELEM_NS_get();
  public static readonly int ZXERR_MISSING_ATTR = zxidPINVOKE.ZXERR_MISSING_ATTR_get();
  public static readonly int ZXERR_EXTRA_ATTR = zxidPINVOKE.ZXERR_EXTRA_ATTR_get();
  public static readonly int ZXERR_MISSING_ELEM = zxidPINVOKE.ZXERR_MISSING_ELEM_get();
  public static readonly int ZXERR_EXTRA_ELEM = zxidPINVOKE.ZXERR_EXTRA_ELEM_get();
  public static readonly int ZXERR_ELEM_ORDER = zxidPINVOKE.ZXERR_ELEM_ORDER_get();
  public static readonly int ZXERR_BAD_NS_PREFIX = zxidPINVOKE.ZXERR_BAD_NS_PREFIX_get();
  public static readonly int ZXERR_TAG_NOT_CLOSED = zxidPINVOKE.ZXERR_TAG_NOT_CLOSED_get();
  public static readonly int ZXERR_MASK = zxidPINVOKE.ZXERR_MASK_get();
  public static readonly int ZXERR_ATTR_FLAG = zxidPINVOKE.ZXERR_ATTR_FLAG_get();
  public static readonly int ZX_TOK_XMLNS = zxidPINVOKE.ZX_TOK_XMLNS_get();
  public static readonly int ZX_TOK_DATA = zxidPINVOKE.ZX_TOK_DATA_get();
  public static readonly int ZX_TOK_NOT_FOUND = zxidPINVOKE.ZX_TOK_NOT_FOUND_get();
  public static readonly string SIG_ALGO_RSA_SHA1 = zxidPINVOKE.SIG_ALGO_RSA_SHA1_get();
  public static readonly string SIG_ALGO_DSA_SHA1 = zxidPINVOKE.SIG_ALGO_DSA_SHA1_get();
  public static readonly string SIG_ALGO = zxidPINVOKE.SIG_ALGO_get();
  public static readonly string DIGEST_ALGO = zxidPINVOKE.DIGEST_ALGO_get();
  public static readonly string CANON_ALGO = zxidPINVOKE.CANON_ALGO_get();
  public static readonly string ENVELOPED_ALGO = zxidPINVOKE.ENVELOPED_ALGO_get();
  public static readonly string ENC_ALGO_TRIPLEDES_CBC = zxidPINVOKE.ENC_ALGO_TRIPLEDES_CBC_get();
  public static readonly string ENC_ALGO_AES128_CBC = zxidPINVOKE.ENC_ALGO_AES128_CBC_get();
  public static readonly string ENC_ALGO_AES192_CBC = zxidPINVOKE.ENC_ALGO_AES192_CBC_get();
  public static readonly string ENC_ALGO_AES256_CBC = zxidPINVOKE.ENC_ALGO_AES256_CBC_get();
  public static readonly string ENC_ALGO = zxidPINVOKE.ENC_ALGO_get();
  public static readonly string ENC_KEYTRAN_RSA_1_5 = zxidPINVOKE.ENC_KEYTRAN_RSA_1_5_get();
  public static readonly string ENC_KEYTRAN_RSA_OAEP = zxidPINVOKE.ENC_KEYTRAN_RSA_OAEP_get();
  public static readonly string ENC_KEYTRAN_ALGO = zxidPINVOKE.ENC_KEYTRAN_ALGO_get();
  public static readonly string ENC_ENCKEY_METH = zxidPINVOKE.ENC_ENCKEY_METH_get();
  public static readonly string ENC_TYPE_ELEMENT = zxidPINVOKE.ENC_TYPE_ELEMENT_get();
  public static readonly string ENC_TYPE_CONTENT = zxidPINVOKE.ENC_TYPE_CONTENT_get();
  public static readonly int ZXID_CONF_MAGIC = zxidPINVOKE.ZXID_CONF_MAGIC_get();
  public static readonly int ZXID_CGI_MAGIC = zxidPINVOKE.ZXID_CGI_MAGIC_get();
  public static readonly int ZXID_SES_MAGIC = zxidPINVOKE.ZXID_SES_MAGIC_get();
  public static readonly int ZXID_MAP_RULE_RENAME = zxidPINVOKE.ZXID_MAP_RULE_RENAME_get();
  public static readonly int ZXID_MAP_RULE_DEL = zxidPINVOKE.ZXID_MAP_RULE_DEL_get();
  public static readonly int ZXID_MAP_RULE_RESET = zxidPINVOKE.ZXID_MAP_RULE_RESET_get();
  public static readonly int ZXID_MAP_RULE_FEIDEDEC = zxidPINVOKE.ZXID_MAP_RULE_FEIDEDEC_get();
  public static readonly int ZXID_MAP_RULE_FEIDEENC = zxidPINVOKE.ZXID_MAP_RULE_FEIDEENC_get();
  public static readonly int ZXID_MAP_RULE_UNSB64_INF = zxidPINVOKE.ZXID_MAP_RULE_UNSB64_INF_get();
  public static readonly int ZXID_MAP_RULE_DEF_SB64 = zxidPINVOKE.ZXID_MAP_RULE_DEF_SB64_get();
  public static readonly int ZXID_MAP_RULE_UNSB64 = zxidPINVOKE.ZXID_MAP_RULE_UNSB64_get();
  public static readonly int ZXID_MAP_RULE_SB64 = zxidPINVOKE.ZXID_MAP_RULE_SB64_get();
  public static readonly string ZXID_SES_DIR = zxidPINVOKE.ZXID_SES_DIR_get();
  public static readonly string ZXID_USER_DIR = zxidPINVOKE.ZXID_USER_DIR_get();
  public static readonly string ZXID_UID_DIR = zxidPINVOKE.ZXID_UID_DIR_get();
  public static readonly string ZXID_NID_DIR = zxidPINVOKE.ZXID_NID_DIR_get();
  public static readonly string ZXID_PEM_DIR = zxidPINVOKE.ZXID_PEM_DIR_get();
  public static readonly string ZXID_COT_DIR = zxidPINVOKE.ZXID_COT_DIR_get();
  public static readonly string ZXID_DIMD_DIR = zxidPINVOKE.ZXID_DIMD_DIR_get();
  public static readonly int ZXID_MAX_USER = zxidPINVOKE.ZXID_MAX_USER_get();
  public static readonly int ZXID_MAX_MD = zxidPINVOKE.ZXID_MAX_MD_get();
  public static readonly int ZXID_MAX_SOAP = zxidPINVOKE.ZXID_MAX_SOAP_get();
  public static readonly int ZXID_MAX_EID = zxidPINVOKE.ZXID_MAX_EID_get();
  public static readonly int ZXID_MAX_DIR = zxidPINVOKE.ZXID_MAX_DIR_get();
  public static readonly int ZXID_AUTO_EXIT = zxidPINVOKE.ZXID_AUTO_EXIT_get();
  public static readonly int ZXID_AUTO_REDIR = zxidPINVOKE.ZXID_AUTO_REDIR_get();
  public static readonly int ZXID_AUTO_SOAPC = zxidPINVOKE.ZXID_AUTO_SOAPC_get();
  public static readonly int ZXID_AUTO_SOAPH = zxidPINVOKE.ZXID_AUTO_SOAPH_get();
  public static readonly int ZXID_AUTO_METAC = zxidPINVOKE.ZXID_AUTO_METAC_get();
  public static readonly int ZXID_AUTO_METAH = zxidPINVOKE.ZXID_AUTO_METAH_get();
  public static readonly int ZXID_AUTO_LOGINC = zxidPINVOKE.ZXID_AUTO_LOGINC_get();
  public static readonly int ZXID_AUTO_LOGINH = zxidPINVOKE.ZXID_AUTO_LOGINH_get();
  public static readonly int ZXID_AUTO_MGMTC = zxidPINVOKE.ZXID_AUTO_MGMTC_get();
  public static readonly int ZXID_AUTO_MGMTH = zxidPINVOKE.ZXID_AUTO_MGMTH_get();
  public static readonly int ZXID_AUTO_FORMF = zxidPINVOKE.ZXID_AUTO_FORMF_get();
  public static readonly int ZXID_AUTO_FORMT = zxidPINVOKE.ZXID_AUTO_FORMT_get();
  public static readonly int ZXID_AUTO_ALL = zxidPINVOKE.ZXID_AUTO_ALL_get();
  public static readonly int ZXID_AUTO_DEBUG = zxidPINVOKE.ZXID_AUTO_DEBUG_get();
  public static readonly int ZXID_AUTO_FMTQ = zxidPINVOKE.ZXID_AUTO_FMTQ_get();
  public static readonly int ZXID_AUTO_FMTJ = zxidPINVOKE.ZXID_AUTO_FMTJ_get();
  public static readonly int ZXID_SSO_SIGN_A7N = zxidPINVOKE.ZXID_SSO_SIGN_A7N_get();
  public static readonly int ZXID_SSO_SIGN_RESP = zxidPINVOKE.ZXID_SSO_SIGN_RESP_get();
  public static readonly int ZXID_SSO_SIGN_A7N_SIMPLE = zxidPINVOKE.ZXID_SSO_SIGN_A7N_SIMPLE_get();
  public static readonly int ZXSIG_OK = zxidPINVOKE.ZXSIG_OK_get();
  public static readonly int ZXSIG_BAD_DALGO = zxidPINVOKE.ZXSIG_BAD_DALGO_get();
  public static readonly int ZXSIG_DIGEST_LEN = zxidPINVOKE.ZXSIG_DIGEST_LEN_get();
  public static readonly int ZXSIG_BAD_DIGEST = zxidPINVOKE.ZXSIG_BAD_DIGEST_get();
  public static readonly int ZXSIG_BAD_SALGO = zxidPINVOKE.ZXSIG_BAD_SALGO_get();
  public static readonly int ZXSIG_BAD_CERT = zxidPINVOKE.ZXSIG_BAD_CERT_get();
  public static readonly int ZXSIG_VFY_FAIL = zxidPINVOKE.ZXSIG_VFY_FAIL_get();
  public static readonly int ZXSIG_NO_SIG = zxidPINVOKE.ZXSIG_NO_SIG_get();
  public static readonly int ZXSIG_TIMEOUT = zxidPINVOKE.ZXSIG_TIMEOUT_get();
  public static readonly int ZXSIG_AUDIENCE = zxidPINVOKE.ZXSIG_AUDIENCE_get();
  public static readonly string ZXLOG_RELY_DIR = zxidPINVOKE.ZXLOG_RELY_DIR_get();
  public static readonly string ZXLOG_ISSUE_DIR = zxidPINVOKE.ZXLOG_ISSUE_DIR_get();
  public static readonly string ZXLOG_A7N_KIND = zxidPINVOKE.ZXLOG_A7N_KIND_get();
  public static readonly string ZXLOG_MSG_KIND = zxidPINVOKE.ZXLOG_MSG_KIND_get();
  public static readonly string ZXLOG_WIR_KIND = zxidPINVOKE.ZXLOG_WIR_KIND_get();
  public static readonly int ZXID_DAP_SCOPE_BASE = zxidPINVOKE.ZXID_DAP_SCOPE_BASE_get();
  public static readonly int ZXID_DAP_SCOPE_SINGLE = zxidPINVOKE.ZXID_DAP_SCOPE_SINGLE_get();
  public static readonly int ZXID_DAP_SCOPE_SUBTREE = zxidPINVOKE.ZXID_DAP_SCOPE_SUBTREE_get();
  public static readonly int ZXID_CDC_CHOICE_ALWAYS_FIRST = zxidPINVOKE.ZXID_CDC_CHOICE_ALWAYS_FIRST_get();
  public static readonly int ZXID_CDC_CHOICE_ALWAYS_LAST = zxidPINVOKE.ZXID_CDC_CHOICE_ALWAYS_LAST_get();
  public static readonly int ZXID_CDC_CHOICE_ALWAYS_ONLY = zxidPINVOKE.ZXID_CDC_CHOICE_ALWAYS_ONLY_get();
  public static readonly int ZXID_CDC_CHOICE_UI_PREF = zxidPINVOKE.ZXID_CDC_CHOICE_UI_PREF_get();
  public static readonly int ZXID_CDC_CHOICE_UI_NOPREF = zxidPINVOKE.ZXID_CDC_CHOICE_UI_NOPREF_get();
  public static readonly int ZXID_CDC_CHOICE_UI_ONLY_CDC = zxidPINVOKE.ZXID_CDC_CHOICE_UI_ONLY_CDC_get();
  public static readonly int ZXID_SAML2_ART = zxidPINVOKE.ZXID_SAML2_ART_get();
  public static readonly int ZXID_SAML2_POST = zxidPINVOKE.ZXID_SAML2_POST_get();
  public static readonly int ZXID_SAML2_PAOS = zxidPINVOKE.ZXID_SAML2_PAOS_get();
  public static readonly int ZXID_SAML2_SOAP = zxidPINVOKE.ZXID_SAML2_SOAP_get();
  public static readonly int ZXID_SAML2_POST_SIMPLE_SIGN = zxidPINVOKE.ZXID_SAML2_POST_SIMPLE_SIGN_get();
  public static readonly int ZXID_SAML2_REDIR = zxidPINVOKE.ZXID_SAML2_REDIR_get();
  public static readonly int ZXID_SAML2_URI = zxidPINVOKE.ZXID_SAML2_URI_get();
  public static readonly int ZXID_SLO_SVC = zxidPINVOKE.ZXID_SLO_SVC_get();
  public static readonly int ZXID_MNI_SVC = zxidPINVOKE.ZXID_MNI_SVC_get();
  public static readonly int ZXID_ACS_SVC = zxidPINVOKE.ZXID_ACS_SVC_get();
  public static readonly int ZXID_SEC_MECH_NULL = zxidPINVOKE.ZXID_SEC_MECH_NULL_get();
  public static readonly int ZXID_SEC_MECH_BEARER = zxidPINVOKE.ZXID_SEC_MECH_BEARER_get();
  public static readonly int ZXID_SEC_MECH_SAML = zxidPINVOKE.ZXID_SEC_MECH_SAML_get();
  public static readonly int ZXID_SEC_MECH_X509 = zxidPINVOKE.ZXID_SEC_MECH_X509_get();
  public static readonly int ZXID_SEC_MECH_PEERS = zxidPINVOKE.ZXID_SEC_MECH_PEERS_get();
  public static readonly int ZXID_FAIL = zxidPINVOKE.ZXID_FAIL_get();
  public static readonly int ZXID_OK = zxidPINVOKE.ZXID_OK_get();
  public static readonly int ZXID_REDIR_OK = zxidPINVOKE.ZXID_REDIR_OK_get();
  public static readonly int ZXID_SSO_OK = zxidPINVOKE.ZXID_SSO_OK_get();
  public static readonly int ZXID_IDP_REQ = zxidPINVOKE.ZXID_IDP_REQ_get();
  public static readonly string ZXID_TRUE = zxidPINVOKE.ZXID_TRUE_get();
  public static readonly string ZXID_FALSE = zxidPINVOKE.ZXID_FALSE_get();
  public static readonly string CRLF = zxidPINVOKE.CRLF_get();
  public static readonly string CRLF2 = zxidPINVOKE.CRLF2_get();
  public static readonly string SAML2_PROTO = zxidPINVOKE.SAML2_PROTO_get();
  public static readonly string SAML2_VERSION = zxidPINVOKE.SAML2_VERSION_get();
  public static readonly string SAML2_SC_SUCCESS = zxidPINVOKE.SAML2_SC_SUCCESS_get();
  public static readonly string SAML2_SC_REQUESTER = zxidPINVOKE.SAML2_SC_REQUESTER_get();
  public static readonly string SAML2_SC_RESPONDER = zxidPINVOKE.SAML2_SC_RESPONDER_get();
  public static readonly string SAML2_SC_VERSION = zxidPINVOKE.SAML2_SC_VERSION_get();
  public static readonly string SAML2_SC_AUTHNFAIL = zxidPINVOKE.SAML2_SC_AUTHNFAIL_get();
  public static readonly string SAML2_SC_INVATTRNV = zxidPINVOKE.SAML2_SC_INVATTRNV_get();
  public static readonly string SAML2_SC_INVNIDPOL = zxidPINVOKE.SAML2_SC_INVNIDPOL_get();
  public static readonly string SAML2_SC_NOAUTNCTX = zxidPINVOKE.SAML2_SC_NOAUTNCTX_get();
  public static readonly string SAML2_SC_NOAVALIDP = zxidPINVOKE.SAML2_SC_NOAVALIDP_get();
  public static readonly string SAML2_SC_NOPASSIVE = zxidPINVOKE.SAML2_SC_NOPASSIVE_get();
  public static readonly string SAML2_SC_NOSUPPIDP = zxidPINVOKE.SAML2_SC_NOSUPPIDP_get();
  public static readonly string SAML2_SC_PARLOGOUT = zxidPINVOKE.SAML2_SC_PARLOGOUT_get();
  public static readonly string SAML2_SC_PROXYCEXC = zxidPINVOKE.SAML2_SC_PROXYCEXC_get();
  public static readonly string SAML2_SC_REQDENIED = zxidPINVOKE.SAML2_SC_REQDENIED_get();
  public static readonly string SAML2_SC_REQUNSUPP = zxidPINVOKE.SAML2_SC_REQUNSUPP_get();
  public static readonly string SAML2_SC_REQVERDEP = zxidPINVOKE.SAML2_SC_REQVERDEP_get();
  public static readonly string SAML2_SC_REQVERHIG = zxidPINVOKE.SAML2_SC_REQVERHIG_get();
  public static readonly string SAML2_SC_REQVERLOW = zxidPINVOKE.SAML2_SC_REQVERLOW_get();
  public static readonly string SAML2_SC_RESONRECG = zxidPINVOKE.SAML2_SC_RESONRECG_get();
  public static readonly string SAML2_SC_TOOMNYRES = zxidPINVOKE.SAML2_SC_TOOMNYRES_get();
  public static readonly string SAML2_SC_UNKATTPRO = zxidPINVOKE.SAML2_SC_UNKATTPRO_get();
  public static readonly string SAML2_SC_UNKPRNCPL = zxidPINVOKE.SAML2_SC_UNKPRNCPL_get();
  public static readonly string SAML2_SC_UNSUPPBIN = zxidPINVOKE.SAML2_SC_UNSUPPBIN_get();
  public static readonly string SAML_AUTHCTX_PASSWORDPROTECTED = zxidPINVOKE.SAML_AUTHCTX_PASSWORDPROTECTED_get();
  public static readonly string SAML_AUTHCTX_PASSWORD = zxidPINVOKE.SAML_AUTHCTX_PASSWORD_get();
  public static readonly string SAML_AUTHCTX_SSL_TLS_CERT = zxidPINVOKE.SAML_AUTHCTX_SSL_TLS_CERT_get();
  public static readonly string SAML_AUTHCTX_PREVSESS = zxidPINVOKE.SAML_AUTHCTX_PREVSESS_get();
  public static readonly string SAML_AUTHCTX_UNSPCFD = zxidPINVOKE.SAML_AUTHCTX_UNSPCFD_get();
  public static readonly string SAML_AUTHCTX_INPROT = zxidPINVOKE.SAML_AUTHCTX_INPROT_get();
  public static readonly string SAML2_UNSPECIFIED_NID_FMT = zxidPINVOKE.SAML2_UNSPECIFIED_NID_FMT_get();
  public static readonly string SAML2_EMAILADDR_NID_FMT = zxidPINVOKE.SAML2_EMAILADDR_NID_FMT_get();
  public static readonly string SAML2_X509_NID_FMT = zxidPINVOKE.SAML2_X509_NID_FMT_get();
  public static readonly string SAML2_WINDOMAINQN_NID_FMT = zxidPINVOKE.SAML2_WINDOMAINQN_NID_FMT_get();
  public static readonly string SAML2_KERBEROS_NID_FMT = zxidPINVOKE.SAML2_KERBEROS_NID_FMT_get();
  public static readonly string SAML2_ENTITY_NID_FMT = zxidPINVOKE.SAML2_ENTITY_NID_FMT_get();
  public static readonly string SAML2_PERSISTENT_NID_FMT = zxidPINVOKE.SAML2_PERSISTENT_NID_FMT_get();
  public static readonly string SAML2_TRANSIENT_NID_FMT = zxidPINVOKE.SAML2_TRANSIENT_NID_FMT_get();
  public static readonly string SAML2_SSO_BRWS = zxidPINVOKE.SAML2_SSO_BRWS_get();
  public static readonly string SAML2_SSO_ECP = zxidPINVOKE.SAML2_SSO_ECP_get();
  public static readonly string SAML2_SLO = zxidPINVOKE.SAML2_SLO_get();
  public static readonly string SAML2_NIREG = zxidPINVOKE.SAML2_NIREG_get();
  public static readonly string SAML2_NIMAP = zxidPINVOKE.SAML2_NIMAP_get();
  public static readonly string SAML2_ARTIFACT = zxidPINVOKE.SAML2_ARTIFACT_get();
  public static readonly string SAML2_QUERY = zxidPINVOKE.SAML2_QUERY_get();
  public static readonly string SAML2_PAOS = zxidPINVOKE.SAML2_PAOS_get();
  public static readonly string SAML2_SOAP = zxidPINVOKE.SAML2_SOAP_get();
  public static readonly string SAML2_REDIR = zxidPINVOKE.SAML2_REDIR_get();
  public static readonly string SAML2_ART = zxidPINVOKE.SAML2_ART_get();
  public static readonly string SAML2_POST = zxidPINVOKE.SAML2_POST_get();
  public static readonly string SAML2_POST_SIMPLE_SIGN = zxidPINVOKE.SAML2_POST_SIMPLE_SIGN_get();
  public static readonly string SAML2_URI = zxidPINVOKE.SAML2_URI_get();
  public static readonly string SAML2_AP_BASIC = zxidPINVOKE.SAML2_AP_BASIC_get();
  public static readonly string SAML2_AP_X500 = zxidPINVOKE.SAML2_AP_X500_get();
  public static readonly string SAML2_AP_UUID = zxidPINVOKE.SAML2_AP_UUID_get();
  public static readonly string SAML2_AP_DCE = zxidPINVOKE.SAML2_AP_DCE_get();
  public static readonly string SAML2_AP_XACML = zxidPINVOKE.SAML2_AP_XACML_get();
  public static readonly string ATTRNAME_UNSPECIFIED = zxidPINVOKE.ATTRNAME_UNSPECIFIED_get();
  public static readonly string ATTRNAME_BASIC = zxidPINVOKE.ATTRNAME_BASIC_get();
  public static readonly string SOAP_ACTOR_NEXT = zxidPINVOKE.SOAP_ACTOR_NEXT_get();
  public static readonly string SAML2_BEARER = zxidPINVOKE.SAML2_BEARER_get();
  public static readonly string SAML2_SOAP_ACTION = zxidPINVOKE.SAML2_SOAP_ACTION_get();
  public static readonly string ACTION_RW = zxidPINVOKE.ACTION_RW_get();
  public static readonly string ACTION_RWN = zxidPINVOKE.ACTION_RWN_get();
  public static readonly string ACTION_GHPP = zxidPINVOKE.ACTION_GHPP_get();
  public static readonly string ACTION_UNIX = zxidPINVOKE.ACTION_UNIX_get();
  public static readonly string PAOS_CONTENT = zxidPINVOKE.PAOS_CONTENT_get();
  public static readonly string XMLNS_SA = zxidPINVOKE.XMLNS_SA_get();
  public static readonly string XMLNS_IMS = zxidPINVOKE.XMLNS_IMS_get();
  public static readonly string XMLNS_LIB = zxidPINVOKE.XMLNS_LIB_get();
  public static readonly string ACT_SASL_REQ = zxidPINVOKE.ACT_SASL_REQ_get();
  public static readonly string ACT_SASL_RES = zxidPINVOKE.ACT_SASL_RES_get();
  public static readonly string PWTRUNCATE = zxidPINVOKE.PWTRUNCATE_get();
  public static readonly string PWLOWERCASE = zxidPINVOKE.PWLOWERCASE_get();
  public static readonly string PWUPPERCASE = zxidPINVOKE.PWUPPERCASE_get();
  public static readonly string PWSELECT = zxidPINVOKE.PWSELECT_get();
  public static readonly string XMLNS_SUBS = zxidPINVOKE.XMLNS_SUBS_get();
  public static readonly string XMLNS_SUBSREF = zxidPINVOKE.XMLNS_SUBSREF_get();
  public static readonly string SUBS_OPT_NOSUBSCIB = zxidPINVOKE.SUBS_OPT_NOSUBSCIB_get();
  public static readonly string SUBS_OPT_NOQUESUBS = zxidPINVOKE.SUBS_OPT_NOQUESUBS_get();
  public static readonly string SUBS_END_EXPIRED = zxidPINVOKE.SUBS_END_EXPIRED_get();
  public static readonly string SUBS_END_DELETED = zxidPINVOKE.SUBS_END_DELETED_get();
  public static readonly string WSF11_DI_RO = zxidPINVOKE.WSF11_DI_RO_get();
  public static readonly string WSF20_DI_RO = zxidPINVOKE.WSF20_DI_RO_get();
  public static readonly string IMPLIED_RSC = zxidPINVOKE.IMPLIED_RSC_get();
  public static readonly string XMLNS_DISCO_1_1 = zxidPINVOKE.XMLNS_DISCO_1_1_get();
  public static readonly string XMLNS_DISCO_EXT = zxidPINVOKE.XMLNS_DISCO_EXT_get();
  public static readonly string XMLNS_DISCO_2_0 = zxidPINVOKE.XMLNS_DISCO_2_0_get();
  public static readonly string XMLNS_SBF = zxidPINVOKE.XMLNS_SBF_get();
  public static readonly string ACT_QUE = zxidPINVOKE.ACT_QUE_get();
  public static readonly string ACT_QUE_RES = zxidPINVOKE.ACT_QUE_RES_get();
  public static readonly string ACT_ASSO_QUE = zxidPINVOKE.ACT_ASSO_QUE_get();
  public static readonly string ACT_ASSO_QUE_RES = zxidPINVOKE.ACT_ASSO_QUE_RES_get();
  public static readonly string ACT_ASSO_ADD = zxidPINVOKE.ACT_ASSO_ADD_get();
  public static readonly string ACT_ASSO_ADD_RES = zxidPINVOKE.ACT_ASSO_ADD_RES_get();
  public static readonly string ACT_ASSO_DEL = zxidPINVOKE.ACT_ASSO_DEL_get();
  public static readonly string ACT_ASSO_DEL_RES = zxidPINVOKE.ACT_ASSO_DEL_RES_get();
  public static readonly string ACT_SVCMD_QUE = zxidPINVOKE.ACT_SVCMD_QUE_get();
  public static readonly string ACT_SVCMD_QUE_RES = zxidPINVOKE.ACT_SVCMD_QUE_RES_get();
  public static readonly string ACT_SVCMD_REG = zxidPINVOKE.ACT_SVCMD_REG_get();
  public static readonly string ACT_SVCMD_REG_RES = zxidPINVOKE.ACT_SVCMD_REG_RES_get();
  public static readonly string ACT_SVCMD_REP = zxidPINVOKE.ACT_SVCMD_REP_get();
  public static readonly string ACT_SVCMD_REP_RES = zxidPINVOKE.ACT_SVCMD_REP_RES_get();
  public static readonly string ACT_SVCMD_DEL = zxidPINVOKE.ACT_SVCMD_DEL_get();
  public static readonly string ACT_SVCMD_DEL_RES = zxidPINVOKE.ACT_SVCMD_DEL_RES_get();
  public static readonly string XMLNS_GL = zxidPINVOKE.XMLNS_GL_get();
  public static readonly string GL_OPT_SHAPE = zxidPINVOKE.GL_OPT_SHAPE_get();
  public static readonly string GL_OPT_SPEED = zxidPINVOKE.GL_OPT_SPEED_get();
  public static readonly string GL_OPT_DIRECTION = zxidPINVOKE.GL_OPT_DIRECTION_get();
  public static readonly string GL_OPT_HEADING = zxidPINVOKE.GL_OPT_HEADING_get();
  public static readonly string GL_OPT_ALT = zxidPINVOKE.GL_OPT_ALT_get();
  public static readonly string GL_OPT_CIVIL_DATA = zxidPINVOKE.GL_OPT_CIVIL_DATA_get();
  public static readonly string GL_OPT_AC = zxidPINVOKE.GL_OPT_AC_get();
  public static readonly string GL_OPT_AC_ONLY = zxidPINVOKE.GL_OPT_AC_ONLY_get();
  public static readonly string GL_OPT_ACC_HIGH = zxidPINVOKE.GL_OPT_ACC_HIGH_get();
  public static readonly string GL_OPT_ACC_MEDIUM = zxidPINVOKE.GL_OPT_ACC_MEDIUM_get();
  public static readonly string GL_OPT_ACC_LOW = zxidPINVOKE.GL_OPT_ACC_LOW_get();
  public static readonly string XMLNS_IS11 = zxidPINVOKE.XMLNS_IS11_get();
  public static readonly string XMLNS_IS20 = zxidPINVOKE.XMLNS_IS20_get();
  public static readonly string ACT_IREQ = zxidPINVOKE.ACT_IREQ_get();
  public static readonly string ACT_IRES = zxidPINVOKE.ACT_IRES_get();
  public static readonly string OPT_PP = zxidPINVOKE.OPT_PP_get();
  public static readonly string OPT_PP_INAME = zxidPINVOKE.OPT_PP_INAME_get();
  public static readonly string OPT_PP_CN = zxidPINVOKE.OPT_PP_CN_get();
  public static readonly string OPT_PP_LEG = zxidPINVOKE.OPT_PP_LEG_get();
  public static readonly string OPT_PP_ADD = zxidPINVOKE.OPT_PP_ADD_get();
  public static readonly string OPTC_PP = zxidPINVOKE.OPTC_PP_get();
  public static readonly string OPTC_PP_INAME = zxidPINVOKE.OPTC_PP_INAME_get();
  public static readonly string OPTC_PP_CN = zxidPINVOKE.OPTC_PP_CN_get();
  public static readonly string OPTC_PP_LEG = zxidPINVOKE.OPTC_PP_LEG_get();
  public static readonly string OPTC_PP_ADD = zxidPINVOKE.OPTC_PP_ADD_get();
  public static readonly string OPT_MULT_QI = zxidPINVOKE.OPT_MULT_QI_get();
  public static readonly string OPT_MULT_MI = zxidPINVOKE.OPT_MULT_MI_get();
  public static readonly string XMLNS_PP = zxidPINVOKE.XMLNS_PP_get();
  public static readonly string PS_COL = zxidPINVOKE.PS_COL_get();
  public static readonly string PS_ENT = zxidPINVOKE.PS_ENT_get();
  public static readonly string XMLNS_PS = zxidPINVOKE.XMLNS_PS_get();
  public static readonly string ACT_PS_ADDENT_REQ = zxidPINVOKE.ACT_PS_ADDENT_REQ_get();
  public static readonly string ACT_PS_ADDENT_RES = zxidPINVOKE.ACT_PS_ADDENT_RES_get();
  public static readonly string ACT_PS_ADDKENT_REQ = zxidPINVOKE.ACT_PS_ADDKENT_REQ_get();
  public static readonly string ACT_PS_ADDKENT_RES = zxidPINVOKE.ACT_PS_ADDKENT_RES_get();
  public static readonly string ACT_PS_REMENT_REQ = zxidPINVOKE.ACT_PS_REMENT_REQ_get();
  public static readonly string ACT_PS_REMENT_RES = zxidPINVOKE.ACT_PS_REMENT_RES_get();
  public static readonly string ACT_PS_ADDCOL_REQ = zxidPINVOKE.ACT_PS_ADDCOL_REQ_get();
  public static readonly string ACT_PS_ADDCOL_RES = zxidPINVOKE.ACT_PS_ADDCOL_RES_get();
  public static readonly string ACT_PS_REMCOL_REQ = zxidPINVOKE.ACT_PS_REMCOL_REQ_get();
  public static readonly string ACT_PS_REMCOL_RES = zxidPINVOKE.ACT_PS_REMCOL_RES_get();
  public static readonly string ACT_PS_ADDTOCOL_REQ = zxidPINVOKE.ACT_PS_ADDTOCOL_REQ_get();
  public static readonly string ACT_PS_ADDTOCOL_RES = zxidPINVOKE.ACT_PS_ADDTOCOL_RES_get();
  public static readonly string ACT_PS_REMFROMCOL_REQ = zxidPINVOKE.ACT_PS_REMFROMCOL_REQ_get();
  public static readonly string ACT_PS_REMFROMCOL_RES = zxidPINVOKE.ACT_PS_REMFROMCOL_RES_get();
  public static readonly string ACT_PS_LISTMEM_REQ = zxidPINVOKE.ACT_PS_LISTMEM_REQ_get();
  public static readonly string ACT_PS_LISTMEM_RES = zxidPINVOKE.ACT_PS_LISTMEM_RES_get();
  public static readonly string ACT_PS_GETOBJ_REQ = zxidPINVOKE.ACT_PS_GETOBJ_REQ_get();
  public static readonly string ACT_PS_GETOBJ_RES = zxidPINVOKE.ACT_PS_GETOBJ_RES_get();
  public static readonly string ACT_PS_SETOBJ_REQ = zxidPINVOKE.ACT_PS_SETOBJ_REQ_get();
  public static readonly string ACT_PS_SETOBJ_RES = zxidPINVOKE.ACT_PS_SETOBJ_RES_get();
  public static readonly string ACT_PS_QUEOBJ_REQ = zxidPINVOKE.ACT_PS_QUEOBJ_REQ_get();
  public static readonly string ACT_PS_QUEOBJ_RES = zxidPINVOKE.ACT_PS_QUEOBJ_RES_get();
  public static readonly string ACT_PS_TESTMEM_REQ = zxidPINVOKE.ACT_PS_TESTMEM_REQ_get();
  public static readonly string ACT_PS_TESTMEM_RES = zxidPINVOKE.ACT_PS_TESTMEM_RES_get();
  public static readonly string ACT_PS_RSLVID_REQ = zxidPINVOKE.ACT_PS_RSLVID_REQ_get();
  public static readonly string ACT_PS_RSLVID_RES = zxidPINVOKE.ACT_PS_RSLVID_RES_get();
  public static readonly string ACT_PS_NOTIFY = zxidPINVOKE.ACT_PS_NOTIFY_get();
  public static readonly string ACT_PS_NOTIFY_RES = zxidPINVOKE.ACT_PS_NOTIFY_RES_get();
  public static readonly string XMLNS_SEC = zxidPINVOKE.XMLNS_SEC_get();
  public static readonly string TOKNUSG_SEC = zxidPINVOKE.TOKNUSG_SEC_get();
  public static readonly string TOKNUSG_TID = zxidPINVOKE.TOKNUSG_TID_get();
  public static readonly string TOKNUSG_IID = zxidPINVOKE.TOKNUSG_IID_get();
  public static readonly string WSF10_SEC_MECH_NULL_BEARER = zxidPINVOKE.WSF10_SEC_MECH_NULL_BEARER_get();
  public static readonly string WSF10_SEC_MECH_TLS_BEARER = zxidPINVOKE.WSF10_SEC_MECH_TLS_BEARER_get();
  public static readonly string WSF11_SEC_MECH_NULL_NULL = zxidPINVOKE.WSF11_SEC_MECH_NULL_NULL_get();
  public static readonly string WSF11_SEC_MECH_TLS_NULL = zxidPINVOKE.WSF11_SEC_MECH_TLS_NULL_get();
  public static readonly string WSF11_SEC_MECH_CLTLS_NULL = zxidPINVOKE.WSF11_SEC_MECH_CLTLS_NULL_get();
  public static readonly string WSF11_SEC_MECH_NULL_BEARER = zxidPINVOKE.WSF11_SEC_MECH_NULL_BEARER_get();
  public static readonly string WSF11_SEC_MECH_TLS_BEARER = zxidPINVOKE.WSF11_SEC_MECH_TLS_BEARER_get();
  public static readonly string WSF11_SEC_MECH_CLTLS_BEARER = zxidPINVOKE.WSF11_SEC_MECH_CLTLS_BEARER_get();
  public static readonly string WSF11_SEC_MECH_NULL_X509 = zxidPINVOKE.WSF11_SEC_MECH_NULL_X509_get();
  public static readonly string WSF11_SEC_MECH_TLS_X509 = zxidPINVOKE.WSF11_SEC_MECH_TLS_X509_get();
  public static readonly string WSF11_SEC_MECH_CLTLS_X509 = zxidPINVOKE.WSF11_SEC_MECH_CLTLS_X509_get();
  public static readonly string WSF11_SEC_MECH_NULL_SAML = zxidPINVOKE.WSF11_SEC_MECH_NULL_SAML_get();
  public static readonly string WSF11_SEC_MECH_TLS_SAML = zxidPINVOKE.WSF11_SEC_MECH_TLS_SAML_get();
  public static readonly string WSF11_SEC_MECH_CLTLS_SAML = zxidPINVOKE.WSF11_SEC_MECH_CLTLS_SAML_get();
  public static readonly string WSF20_SEC_MECH_NULL_NULL = zxidPINVOKE.WSF20_SEC_MECH_NULL_NULL_get();
  public static readonly string WSF20_SEC_MECH_TLS_NULL = zxidPINVOKE.WSF20_SEC_MECH_TLS_NULL_get();
  public static readonly string WSF20_SEC_MECH_NULL_BEARER = zxidPINVOKE.WSF20_SEC_MECH_NULL_BEARER_get();
  public static readonly string WSF20_SEC_MECH_TLS_BEARER = zxidPINVOKE.WSF20_SEC_MECH_TLS_BEARER_get();
  public static readonly string WSF20_SEC_MECH_NULL_SAML2 = zxidPINVOKE.WSF20_SEC_MECH_NULL_SAML2_get();
  public static readonly string WSF20_SEC_MECH_TLS_SAML2 = zxidPINVOKE.WSF20_SEC_MECH_TLS_SAML2_get();
  public static readonly string WSF20_SEC_MECH_CLTLS_SAML2 = zxidPINVOKE.WSF20_SEC_MECH_CLTLS_SAML2_get();
  public static readonly string WSF20_SEC_MECH_CLTLS_PEERS2 = zxidPINVOKE.WSF20_SEC_MECH_CLTLS_PEERS2_get();
  public static readonly string SAML2_TOK_PROFILE = zxidPINVOKE.SAML2_TOK_PROFILE_get();
  public static readonly string SAMLID_TOK_PROFILE = zxidPINVOKE.SAMLID_TOK_PROFILE_get();
  public static readonly string WSS_X509_TOKEN_PROFILE = zxidPINVOKE.WSS_X509_TOKEN_PROFILE_get();
  public static readonly string SB_EPUPD_COMP = zxidPINVOKE.SB_EPUPD_COMP_get();
  public static readonly string SB_EPUPD_PART = zxidPINVOKE.SB_EPUPD_PART_get();
  public static readonly string SB_EPUPD_NOCH = zxidPINVOKE.SB_EPUPD_NOCH_get();
  public static readonly string XMLNS_CSM = zxidPINVOKE.XMLNS_CSM_get();
  public static readonly string XMLNS_LU = zxidPINVOKE.XMLNS_LU_get();
  public static readonly string XMLNS_HLO = zxidPINVOKE.XMLNS_HLO_get();
  public static readonly string DST_ACC_CHALLENGE = zxidPINVOKE.DST_ACC_CHALLENGE_get();
  public static readonly string XMLNS_CXP = zxidPINVOKE.XMLNS_CXP_get();
  public static readonly string XMLNS_LIB_MD = zxidPINVOKE.XMLNS_LIB_MD_get();
  public static readonly string XMLNS_AC = zxidPINVOKE.XMLNS_AC_get();
  public static readonly string LIBERTY_NAMEID_FMT_FED = zxidPINVOKE.LIBERTY_NAMEID_FMT_FED_get();
  public static readonly string LIBERTY_NAMEID_FMT_ONE = zxidPINVOKE.LIBERTY_NAMEID_FMT_ONE_get();
  public static readonly string LIBERTY_NAMEID_FMT_ENC = zxidPINVOKE.LIBERTY_NAMEID_FMT_ENC_get();
  public static readonly string LIBERTY_NAMEID_FMT_ENT = zxidPINVOKE.LIBERTY_NAMEID_FMT_ENT_get();
  public static readonly string XMLNS_PAOS = zxidPINVOKE.XMLNS_PAOS_get();
  public static readonly string PAOS_HDR = zxidPINVOKE.PAOS_HDR_get();
  public static readonly string LIBERTY_ENA_HDR = zxidPINVOKE.LIBERTY_ENA_HDR_get();
  public static readonly string LIBERTY_CONSENT_OBTAINED = zxidPINVOKE.LIBERTY_CONSENT_OBTAINED_get();
  public static readonly string XMLNS_DAP = zxidPINVOKE.XMLNS_DAP_get();
  public static readonly int ZXID_VERSION = zxidPINVOKE.ZXID_VERSION_get();
  public static readonly string ZXID_REL = zxidPINVOKE.ZXID_REL_get();
  public static readonly string ZXID_COMPILE_DATE = zxidPINVOKE.ZXID_COMPILE_DATE_get();
  public static readonly int zx_xmlns_ix_ds = zxidPINVOKE.zx_xmlns_ix_ds_get();
  public static readonly string zx_xmlns_ds = zxidPINVOKE.zx_xmlns_ds_get();
  public static readonly int zx_xmlns_ix_xenc = zxidPINVOKE.zx_xmlns_ix_xenc_get();
  public static readonly string zx_xmlns_xenc = zxidPINVOKE.zx_xmlns_xenc_get();
  public static readonly int zx_xmlns_ix_exca = zxidPINVOKE.zx_xmlns_ix_exca_get();
  public static readonly string zx_xmlns_exca = zxidPINVOKE.zx_xmlns_exca_get();
  public static readonly int zx_xmlns_ix_sa = zxidPINVOKE.zx_xmlns_ix_sa_get();
  public static readonly string zx_xmlns_sa = zxidPINVOKE.zx_xmlns_sa_get();
  public static readonly int zx_xmlns_ix_sp = zxidPINVOKE.zx_xmlns_ix_sp_get();
  public static readonly string zx_xmlns_sp = zxidPINVOKE.zx_xmlns_sp_get();
  public static readonly int zx_xmlns_ix_ecp = zxidPINVOKE.zx_xmlns_ix_ecp_get();
  public static readonly string zx_xmlns_ecp = zxidPINVOKE.zx_xmlns_ecp_get();
  public static readonly int zx_xmlns_ix_paos = zxidPINVOKE.zx_xmlns_ix_paos_get();
  public static readonly string zx_xmlns_paos = zxidPINVOKE.zx_xmlns_paos_get();
  public static readonly int zx_xmlns_ix_e = zxidPINVOKE.zx_xmlns_ix_e_get();
  public static readonly string zx_xmlns_e = zxidPINVOKE.zx_xmlns_e_get();
  public static readonly int zx_xmlns_ix_md = zxidPINVOKE.zx_xmlns_ix_md_get();
  public static readonly string zx_xmlns_md = zxidPINVOKE.zx_xmlns_md_get();
  public static readonly int zx_xmlns_ix_shibmd = zxidPINVOKE.zx_xmlns_ix_shibmd_get();
  public static readonly string zx_xmlns_shibmd = zxidPINVOKE.zx_xmlns_shibmd_get();
  public static readonly int zx_xmlns_ix_sp11 = zxidPINVOKE.zx_xmlns_ix_sp11_get();
  public static readonly string zx_xmlns_sp11 = zxidPINVOKE.zx_xmlns_sp11_get();
  public static readonly int zx_xmlns_ix_sa11 = zxidPINVOKE.zx_xmlns_ix_sa11_get();
  public static readonly string zx_xmlns_sa11 = zxidPINVOKE.zx_xmlns_sa11_get();
  public static readonly int zx_xmlns_ix_ff12 = zxidPINVOKE.zx_xmlns_ix_ff12_get();
  public static readonly string zx_xmlns_ff12 = zxidPINVOKE.zx_xmlns_ff12_get();
  public static readonly int zx_xmlns_ix_ac = zxidPINVOKE.zx_xmlns_ix_ac_get();
  public static readonly string zx_xmlns_ac = zxidPINVOKE.zx_xmlns_ac_get();
  public static readonly int zx_xmlns_ix_m20 = zxidPINVOKE.zx_xmlns_ix_m20_get();
  public static readonly string zx_xmlns_m20 = zxidPINVOKE.zx_xmlns_m20_get();
  public static readonly int zx_xmlns_ix_a = zxidPINVOKE.zx_xmlns_ix_a_get();
  public static readonly string zx_xmlns_a = zxidPINVOKE.zx_xmlns_a_get();
  public static readonly int zx_xmlns_ix_wsse = zxidPINVOKE.zx_xmlns_ix_wsse_get();
  public static readonly string zx_xmlns_wsse = zxidPINVOKE.zx_xmlns_wsse_get();
  public static readonly int zx_xmlns_ix_wsu = zxidPINVOKE.zx_xmlns_ix_wsu_get();
  public static readonly string zx_xmlns_wsu = zxidPINVOKE.zx_xmlns_wsu_get();
  public static readonly int zx_xmlns_ix_sbf = zxidPINVOKE.zx_xmlns_ix_sbf_get();
  public static readonly string zx_xmlns_sbf = zxidPINVOKE.zx_xmlns_sbf_get();
  public static readonly int zx_xmlns_ix_b = zxidPINVOKE.zx_xmlns_ix_b_get();
  public static readonly string zx_xmlns_b = zxidPINVOKE.zx_xmlns_b_get();
  public static readonly int zx_xmlns_ix_sec = zxidPINVOKE.zx_xmlns_ix_sec_get();
  public static readonly string zx_xmlns_sec = zxidPINVOKE.zx_xmlns_sec_get();
  public static readonly int zx_xmlns_ix_di = zxidPINVOKE.zx_xmlns_ix_di_get();
  public static readonly string zx_xmlns_di = zxidPINVOKE.zx_xmlns_di_get();
  public static readonly int zx_xmlns_ix_is = zxidPINVOKE.zx_xmlns_ix_is_get();
  public static readonly string zx_xmlns_is = zxidPINVOKE.zx_xmlns_is_get();
  public static readonly int zx_xmlns_ix_lu = zxidPINVOKE.zx_xmlns_ix_lu_get();
  public static readonly string zx_xmlns_lu = zxidPINVOKE.zx_xmlns_lu_get();
  public static readonly int zx_xmlns_ix_dap = zxidPINVOKE.zx_xmlns_ix_dap_get();
  public static readonly string zx_xmlns_dap = zxidPINVOKE.zx_xmlns_dap_get();
  public static readonly int zx_xmlns_ix_subs = zxidPINVOKE.zx_xmlns_ix_subs_get();
  public static readonly string zx_xmlns_subs = zxidPINVOKE.zx_xmlns_subs_get();
  public static readonly int zx_xmlns_ix_dst = zxidPINVOKE.zx_xmlns_ix_dst_get();
  public static readonly string zx_xmlns_dst = zxidPINVOKE.zx_xmlns_dst_get();
  public static readonly int zx_xmlns_ix_im = zxidPINVOKE.zx_xmlns_ix_im_get();
  public static readonly string zx_xmlns_im = zxidPINVOKE.zx_xmlns_im_get();
  public static readonly int zx_xmlns_ix_ps = zxidPINVOKE.zx_xmlns_ix_ps_get();
  public static readonly string zx_xmlns_ps = zxidPINVOKE.zx_xmlns_ps_get();
  public static readonly int zx_xmlns_ix_as = zxidPINVOKE.zx_xmlns_ix_as_get();
  public static readonly string zx_xmlns_as = zxidPINVOKE.zx_xmlns_as_get();
  public static readonly int zx_xmlns_ix_xml = zxidPINVOKE.zx_xmlns_ix_xml_get();
  public static readonly string zx_xmlns_xml = zxidPINVOKE.zx_xmlns_xml_get();
  public static readonly int zx_xmlns_ix_xsi = zxidPINVOKE.zx_xmlns_ix_xsi_get();
  public static readonly string zx_xmlns_xsi = zxidPINVOKE.zx_xmlns_xsi_get();
  public static readonly int zx_xmlns_ix_xs = zxidPINVOKE.zx_xmlns_ix_xs_get();
  public static readonly string zx_xmlns_xs = zxidPINVOKE.zx_xmlns_xs_get();
  public static readonly int zx_xmlns_ix_mm7 = zxidPINVOKE.zx_xmlns_ix_mm7_get();
  public static readonly string zx_xmlns_mm7 = zxidPINVOKE.zx_xmlns_mm7_get();
  public static readonly int zx_xmlns_ix_cb = zxidPINVOKE.zx_xmlns_ix_cb_get();
  public static readonly string zx_xmlns_cb = zxidPINVOKE.zx_xmlns_cb_get();
  public static readonly int zx_xmlns_ix_cdm = zxidPINVOKE.zx_xmlns_ix_cdm_get();
  public static readonly string zx_xmlns_cdm = zxidPINVOKE.zx_xmlns_cdm_get();
  public static readonly int zx_xmlns_ix_gl = zxidPINVOKE.zx_xmlns_ix_gl_get();
  public static readonly string zx_xmlns_gl = zxidPINVOKE.zx_xmlns_gl_get();
  public static readonly int zx_xmlns_ix_dp = zxidPINVOKE.zx_xmlns_ix_dp_get();
  public static readonly string zx_xmlns_dp = zxidPINVOKE.zx_xmlns_dp_get();
  public static readonly int zx_xmlns_ix_idp = zxidPINVOKE.zx_xmlns_ix_idp_get();
  public static readonly string zx_xmlns_idp = zxidPINVOKE.zx_xmlns_idp_get();
  public static readonly int zx_xmlns_ix_pmm = zxidPINVOKE.zx_xmlns_ix_pmm_get();
  public static readonly string zx_xmlns_pmm = zxidPINVOKE.zx_xmlns_pmm_get();
  public static readonly int zx_xmlns_ix_prov = zxidPINVOKE.zx_xmlns_ix_prov_get();
  public static readonly string zx_xmlns_prov = zxidPINVOKE.zx_xmlns_prov_get();
  public static readonly int zx_xmlns_ix_shps = zxidPINVOKE.zx_xmlns_ix_shps_get();
  public static readonly string zx_xmlns_shps = zxidPINVOKE.zx_xmlns_shps_get();
  public static readonly int zx_xmlns_ix_hrxml = zxidPINVOKE.zx_xmlns_ix_hrxml_get();
  public static readonly string zx_xmlns_hrxml = zxidPINVOKE.zx_xmlns_hrxml_get();
  public static readonly int zx_xmlns_ix_idhrxml = zxidPINVOKE.zx_xmlns_ix_idhrxml_get();
  public static readonly string zx_xmlns_idhrxml = zxidPINVOKE.zx_xmlns_idhrxml_get();
  public static readonly int zx_xmlns_ix_demomed = zxidPINVOKE.zx_xmlns_ix_demomed_get();
  public static readonly string zx_xmlns_demomed = zxidPINVOKE.zx_xmlns_demomed_get();
  public static readonly int zx_xmlns_ix_b12 = zxidPINVOKE.zx_xmlns_ix_b12_get();
  public static readonly string zx_xmlns_b12 = zxidPINVOKE.zx_xmlns_b12_get();
  public static readonly int zx_xmlns_ix_sec12 = zxidPINVOKE.zx_xmlns_ix_sec12_get();
  public static readonly string zx_xmlns_sec12 = zxidPINVOKE.zx_xmlns_sec12_get();
  public static readonly int zx_xmlns_ix_di12 = zxidPINVOKE.zx_xmlns_ix_di12_get();
  public static readonly string zx_xmlns_di12 = zxidPINVOKE.zx_xmlns_di12_get();
  public static readonly int zx_xmlns_ix_is12 = zxidPINVOKE.zx_xmlns_ix_is12_get();
  public static readonly string zx_xmlns_is12 = zxidPINVOKE.zx_xmlns_is12_get();
  public static readonly int zx_xmlns_ix_xac = zxidPINVOKE.zx_xmlns_ix_xac_get();
  public static readonly string zx_xmlns_xac = zxidPINVOKE.zx_xmlns_xac_get();
  public static readonly int zx_xmlns_ix_xa = zxidPINVOKE.zx_xmlns_ix_xa_get();
  public static readonly string zx_xmlns_xa = zxidPINVOKE.zx_xmlns_xa_get();
  public static readonly int zx_xmlns_ix_xasa = zxidPINVOKE.zx_xmlns_ix_xasa_get();
  public static readonly string zx_xmlns_xasa = zxidPINVOKE.zx_xmlns_xasa_get();
  public static readonly int zx_xmlns_ix_xasp = zxidPINVOKE.zx_xmlns_ix_xasp_get();
  public static readonly string zx_xmlns_xasp = zxidPINVOKE.zx_xmlns_xasp_get();
  public static readonly int zx_xmlns_ix_xaspcd1 = zxidPINVOKE.zx_xmlns_ix_xaspcd1_get();
  public static readonly string zx_xmlns_xaspcd1 = zxidPINVOKE.zx_xmlns_xaspcd1_get();
  public static readonly int zx_xmlns_ix_xasacd1 = zxidPINVOKE.zx_xmlns_ix_xasacd1_get();
  public static readonly string zx_xmlns_xasacd1 = zxidPINVOKE.zx_xmlns_xasacd1_get();
  public static readonly int zx_xmlns_ix_wst = zxidPINVOKE.zx_xmlns_ix_wst_get();
  public static readonly string zx_xmlns_wst = zxidPINVOKE.zx_xmlns_wst_get();
  public static readonly int zx_xmlns_ix_wsp = zxidPINVOKE.zx_xmlns_ix_wsp_get();
  public static readonly string zx_xmlns_wsp = zxidPINVOKE.zx_xmlns_wsp_get();
  public static readonly int zx_xmlns_ix_wsc = zxidPINVOKE.zx_xmlns_ix_wsc_get();
  public static readonly string zx_xmlns_wsc = zxidPINVOKE.zx_xmlns_wsc_get();
  public static readonly int zx_xmlns_ix_tas3 = zxidPINVOKE.zx_xmlns_ix_tas3_get();
  public static readonly string zx_xmlns_tas3 = zxidPINVOKE.zx_xmlns_tas3_get();
  public static readonly int zx_xmlns_ix_tas3sol = zxidPINVOKE.zx_xmlns_ix_tas3sol_get();
  public static readonly string zx_xmlns_tas3sol = zxidPINVOKE.zx_xmlns_tas3sol_get();
}
